@@ -1,14 +1,14 @@
 /** 
  * @file bonus.c 
  * @brief Handle gems, bonus and penality 
- * @date 2007-08-22
+ * @date 2012-08-26 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  * @author Laurent Duperval
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: bonus.c,v 1.17 2007/08/24 07:55:16 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: bonus.c,v 1.30 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -36,6 +36,7 @@
 #include "electrical_shock.h"
 #include "energy_gauge.h"
 #include "gfx_wrapper.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "menu_sections.h"
 #include "lonely_foes.h"
@@ -133,21 +134,67 @@ bonus_once_init (void)
                                        sizeof (gem_str));
       if (gems == NULL)
         {
-          fprintf (stderr, "bonus.c/bonus_once_init() "
-                   "not enough memory to allocate 'gems' structure");
+          LOG_ERR ("not enough memory to allocate 'gems' structure");
           return FALSE;
         }
     }
   return 1;
 }
 
+/**
+ * Convert bonus gems from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+bonus_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/bonus-gems/bonus-gem-x/bonus-gem-xx.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/bonus-gems"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < GEM_NUMOF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/bonus-gems/bonus-gem-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < GEM_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/bonus-gems/bonus-gem-%01d/bonus-gem-%02d.png",
+                   type + 1, frame);
+          if (!image_to_png (&bonus[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /**
  * Initialize gem structure and chained list 
  */
 void
 bonus_init (void)
 {
-  Uint32 i;
+  Sint32 i;
   gem_str *gem;
   num_of_gems = 0;
   for (i = 0; i < MAX_NUMOF_GEMS_ON_SCREEN; i++)
@@ -189,17 +236,18 @@ bonus_handle (void)
     }
   for (i = 0; i < num_of_gems; i++, gem = gem->next)
     {
+
+#ifdef UNDER_DEVELOPMENT
+      if (gem == NULL && i < (num_of_gems - 1))
+        {
+          LOG_ERR ("gem->next is null %i/%i", i, num_of_gems);
+          break;
+        }
+#endif
+
       /* check the current trajectory (only one available) */
       switch (gem->trajectory)
         {
-#ifdef UNDER_DEVELOPMENT
-          if (gem == NULL && i < (num_of_gems - 1))
-            {
-              fprintf (stderr, "(!)bonus.c/bonus_handle(): "
-                       "gem->next is null %i/%i\n", i, num_of_gems);
-              break;
-            }
-#endif
           /*
            * bonus go straight (from top to bottom)
            */
@@ -214,12 +262,11 @@ bonus_handle (void)
             if (((Sint16) gem->ycoord >=
                  (offscreen_height_visible + offscreen_clipsize))
                 || ((Sint16) gem->xcoord +
-                    (Sint16) gem->img[gem->
-                                      current_image]->w >=
+                    (Sint16) gem->img[gem->current_image]->w >=
                     (offscreen_width - 1))
                 || ((Sint16) gem->xcoord +
-                    (Sint16) gem->img[gem->
-                                      current_image]->w < offscreen_clipsize))
+                    (Sint16) gem->img[gem->current_image]->w <
+                    offscreen_clipsize))
               {
                 /* gem sprite disappear from the screen, remove it */
                 bonus_del_gem (gem);
@@ -416,7 +463,7 @@ bonus_add (const enemy * const foe)
 static void
 bonus_new_gem (Sint32 type, float xcoord, float ycoord, float speed)
 {
-  Uint32 i;
+  Sint32 i;
   gem_str *gem;
   gem = bonus_get_gem ();
   if (gem == NULL)
@@ -763,9 +810,9 @@ bonus_meteor_get (Sint32 value)
 static void
 bonus_check_chained_list (void)
 {
-  Uint32 i;
+  Sint32 i;
   gem_str *gem;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < MAX_NUMOF_GEMS_ON_SCREEN; i++)
     {
       gem = &gems[i];
@@ -776,10 +823,8 @@ bonus_check_chained_list (void)
     }
   if (count != num_of_gems)
     {
-      fprintf (stderr, "(!)bonus.c/"
-               "bonus_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, =%i\n", count, num_of_gems);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, num_of_gems=%i", count, num_of_gems);
     }
   count = 0;
   gem = gem_first;
@@ -791,10 +836,8 @@ bonus_check_chained_list (void)
   while (gem != NULL && count <= (MAX_NUMOF_GEMS_ON_SCREEN + 1));
   if (count != num_of_gems)
     {
-      fprintf (stderr, "(!)bonus.c/"
-               "bonus_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_gems=%i\n", count, num_of_gems);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_gems=%i", count, num_of_gems);
     }
   count = 0;
   gem = gem_last;
@@ -806,10 +849,8 @@ bonus_check_chained_list (void)
   while (gem != NULL && count <= (MAX_NUMOF_GEMS_ON_SCREEN + 1));
   if (count != num_of_gems)
     {
-      fprintf (stderr, "(!)bonus.c/"
-               "bonus_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_gems=%i\n", count, num_of_gems);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_gems=%i", count, num_of_gems);
     }
 }
 #endif
@@ -821,7 +862,7 @@ bonus_check_chained_list (void)
 static gem_str *
 bonus_get_gem (void)
 {
-  Uint32 i;
+  Sint32 i;
   gem_str *gem;
   for (i = 0; i < MAX_NUMOF_GEMS_ON_SCREEN; i++)
     {
@@ -850,8 +891,7 @@ bonus_get_gem (void)
 #endif
       return gem;
     }
-  fprintf (stderr, "(!)bonus.c/bonus_get() "
-           "no more element gem is available\n");
+  LOG_ERR ("no more element gem is available");
   return NULL;
 }
 
