@@ -1,13 +1,12 @@
-
 /** 
  * @file bonus.h 
  * @brief Handle gems, bonus and penality 
  * @created 2006-11-19 
- * @date 2007-08-22
+ * @date 2012-08-26
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: bonus.h,v 1.11 2007/08/24 07:55:16 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: bonus.h,v 1.18 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +27,8 @@
 #define __BONUS__
 
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif
 
 /** Number of different bonus 
@@ -37,13 +37,16 @@ extern "C" {
 /** Maximum number of images peer bonus */
 #define GEM_NUMOF_IMAGES 32
 
-bool bonus_once_init (void);
-void bonus_init (void); 
-void bonus_free (void);
-void bonus_handle (void);
-void bonus_add (const enemy *const pve);
-void bonus_meteor_add (const enemy *const pve);
-extern image bonus[GEM_NUMOF_TYPES][GEM_NUMOF_IMAGES];
+  bool bonus_once_init (void);
+  void bonus_init (void);
+  void bonus_free (void);
+  void bonus_handle (void);
+  void bonus_add (const enemy * const pve);
+  void bonus_meteor_add (const enemy * const pve);
+  extern image bonus[GEM_NUMOF_TYPES][GEM_NUMOF_IMAGES];
+#ifdef PNG_EXPORT_ENABLE
+  bool bonus_extract (void);
+#endif
 
 #ifdef __cplusplus
 }
