@@ -1,13 +1,13 @@
 /** 
  * @file curve_phase.c
  * @brief Handle the curve phase 
- * @date 2007-08-22
+ * @date 2010-01-01
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: curve_phase.c,v 1.16 2007/08/24 07:55:16 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: curve_phase.c,v 1.22 2012/06/03 17:06:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -33,6 +33,7 @@
 #include "electrical_shock.h"
 #include "enemies.h"
 #include "shots.h"
+#include "log_recorder.h"
 #include "meteors_phase.h"
 #include "gfx_wrapper.h"
 #include "grid_phase.h"
@@ -74,8 +75,7 @@ curve_once_init (void)
         (curve *) memory_allocation (CURVES_BEZIER_NUMOF * sizeof (curve));
       if (initial_curve == NULL)
         {
-          fprintf (stderr, "(!)curve_phase.c/curve_once_init(): "
-                   "'initial_curve' out of memory");
+          LOG_ERR ("'initial_curve' out of memory");
           return FALSE;
         }
     }
@@ -147,13 +147,11 @@ curve_phase (void)
       for (k = 0; k < foe->spr.numof_images; k++)
         {
           foe->spr.img[k] =
-            (image *) & enemi[courbe.
-                              num_vaisseau[i][courbe.
-                                              current_numof_enemies[i]]][k];
+            (image *) &
+            enemi[courbe.num_vaisseau[i][courbe.current_numof_enemies[i]]][k];
         }
       /* set shot time-frequency */
-      foe->fire_rate =
-        courbe.freq_tir[i][courbe.current_numof_enemies[i]];
+      foe->fire_rate = courbe.freq_tir[i][courbe.current_numof_enemies[i]];
       /* set counter of delay between two shots */
       foe->fire_rate_count = foe->fire_rate;
 
@@ -369,8 +367,8 @@ courbe_editeur ()
                        game_offscreen + ((128 + i * 16) * offscreen_width) +
                        (128 + 16 * j),
                        enemi[courbe.num_vaisseau[i][j]][15].compress,
-                       (Sint16) (enemi[courbe.num_vaisseau[i][j]][15].
-                                 nbr_data_comp >> 2),
+                       (Sint16) (enemi[courbe.num_vaisseau[i][j]]
+                                 [15].nbr_data_comp >> 2),
                        "enemi[courbe.num_vaisseau[i][j]][15].img");
         }
     }
@@ -414,8 +412,7 @@ courbe_editeur ()
         }
       else
         {
-          fprintf (stderr, "(!)curve_phase.c/courbe_editeur(): ",
-                   "Cannot create curve file !\n");
+          LOG_ERR ("Cannot create curve file!");
         }
     }
   curve_s_key_down = keys_down[K_S];
@@ -685,13 +682,11 @@ curve_enable_level (void)
       for (j = 0; j < foe->spr.numof_images; j++)
         {
           foe->spr.img[j] =
-            (image *) & enemi[courbe.
-                              num_vaisseau[i][courbe.
-                                              nbr_vaisseaux_act[i]]][j];
+            (image *) &
+            enemi[courbe.num_vaisseau[i][courbe.nbr_vaisseaux_act[i]]][j];
         }
       /* set shot time-frequency */
-      foe->fire_rate =
-        courbe.freq_tir[i][courbe.current_numof_enemies[i]];
+      foe->fire_rate = courbe.freq_tir[i][courbe.current_numof_enemies[i]];
       /* set counter of delay between two shots */
       foe->fire_rate_count = foe->fire_rate;
       /* set type of displacement */
