@@ -2,12 +2,12 @@
  * @file display_x11.c
  * @brief Handle displaying and updating the graphical components of the game
  * @created 1999-08-17
- * @date 2007-08-31
+ * @date 2010-01-01
  * @author Bruno Ethvignot
  */
 /*
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: display_x11.c,v 1.13 2007/09/02 16:13:56 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: display_x11.c,v 1.19 2012/06/03 17:06:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "assembler.h"
@@ -33,6 +33,7 @@
 #include "display.h"
 #include "electrical_shock.h"
 #include "energy_gauge.h"
+#include "log_recorder.h"
 #include "movie.h"
 #include "gfx_wrapper.h"
 #include "options_panel.h"
@@ -138,14 +139,7 @@ display_init (void)
       ximages_list[i] = NULL;
     }
 
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "display_x11.c/display_init(): "
-               "start xwindow intialize\n");
-    }
-#endif
-
+  LOG_INF ("Beginning of the initialization of XWindow");
   switch (vmode)
     {
     case 0:
@@ -167,8 +161,7 @@ display_init (void)
       x11_display = XOpenDisplay (0);
       if (x11_display == NULL)
         {
-          fprintf (stderr, "(!)display_x11.c/display_init(): "
-                   "XOpenDisplay failed!\n");
+          LOG_ERR ("XOpenDisplay() failed!");
           return FALSE;
         }
     }
@@ -179,8 +172,7 @@ display_init (void)
       root_window_id = DefaultRootWindow (x11_display);
       if (root_window_id == 0)
         {
-          fprintf (stderr, "(!)display_x11.c/display_init(): "
-                   "DefaultRootWindow failed!\n");
+          LOG_ERR ("DefaultRootWindow() failed!");
           return FALSE;
         }
     }
@@ -194,8 +186,7 @@ display_init (void)
   depth = DefaultDepth (x11_display, dfscreen);
   if (depth < 8)
     {
-      fprintf (stderr, "(!)display_x11.c/display_init(): "
-               "this game need 8-bit per pixels minimum " "(256 colors)!\n");
+      LOG_ERR ("this game need 8-bit per pixels minimum (256 colors)!");
       return FALSE;
     }
   bits_per_pixel = depth;
@@ -203,18 +194,20 @@ display_init (void)
   formatlist = XListPixmapFormats (x11_display, &formatcnt);
   if (formatlist == NULL)
     {
-      fprintf (stderr, "(!)display_x11.c/display_init(): "
-               "cannot get pixmap list format\n");
+      LOG_ERR ("cannot get pixmap list format");
       return FALSE;
     }
   formatok = -1;
   for (i = 0; i < formatcnt; i++)
-    if (formatlist[i].depth == (Sint32) (depth))
-      formatok = i;
+    {
+      if (formatlist[i].depth == (Sint32) (depth))
+        {
+          formatok = i;
+        }
+    }
   if (formatok == -1)
     {
-      fprintf (stderr, "(!)display_x11.c/display_init(): "
-               "screen depth error\n");
+      LOG_ERR ("screen depth error");
       return FALSE;
     }
   memcpy (&pixmapFormat, &formatlist[formatok], sizeof (pixmapFormat));
@@ -243,17 +236,12 @@ display_init (void)
     }
   displayw = DisplayWidth (x11_display, dfscreen);
   displayh = DisplayHeight (x11_display, dfscreen);
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "depth of screen: %i; bytes per pixel:%i; "
-               "size screen: (%i,%i)\n", depth, bytes_per_pixel, displayw,
-               displayh);
-      fprintf (stdout, "depth:%i; formatok:%i; formatcnt:%i; "
-               "pixmapFormat.scanline_pad:%i\n", depth, formatok, formatcnt,
-               pixmapFormat.scanline_pad);
-    }
-#endif
+  LOG_INF ("depth of screen: %i; bytes per pixel:%i; "
+           "size screen: (%i,%i)", depth, bytes_per_pixel, displayw,
+           displayh);
+  LOG_INF ("depth:%i; formatok:%i; formatcnt:%i; "
+           "pixmapFormat.scanline_pad:%i", depth, formatok, formatcnt,
+           pixmapFormat.scanline_pad);
 
   /* function creates a graphics context and returns a Graphic Contexts */
   if (!dga_enable)
@@ -268,8 +256,7 @@ display_init (void)
                                         &gcvalues);
           if (graphic_contexts == NULL)
             {
-              fprintf (stderr, "(!)display_x11.c/display_init(): "
-                       "XCreateGC() failed!\n");
+              LOG_ERR ("XCreateGC() failed!");
               return FALSE;
             }
         }
@@ -299,8 +286,7 @@ display_init (void)
                                   &window_attributes);
   if (main_window_id == 0)
     {
-      fprintf (stderr, "(!)display_x11.c/display_init(): "
-               "XCreateWindow() failed!");
+      LOG_ERR ("XCreateWindow() failed!");
       return FALSE;
     }
   XStoreName (x11_display, main_window_id, "PowerManga by TLK Games");
@@ -331,24 +317,17 @@ display_init (void)
       XF86DGAQueryDirectVideo (x11_display, dfscreen, &dga_flags);
       if (!(dga_flags & XF86DGADirectPresent))
         {
-          fprintf (stderr, "(!)display_x11.c/display_init()"
-                   "DGA's not available!\n");
+          LOG_ERR ("DGA's not available!");
           return FALSE;
         }
       XF86DGAGetVideo (x11_display, dfscreen, &dga_base_addr,
                        &dga_width, &dga_bank_size, &dga_ram_size);
       XF86DGAGetViewPortSize (x11_display, dfscreen, &dga_viewport_width,
                               &dga_viewport_height);
-#ifdef VERBOSE
-      if (power_conf->verbose)
-        {
-          fprintf (stdout, ">display_x11.c/display_init()"
-                   "dga_base_addr=%X; dga_width=%i; dga_bank_size=%i; "
-                   "dga_ram_size=%i; dga_viewport_width=%i; dga_viewport_height=%i\n",
-                   (Sint32) (dga_base_addr), dga_width, dga_bank_size,
-                   dga_ram_size, dga_viewport_width, dga_viewport_height);
-        }
-#endif
+      LOG_INF ("dga_base_addr: %p; dga_width: %i; dga_bank_size: %i; "
+               "dga_ram_size: %i; dga_viewport_width: %i; dga_viewport_height: %i",
+               dga_base_addr, dga_width, dga_bank_size,
+               dga_ram_size, dga_viewport_width, dga_viewport_height);
       XF86DGADirectVideo (x11_display, dfscreen,
                           XF86DGADirectGraphics | XF86DGADirectKeyb);
       memset (dga_base_addr, 0,
@@ -357,15 +336,9 @@ display_init (void)
     }
 
   disable_cursor ();
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "display_x11.c/display_init(): "
-               "end xwindow intialisation "
-               "dga_enable=%i vmode=%i  window_width=%i\n",
-               dga_enable, vmode, window_width);
-    }
-#endif
+  LOG_INF ("end xwindow intialisation "
+           "dga_enable: %i; vmode: %i; window_width: %i",
+           dga_enable, vmode, window_width);
 
   /* 8-bit depth screen */
   if (bytes_per_pixel == 1)
@@ -415,7 +388,7 @@ bool
 create_offscreens (void)
 {
   /* create XImage "game_offscreen" 512*440 */
-  if (!(game_ximage = create_ximage (offscreen_width, display_height)))
+  if ((game_ximage = create_ximage (offscreen_width, display_height)) == NULL)
     {
       return FALSE;
     }
@@ -467,8 +440,7 @@ create_palettes (void)
         }
       if (x_colors == NULL)
         {
-          fprintf (stderr, "(!)display_x11.c/create_palettes() "
-                   "'x_colors' out of memory");
+          LOG_ERR ("'x_colors' out of memory");
           return FALSE;
         }
       _p = (unsigned char *) palette_24;
@@ -495,8 +467,7 @@ create_palettes (void)
               pal16 = (Uint16 *) memory_allocation (256 * 2);
               if (pal16 == NULL)
                 {
-                  fprintf (stderr, "(!)display_x11.c/create_palettes() "
-                           "not enough memory to allocate 512 bytes!\n");
+                  LOG_ERR ("not enough memory to allocate 512 bytes!");
                   return FALSE;
                 }
             }
@@ -520,8 +491,7 @@ create_palettes (void)
                 }
               if (pal32 == NULL)
                 {
-                  fprintf (stderr, "(!)display_x11.c/create_palettes() "
-                           "not enough memory to allocate 1024 bytes!\n");
+                  LOG_ERR ("not enough memory to allocate 1024 bytes!");
                   return FALSE;
                 }
               _p = (unsigned char *) pal32;
@@ -617,12 +587,7 @@ display_handle_events (void)
           break;
 
         default:
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            fprintf (stdout,
-                     "display_x11.c / xw_exec() : evenement type=%i\n",
-                     xevent.type);
-#endif
+          LOG_DBG ("evenement type: %i", xevent.type);
           break;
         }
     }
@@ -691,8 +656,7 @@ dga320x200 ()
     dga_base_addr + _iOffset +
     ((dga_viewport_height -
       display_height) / 2 * dga_viewport_width) * bytes_per_pixel;
-  _pDestination2 =
-    _pDestination + 16 * dga_viewport_width * bytes_per_pixel;
+  _pDestination2 = _pDestination + 16 * dga_viewport_width * bytes_per_pixel;
   copie4octets (_pSource, _pDestination2,
                 (offscreen_width_visible * bytes_per_pixel) / 4,
                 offscreen_height_visible,
@@ -721,7 +685,8 @@ dga320x200 ()
                         ((score_offscreen_height +
                           171) * dga_viewport_width * bytes_per_pixel),
                         16 / 4 * bytes_per_pixel, 8,
-                        OPTIONS_WIDTH * bytes_per_pixel - 16 * bytes_per_pixel,
+                        OPTIONS_WIDTH * bytes_per_pixel -
+                        16 * bytes_per_pixel,
                         (dga_viewport_width * bytes_per_pixel) -
                         16 * bytes_per_pixel);
           score_x2_refresh = FALSE;
@@ -736,7 +701,8 @@ dga320x200 ()
                         ((score_offscreen_height +
                           5) * dga_viewport_width * bytes_per_pixel),
                         16 / 4 * bytes_per_pixel, 8,
-                        OPTIONS_WIDTH * bytes_per_pixel - 16 * bytes_per_pixel,
+                        OPTIONS_WIDTH * bytes_per_pixel -
+                        16 * bytes_per_pixel,
                         (dga_viewport_width * bytes_per_pixel) -
                         16 * bytes_per_pixel);
           score_x4_refresh = FALSE;
@@ -883,7 +849,8 @@ dga640x400 ()
                     ((offscreen_width_visible + optx) * bytes_per_pixel * 2) +
                     ((score_offscreen_height +
                       opty) * dga_viewport_width * bytes_per_pixel * 2), 28,
-                    28, OPTIONS_WIDTH * bytes_per_pixel - 28 * bytes_per_pixel,
+                    28,
+                    OPTIONS_WIDTH * bytes_per_pixel - 28 * bytes_per_pixel,
                     (dga_viewport_width * bytes_per_pixel * 2) -
                     28 * bytes_per_pixel * 2);
           }
@@ -937,7 +904,7 @@ dga640x400 ()
 void
 display_movie (void)
 {
-  Uint32 i;
+  Sint32 i;
   char *_pDestination;
   switch (bytes_per_pixel)
     {
@@ -1049,8 +1016,8 @@ display_320x200 ()
   if (update_all)
     {
       XPutImage (x11_display, main_window_id, graphic_contexts,
-                 options_ximage, 0, 0, offscreen_width_visible, 16, OPTIONS_WIDTH,
-                 OPTIONS_HEIGHT);
+                 options_ximage, 0, 0, offscreen_width_visible, 16,
+                 OPTIONS_WIDTH, OPTIONS_HEIGHT);
       /* display score panel */
       XPutImage (x11_display, main_window_id, graphic_contexts,
                  scores_ximage, 0, 0, 0, 0, score_offscreen_width,
@@ -1134,9 +1101,9 @@ display_scalex (void)
       /* display option panel */
       scale (scalex,
              pixels + (offscreen_width_visible * bytes_per_pixel * scalex) +
-             (pitch * score_offscreen_height * scalex), pitch, options_offscreen,
-             OPTIONS_WIDTH * bytes_per_pixel, bytes_per_pixel, OPTIONS_WIDTH,
-             OPTIONS_HEIGHT);
+             (pitch * score_offscreen_height * scalex), pitch,
+             options_offscreen, OPTIONS_WIDTH * bytes_per_pixel,
+             bytes_per_pixel, OPTIONS_WIDTH, OPTIONS_HEIGHT);
       XPutImage (x11_display, main_window_id, graphic_contexts, scalex_ximage,
                  /* offset source from the top left edge of the image */
                  0, 0,
@@ -1238,8 +1205,9 @@ display_scalex (void)
           scale (scalex,
                  pixels + 10 * bytes_per_pixel * scalex + 3 * pitch * scalex,
                  pitch,
-                 scores_offscreen + 10 * bytes_per_pixel + 3 * score_offscreen_pitch,
-                 score_offscreen_pitch, bytes_per_pixel, 45, 9);
+                 scores_offscreen + 10 * bytes_per_pixel +
+                 3 * score_offscreen_pitch, score_offscreen_pitch,
+                 bytes_per_pixel, 45, 9);
           XPutImage (x11_display, main_window_id, graphic_contexts,
                      scalex_ximage, 10 * scalex, 3 * scalex, 10 * scalex,
                      3 * scalex, 45 * scalex, 9 * scalex);
@@ -1275,7 +1243,8 @@ display_640x400 (void)
       copy2X (options_offscreen,
               scalex_offscreen +
               (offscreen_width_visible * 2 * bytes_per_pixel) +
-              (window_width * bytes_per_pixel * 32), OPTIONS_WIDTH, OPTIONS_HEIGHT, 0,
+              (window_width * bytes_per_pixel * 32), OPTIONS_WIDTH,
+              OPTIONS_HEIGHT, 0,
               window_width * bytes_per_pixel * 2 -
               (OPTIONS_WIDTH * 2 * bytes_per_pixel));
       XPutImage (x11_display, main_window_id, graphic_contexts, scalex_ximage,
@@ -1411,46 +1380,37 @@ display_free (void)
   scores_ximage = NULL;
   options_offscreen = NULL;
   options_ximage = NULL;
-  if (main_window_id)
+  if (main_window_id != 0)
     {
       XDestroyWindow (x11_display, main_window_id);
       main_window_id = 0;
-#ifdef VERBOSE
-      if (power_conf->verbose)
-        fprintf (stdout, "- XDestroyWindow()\n");
-#endif
+      LOG_DBG ("XDestroyWindow()");
     }
-  if (graphic_contexts)
+  if (graphic_contexts != NULL)
     {
       XFreeGC (x11_display, graphic_contexts);
-      graphic_contexts = 0;
-#ifdef VERBOSE
-      if (power_conf->verbose)
-        fprintf (stdout, "- XFreeGC\n");
-#endif
+      graphic_contexts = NULL;
+      LOG_DBG ("XFreeGC()");
     }
-  if (x11_display)
+  if (x11_display != NULL)
     {
       XCloseDisplay (x11_display);
-      x11_display = 0;
-#ifdef VERBOSE
-      if (power_conf->verbose)
-        fprintf (stdout, "- XCloseDisplay()\n");
-#endif
+      x11_display = NULL;
+      LOG_DBG ("XCloseDisplay()");
     }
   if (x_colors != NULL)
     {
-      free_memory ((char *)x_colors);
+      free_memory ((char *) x_colors);
       x_colors = NULL;
     }
   if (pal16 != NULL)
     {
-      free_memory ((char*)pal16);
+      free_memory ((char *) pal16);
       pal16 = NULL;
     }
   if (pal32 != NULL)
     {
-      free_memory ((char*)pal32);
+      free_memory ((char *) pal32);
       pal32 = NULL;
     }
 }
@@ -1463,11 +1423,12 @@ display_clear_offscreen (void)
 {
   /* clear logical screen */
   clear_offscreen (game_offscreen +
-             (offscreen_clipsize * offscreen_pitch) +
-             (offscreen_clipsize * bytes_per_pixel),
-             (offscreen_width_visible * bytes_per_pixel) >> 2,
-             offscreen_height_visible,
-             (offscreen_width - offscreen_width_visible) * bytes_per_pixel);
+                   (offscreen_clipsize * offscreen_pitch) +
+                   (offscreen_clipsize * bytes_per_pixel),
+                   (offscreen_width_visible * bytes_per_pixel) >> 2,
+                   offscreen_height_visible,
+                   (offscreen_width -
+                    offscreen_width_visible) * bytes_per_pixel);
 }
 
 /**
@@ -1505,7 +1466,6 @@ create_ximage (Uint32 width, Uint32 height)
   XImage *ximg;
   Uint32 i;
   Sint32 index = -1;
-
   for (i = 0; i < MAXIMUM_OF_XIMAGES; i++)
     {
       if (ximages_list[i] == 0)
@@ -1516,9 +1476,8 @@ create_ximage (Uint32 width, Uint32 height)
     }
   if (index < 0)
     {
-      fprintf (stderr, "(!)display_x11.c/create_ximage(): "
-               "ximages list overflows!");
-      return 0;
+      LOG_ERR ("ximages list overflows!");
+      return NULL;
     }
 
   ximg =
@@ -1526,9 +1485,8 @@ create_ximage (Uint32 width, Uint32 height)
                      ZPixmap, 0, &SHMInfo[index], width, height);
   if (ximg == NULL)
     {
-      fprintf (stderr, "(!)display_x11.c/create_ximage(): "
-               "XShmCreateImage() failed!");
-      return 0;
+      LOG_ERR ("XShmCreateImage() failed!");
+      return NULL;
     }
   SHMInfo[index].shmid =
     shmget (IPC_PRIVATE, ximg->bytes_per_line * ximg->height,
@@ -1539,11 +1497,7 @@ create_ximage (Uint32 width, Uint32 height)
   XShmAttach (x11_display, &SHMInfo[index]);
   ximages_list[index] = ximg;
   ximages_counter++;
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    fprintf (stdout, "display_x11.c/create_ximage(): XShmCreateImage(%i, %i)",
-             width, height);
-#endif
+  LOG_DBG ("XShmCreateImage(%i, %i)", width, height);
   return ximg;
 }
 #else
@@ -1566,9 +1520,8 @@ create_ximage (Uint32 width, Uint32 height)
     }
   if (index < 0)
     {
-      fprintf (stderr, "(!)display_x11.c/create_ximage(): "
-               "ximages list overflows!");
-      return 0;
+      LOG_ERR ("ximages list overflows!");
+      return NULL;
     }
   pad = pixmapFormat.scanline_pad;
   lenght = pixmapFormat.bits_per_pixel * offscreen_width / 8;
@@ -1581,8 +1534,8 @@ create_ximage (Uint32 width, Uint32 height)
   data = memory_allocation (width * height * bytes_per_pixel);
   if (data == NULL)
     {
-      fprintf (stderr, "(!)display_x11.c/create_ximage(): " "out of memory!");
-      return 0;
+      LOG_ERR ("out of memory!");
+      return NULL;
     }
 
   *ximg =
@@ -1590,19 +1543,12 @@ create_ximage (Uint32 width, Uint32 height)
                   0, data, width, height, pad, width * bytes_per_pixel);
   if (ximg == NULL)
     {
-      fprintf (stderr, "(!)display_x11.c/create_ximage(): "
-               "XCreateImage() failed!");
-      return 0;
+      LOG_ERR ("XCreateImage() failed!");
+      return NULL;
     }
   ximages_list[index] = ximg;
   ximages_counter++;
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "- display_x11.c/create_ximage(): "
-               "XCreateImage successful!\n");
-    }
-#endif
+  LOG_DBG ("XCreateImage() successful!");
   return ximg;
 }
 #endif
@@ -1621,20 +1567,17 @@ destroy_ximage (XImage * ximg)
         {
           XShmDetach (x11_display, &SHMInfo[i]);
           if (SHMInfo[i].shmaddr)
-            shmdt (SHMInfo[i].shmaddr);
+            {
+              shmdt (SHMInfo[i].shmaddr);
+            }
           if (SHMInfo[i].shmid >= 0)
-            shmctl (SHMInfo[i].shmid, IPC_RMID, 0);
+            {
+              shmctl (SHMInfo[i].shmid, IPC_RMID, 0);
+            }
           XDestroyImage (ximg);
           ximages_list[i] = NULL;
           ximages_counter--;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            {
-              fprintf (stdout,
-                       "- display_x11.c/destroy_ximage(): "
-                       "XShmDetach() and XDestroyImage()");
-            }
-#endif
+          LOG_DBG ("XShmDetach() and XDestroyImage()");
           break;
         }
     }
@@ -1652,13 +1595,7 @@ destroy_ximage (XImage * ximg)
           XDestroyImage (ximg);
           ximages_list[i] = NULL;
           ximages_counter--;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            {
-              fprintf (stdout, "- display_x11.c/destroy_ximage(): "
-                       "XDestroyImage() ");
-            }
-#endif
+          LOG_INF ("XDestroyImage()");
           break;
         }
     }
@@ -1689,11 +1626,7 @@ destroy_ximages (void)
           XDestroyImage (ximages_list[i]);
           ximages_list[i] = NULL;
           ximages_counter--;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            fprintf (stdout, "display_x11.c/destroy_ximages(): "
-                     "XShmDetach and XDestroyImage\n");
-#endif
+          LOG_DBG ("XShmDetach and XDestroyImage");
         }
     }
 }
@@ -1711,13 +1644,7 @@ destroy_ximages (void)
           XDestroyImage (ximages_list[i]);
           ximages_list[i] = NULL;
           ximages_counter--;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            {
-              fprintf (stdout, "display_x11.c/destroy_ximages(): "
-                       "XDestroyImage()\n");
-            }
-#endif
+          LOG_INF ("XDestroyImage()");
         }
     }
 }
