@@ -1,13 +1,13 @@
 /** 
  * @file enemies.c
  * @brief handle all enemies 
- * @date 2007-08-22
+ * @date 2012-08-26 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: enemies.c,v 1.31 2007/08/30 15:23:28 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: enemies.c,v 1.48 2012/08/26 15:44:26 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -40,6 +40,7 @@
 #include "gfx_wrapper.h"
 #include "grid_phase.h"
 #include "guardians.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "menu_sections.h"
 #include "meteors_phase.h"
@@ -90,8 +91,7 @@ enemies_once_init (void)
       enemies = (enemy *) memory_allocation (MAX_OF_ENEMIES * sizeof (enemy));
       if (enemies == NULL)
         {
-          fprintf (stderr, "enemies.c/enemies_once_init() "
-                   "not enough memory to allocate 'enemies'");
+          LOG_ERR ("not enough memory to allocate 'enemies'");
           return FALSE;
         }
     }
@@ -167,6 +167,94 @@ enemies_load (void)
   return TRUE;
 }
 
+/**
+ * Convert enemies from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+enemies_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/enemies/bloodsuker-%02d/enemy-%02d.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes",
+               (Sint32) strlen (model) + 1);
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/enemies"))
+    {
+      return FALSE;
+    }
+  for (type = 0; type < ENEMIES_MAX_SMALL_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/enemies/enemies-%02d", type + 1);
+      create_dir (filename);
+      for (frame = 0; frame < IMAGES_MAXOF; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/enemies/enemies-%02d/enemy-%01d.png",
+                   type + 1, frame);
+          if (!image_to_png (&enemi[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  for (type = 0; type < ENEMIES_MAX_BLOODSUCKER_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/enemies/bloodsuker-%02d", type + 1);
+      if (!create_dir (filename))
+        {
+          return FALSE;
+        }
+      for (frame = 0; frame < BLOODSUCKER_NUM_OF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/enemies/bloodsuker-%02d/enemy-%02d.png",
+                   type + 1, frame);
+          if (!image_to_png
+              (&enemi[ENEMIES_MAX_SMALL_TYPES + type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+
+  for (type = 0; type < LONELY_FOES_MAX_OF + ENEMIES_MAX_SPECIAL_TYPES;
+       type++)
+    {
+      sprintf (filename, EXPORT_DIR "/enemies/special-%02d", type + 1);
+      if (!create_dir (filename))
+        {
+          return FALSE;
+        }
+      for (frame = 0; frame < ENEMIES_SPECIAL_NUM_OF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/enemies/special-%02d/enemy-%02d.png",
+                   type + 1, frame);
+          if (!image_to_png
+              (&enemi
+               [ENEMIES_MAX_SMALL_TYPES + ENEMIES_MAX_BLOODSUCKER_TYPES +
+                type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+
+
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /** 
  * Release memory used for the enemies 
  */
@@ -240,8 +328,7 @@ enemies_kill (void)
 #ifdef UNDER_DEVELOPMENT
       if (foe == NULL && i < (num_of_enemies - 1))
         {
-          fprintf (stderr, "(!)enemies.c/enemies_kill(): "
-                   "foe->next is null %i/%i\n", i, num_of_enemies);
+          LOG_ERR ("foe->next is null %i/%i", i, num_of_enemies);
           break;
         }
 #endif
@@ -274,8 +361,7 @@ enemies_handle (void)
 #ifdef UNDER_DEVELOPMENT
       if (foe == NULL && i < (num_of_enemies - 1))
         {
-          fprintf (stderr, "(!)enemies.c/enemies_handle(): "
-                   "foe->next is null %i/%i\n", i, num_of_enemies);
+          LOG_ERR ("foe->next is null %i/%i", i, num_of_enemies);
           break;
         }
 #endif
@@ -333,7 +419,7 @@ enemies_handle (void)
                     energy_gauge_guard_is_update = TRUE;
                     break;
                   }
-                  enemies_kill ();
+                enemies_kill ();
               }
             /*  guardian is always alive */
             else
@@ -470,8 +556,7 @@ enemy_curve (enemy * foe)
           foe->fire_rate_count = foe->fire_rate;
           for (k = 0;
                (k <
-                spr->img[spr->current_image]->
-                numof_cannons
+                spr->img[spr->current_image]->numof_cannons
                 && num_of_shots <
                 ((MAX_OF_SHOTS - 1) -
                  spr->img[spr->current_image]->numof_cannons)); k++)
@@ -623,12 +708,10 @@ enemy_grid (enemy * foe)
       explosion_add (spr->xcoord, spr->ycoord, 0.25, foe->type, 0);
       /* add an explosion fragments to the list  */
       explosions_fragments_add (spr->xcoord +
-                                spr->img[foe->
-                                         spr.current_image]->x_gc - 8,
+                                spr->img[foe->spr.current_image]->x_gc - 8,
                                 spr->ycoord +
-                                spr->img[foe->
-                                         spr.current_image]->y_gc - 8, 1.5, 5,
-                                0, 1);
+                                spr->img[foe->spr.current_image]->y_gc - 8,
+                                1.5, 5, 0, 1);
       return TRUE;
     }
 
@@ -742,11 +825,11 @@ enemy_lonely_soukee (enemy * foe)
       /* search image to draw  corresponding in the angle */
       if (sign (foe->angle_tir) < 0)
         {
-          foe->img_angle = (Sint16) ((foe->angle_tir + DEUX_PI) / PI_SUR_16);
+          foe->img_angle = (Sint16) ((foe->angle_tir + TWO_PI) / PI_BY_16);
         }
       else
         {
-          foe->img_angle = (Sint16) (foe->angle_tir / PI_SUR_16);
+          foe->img_angle = (Sint16) (foe->angle_tir / PI_BY_16);
         }
       /* avoid an negative index of table */
       foe->img_angle = (Sint16) abs (foe->img_angle);
@@ -1110,7 +1193,7 @@ enemy_lonely_meteor (enemy * foe)
           /* clear counter delay between two images */
           spr->anim_count = 0;
           /* flip to the next image */
-          spr->current_image += foe->sens_anim;
+          spr->current_image = (Sint16) (spr->current_image + foe->sens_anim);
           /* check if last image has been reached */
           if (spr->current_image >= spr->numof_images)
             {
@@ -1135,7 +1218,7 @@ enemy_lonely_meteor (enemy * foe)
 static void
 lonely_foe_fire (enemy * foe)
 {
-  Uint32 canon_pos;
+  Sint32 canon_pos;
   if (player_pause || menu_status != MENU_OFF
       || menu_section != NO_SECTION_SELECTED)
     {
@@ -1290,11 +1373,9 @@ lonely_foe_anim_adjustable_cannon (enemy * foe)
   angle =
     calc_target_angle ((Sint16)
                        (spr->xcoord +
-                        spr->img[foe->
-                                 spr.current_image]->x_gc),
+                        spr->img[foe->spr.current_image]->x_gc),
                        (Sint16) (spr->ycoord +
-                                 spr->
-                                 img[spr->current_image]->y_gc),
+                                 spr->img[spr->current_image]->y_gc),
                        (Sint16) (ship->spr.xcoord +
                                  ship->spr.img[ship->spr.current_image]->
                                  x_gc),
@@ -1302,13 +1383,13 @@ lonely_foe_anim_adjustable_cannon (enemy * foe)
                                  ship->spr.img[ship->spr.current_image]->
                                  y_gc));
   /* search image to draw determined upon angle */
-  if (sign (angle < 0))
+  if (sign (angle) < 0)
     {
-      foe->img_angle = (Sint16) ((angle + DEUX_PI) / PI_SUR_16);
+      foe->img_angle = (Sint16) ((angle + TWO_PI) / PI_BY_16);
     }
   else
     {
-      foe->img_angle = (Sint16) (angle / PI_SUR_16);
+      foe->img_angle = (Sint16) (angle / PI_BY_16);
     }
   /* avoid a negative table index */
   foe->img_angle = (Sint16) abs (foe->img_angle);
@@ -1353,46 +1434,6 @@ enemy_lonely (enemy * foe)
         }
       break;
 
-      /* present in the guardian number 12 */
-    /* case ETB_SHURIKY:
-      if (guardian->enemy[0]->type != KAMEAMEA
-          || !guardian->enemy[0]->is_enabled)
-        {
-          foe->type = SHURIKY;
-        }
-      break;
-      */
-
-      /* * present in the guardian number 14 */
-      /*
-    case SAAKEY:
-      if (guardian->enemy[0]->type != GHOTTEN
-          || !guardian->enemy[0]->is_enabled)
-        {
-          if (spr->current_image >= 31)
-            {
-              for (k = 0; k < spr->numof_images; k++)
-                {
-                  spr->img[k] = (image *) & enemi[SAAKAMIN][k];
-                }
-              spr->current_image = 0;
-              spr->anim_speed = 3;
-              foe->type = SAAKAMIN;
-            }
-        }
-      break;
-      */
-      /* present in the guardian number 14 */
-      /*
-    case SAAKAMIN:
-      if (guardian->enemy[0]->type != GHOTTEN
-          || !guardian->enemy[0]->is_enabled)
-        {
-          foe->type = SHURIKY;
-        }
-      break;
-      */
-
       /* foe moving from the top of the screen towards the bottom  */
     case MILLOUZ:
     case TOUBOUG:
@@ -1611,12 +1652,10 @@ enemy_lonely (enemy * foe)
       explosions_add_serie (foe);
       /* add one or more explosions fragments */
       explosions_fragments_add (spr->xcoord +
-                                spr->img[foe->
-                                         spr.current_image]->x_gc - 8,
+                                spr->img[foe->spr.current_image]->x_gc - 8,
                                 spr->ycoord +
-                                spr->img[foe->
-                                         spr.current_image]->y_gc - 8, 1.0, 4,
-                                0, 1);
+                                spr->img[foe->spr.current_image]->y_gc - 8,
+                                1.0, 4, 0, 1);
       return TRUE;
     }
 
@@ -1650,14 +1689,14 @@ enemy_set_fadeout (enemy * foe)
   /* handle the second sprite of the guardien
    * in the cases where the guardian is composed of 2 sprites */
   if (guardian->number > 0 && foe->displacement == DISPLACEMENT_GUARDIAN
-      && guardian->enemy[1] != NULL
-      && guardian->enemy[1]->displacement == DISPLACEMENT_GUARDIAN)
+      && guardian->foe[1] != NULL
+      && guardian->foe[1]->displacement == DISPLACEMENT_GUARDIAN)
     {
-      guardian->enemy[1]->dead = TRUE;
-      guardian->enemy[1]->visible_dead = TRUE;
-      guardian->enemy[1]->dead_color_index = 0;
-      guardian->enemy[1]->invincible = 20;
-      guardian->enemy[1]->spr.energy_level = 0;
+      guardian->foe[1]->dead = TRUE;
+      guardian->foe[1]->visible_dead = TRUE;
+      guardian->foe[1]->dead_color_index = 0;
+      guardian->foe[1]->invincible = 20;
+      guardian->foe[1]->spr.energy_level = 0;
     }
 }
 
@@ -1715,7 +1754,7 @@ enemy_check_chained_list (void)
 {
   Uint32 i;
   enemy *foe;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < MAX_OF_ENEMIES; i++)
     {
       foe = &enemies[i];
@@ -1726,9 +1765,8 @@ enemy_check_chained_list (void)
     }
   if (count != num_of_enemies)
     {
-      fprintf (stderr, "(!)enemies.c/enemy_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, num_of_enemies=%i\n", count, num_of_enemies);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, num_of_enemies=%i", count, num_of_enemies);
     }
   count = 0;
   foe = enemy_first;
@@ -1740,9 +1778,8 @@ enemy_check_chained_list (void)
   while (foe != NULL && count <= (MAX_OF_ENEMIES + 1));
   if (count != num_of_enemies)
     {
-      fprintf (stderr, "(!)enemies.c/enemy_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_enemies=%i\n", count, num_of_enemies);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_enemies=%i", count, num_of_enemies);
     }
   count = 0;
   foe = enemy_last;
@@ -1754,9 +1791,8 @@ enemy_check_chained_list (void)
   while (foe != NULL && count <= (MAX_OF_ENEMIES + 1));
   if (count != num_of_enemies)
     {
-      fprintf (stderr, "(!)enemies.c/enemy_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_enemies=%i\n", count, num_of_enemies);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_enemies=%i", count, num_of_enemies);
     }
 }
 #endif
@@ -1797,8 +1833,7 @@ enemy_get (void)
 #endif
       return foe;
     }
-  fprintf (stderr, "(!)enemies.c/enemy_get() "
-           "no more element enemy is available\n");
+  LOG_ERR ("no more element enemy is available");
   return NULL;
 }
 
@@ -1915,8 +1950,7 @@ enemy_satellites_collisions (enemy * foe)
     }
   explosions_add_serie (foe);
   explosions_fragments_add (spr->xcoord +
-                            spr->
-                            img[spr->current_image]->x_gc - 8,
+                            spr->img[spr->current_image]->x_gc - 8,
                             spr->ycoord +
                             spr->img[spr->current_image]->y_gc - 8, 0.5, 8, 0,
                             3);
