@@ -3,11 +3,11 @@
  * @brief Handle displaying of the energy gauge the top score panel
  *        for the player's spaceship and the current guardian
  * @created 2007-01-06
- * @date 2007-06-01
+ * @date 2012-08-25
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: energy_gauge.h,v 1.5 2007/07/09 20:21:36 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: energy_gauge.h,v 1.11 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,15 +31,17 @@ extern "C"
 #endif
 #ifndef __ENERGY_GAUGE__
 #define __ENERGY_GAUGE__
-bool energy_gauge_once_init (void);
-void energy_gauge_free (void);
-void energy_gauge_init (void);
-void energy_gauge_spaceship_update (void);
-void energy_gauge_guardian_update (void);
-extern bool energy_gauge_spaceship_is_update;
-extern bool energy_gauge_guard_is_update;
+  bool energy_gauge_once_init (void);
+#ifdef PNG_EXPORT_ENABLE
+  bool energy_gauge_extract ();
+#endif
+  void energy_gauge_free (void);
+  void energy_gauge_init (void);
+  void energy_gauge_spaceship_update (void);
+  void energy_gauge_guardian_update (void);
+  extern bool energy_gauge_spaceship_is_update;
+  extern bool energy_gauge_guard_is_update;
 #ifdef __cplusplus
 }
 #endif
 #endif
-
