@@ -1,13 +1,13 @@
 /** 
  * @file explosions.c
  * @brief Handle explosions and explosion fragments 
- * @date 2007-09-02
+ * @date 2014-09-18
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: explosions.c,v 1.16 2007/09/02 16:13:56 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: explosions.c,v 1.28 2012/06/03 17:06:15 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,12 +24,13 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
 #include "display.h"
 #include "electrical_shock.h"
+#include "log_recorder.h"
 #include "enemies.h"
 #include "explosions.h"
 #include "shots.h"
@@ -112,8 +113,7 @@ explosions_once_init (void)
                                                 sizeof (explosion_struct));
       if (explosions == NULL)
         {
-          fprintf (stderr, "(!)explosions.c/explosions_once_init() "
-                   "not enough memory to allocate 'explosions'\n");
+          LOG_ERR ("not enough memory to allocate 'explosions'");
           return FALSE;
         }
     }
@@ -125,6 +125,73 @@ explosions_once_init (void)
   return TRUE;
 }
 
+/**
+ * Convert explosions from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+explosions_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/explosions/explosion/explosion-%01d.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/explosions"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < EXPLOSIONS_NUMOF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/explosions/explosion-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < EXPLOSIONS_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/explosions/explosion-%01d/explosion-%01d.png",
+                   type + 1, frame);
+          if (!image_to_png (&explo[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  for (type = 0; type < FRAGMENTS_NUMOF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/explosions/fragment-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < FRAGMENTS_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/explosions/fragment-%01d/fragment-%01d.png",
+                   type + 1, frame);
+          if (!image_to_png (&eclat[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /** 
  * Release memory used for the explosions 
  */
@@ -160,8 +227,7 @@ explosions_handle ()
 #ifdef UNDER_DEVELOPMENT
       if (blast == NULL && i < (num_of_explosions - 1))
         {
-          fprintf (stderr, "(!)explosions.c/explosions_handle(): "
-                   "blast->next is null %i/%i\n", i, num_of_explosions);
+          LOG_ERR ("blast->next is null %i/%i", i, num_of_explosions);
           break;
         }
 #endif
@@ -203,7 +269,12 @@ explosions_handle ()
                /* explosion move to the right out of the screen? */
                (((Sint16) blast->xcoord +
                  blast->img[blast->current_image]->w) >=
-                (offscreen_width - 1)))
+                (offscreen_width - 1)) ||
+               (((Sint16) blast->xcoord +
+                 blast->img[blast->current_image]->w - 1) < offscreen_startx)
+               ||
+               (((Sint16) blast->ycoord +
+                 blast->img[blast->current_image]->h - 1) < offscreen_starty))
             {
               /* remove a explosion or star element from list */
               explosion_del (blast);
@@ -402,7 +473,7 @@ explosions_fragments_add (float coordx, float coordy, float speed,
       blast->ycoord = coordy;
       /* set speed of the displacement */
       blast->speed = speed;
-      blast->img_angle = rand () % 32;
+      blast->img_angle = (Sint16) (rand () % 32);
       /* delay before begin explosion animation */
       blast->countdown = delay;
     }
@@ -417,7 +488,7 @@ explosion_check_chained_list (void)
 {
   Uint32 i;
   explosion_struct *blast;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < MAX_OF_EXPLOSIONS; i++)
     {
       blast = &explosions[i];
@@ -428,9 +499,8 @@ explosion_check_chained_list (void)
     }
   if (count != num_of_explosions)
     {
-      fprintf (stderr, "(!)shots.c/explosion_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, num_of_explosions=%i\n", count, num_of_explosions);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, num_of_explosions=%i", count, num_of_explosions);
     }
   count = 0;
   blast = explosion_first;
@@ -442,9 +512,8 @@ explosion_check_chained_list (void)
   while (blast != NULL && count <= (MAX_OF_EXPLOSIONS + 1));
   if (count != num_of_explosions)
     {
-      fprintf (stderr, "(!)shots.c/explosion_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_explosions=%i\n", count, num_of_explosions);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_explosions=%i", count, num_of_explosions);
     }
   count = 0;
   blast = explosion_last;
@@ -456,9 +525,8 @@ explosion_check_chained_list (void)
   while (blast != NULL && count <= (MAX_OF_EXPLOSIONS + 1));
   if (count != num_of_explosions)
     {
-      fprintf (stderr, "(!)shots.c/explosion_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_explosions=%i\n", count, num_of_explosions);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_explosions=%i", count, num_of_explosions);
     }
 }
 #endif
@@ -500,8 +568,7 @@ explosion_get (void)
       return blast;
     }
 #ifdef UNDER_DEVELOPMENT
-  fprintf (stderr, "(!)explosions.c/explosion_get() "
-           "no more element explosion is available\n");
+  LOG_ERR ("no more element explosion is available");
 #endif
   return NULL;
 }
@@ -540,7 +607,7 @@ explosion_del (explosion_struct * blast)
 void
 explosions_add_serie (enemy * foe)
 {
-  Uint32 type_of_vessel;
+  Sint32 type_of_vessel;
   Uint32 coordx, coordy, width, height;
   Sint32 height_big, height_normal, height_small, width_big, width_normal,
     width_small;
@@ -616,111 +683,114 @@ explosions_add_serie (enemy * foe)
        * player's spaceship 
        */
     case -1:
-      explosion_add (coordx, coordy, 0.3f, EXPLOSION_BIG, 0);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
+      explosion_add ((float) coordx, (float) coordy, 0.3f, EXPLOSION_BIG, 0);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)), 0.3f,
                      EXPLOSION_MEDIUM, 20);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 30);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 40);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 50);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     30);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     40);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     50);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     60);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     70);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     80);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 30);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 40);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 50);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 30);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 40);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 50);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 60);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 70);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 80);
       break;
       /* enemy is lower than 32 width and height pixels */
     case 0:
-      explosion_add (coordx, coordy, 0.3f, EXPLOSION_BIG, 0);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 10);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 20);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     30);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     40);
+      explosion_add ((float) coordx, (float) coordy, 0.3f, EXPLOSION_BIG, 0);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 10);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 20);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 30);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 40);
       break;
       /* enemy is higher than 32 width pixels */
     case 2:
-      explosion_add (coordx + (rand () % width_big), coordy, 0.3f,
-                     EXPLOSION_BIG, 0);
-      explosion_add (coordx + (rand () % width_big), coordy, 0.3f,
-                     EXPLOSION_BIG, 10);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 20);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 30);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     40);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     50);
+      explosion_add ((float) (coordx + (rand () % width_big)),
+                     (float) coordy, 0.3f, EXPLOSION_BIG, 0);
+      explosion_add ((float) coordx + (rand () % width_big),
+                     (float) coordy, 0.3f, EXPLOSION_BIG, 10);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 20);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 30);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 40);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 50);
       break;
       /* enemy is higher than 32 height pixels */
     case 4:
-      explosion_add (coordx, coordy + (rand () % height_big), 0.3f,
-                     EXPLOSION_BIG, 0);
-      explosion_add (coordx, coordy + (rand () % height_big), 0.3f,
-                     EXPLOSION_BIG, 10);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 20);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 30);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     40);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     50);
+      explosion_add ((float) coordx,
+                     (float) (coordy + (rand () % height_big)),
+                     0.3f, EXPLOSION_BIG, 0);
+      explosion_add ((float) coordx,
+                     (float) coordy + (rand () % height_big),
+                     0.3f, EXPLOSION_BIG, 10);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 20);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 30);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 40);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 50);
       break;
       /* enemy is higher than 32 width and height pixels */
     case 6:
-      explosion_add (coordx + (rand () % width_big),
-                     coordy + (rand () % height_big), 0.3f, EXPLOSION_BIG, 0);
-      explosion_add (coordx + (rand () % width_big),
-                     coordy + (rand () % height_big), 0.3f, EXPLOSION_BIG,
-                     10);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 20);
-      explosion_add (coordx + (rand () % width_normal),
-                     coordy + (rand () % height_normal), 0.3f,
-                     EXPLOSION_MEDIUM, 30);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     40);
-      explosion_add (coordx + (rand () % width_small),
-                     coordy + (rand () % height_small), 0.3f, EXPLOSION_SMALL,
-                     50);
+      explosion_add ((float) (coordx + (rand () % width_big)),
+                     (float) (coordy + (rand () % height_big)),
+                     0.3f, EXPLOSION_BIG, 0);
+      explosion_add ((float) (coordx + (rand () % width_big)),
+                     (float) (coordy + (rand () % height_big)),
+                     0.3f, EXPLOSION_BIG, 10);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 20);
+      explosion_add ((float) (coordx + (rand () % width_normal)),
+                     (float) (coordy + (rand () % height_normal)),
+                     0.3f, EXPLOSION_MEDIUM, 30);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 40);
+      explosion_add ((float) (coordx + (rand () % width_small)),
+                     (float) (coordy + (rand () % height_small)),
+                     0.3f, EXPLOSION_SMALL, 50);
       break;
     }
 }
