@@ -2,13 +2,13 @@
  * @file extra_gun.c 
  * @brief Handle extra guns positioned on the sides of the spaceship
  * @created 2006-11-25 
- * @date 2007-08-19
+ * @date 2012-08-25 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: extra_gun.c,v 1.15 2007/08/24 07:55:16 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: extra_gun.c,v 1.26 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -35,6 +35,7 @@
 #include "electrical_shock.h"
 #include "energy_gauge.h"
 #include "explosions.h"
+#include "log_recorder.h"
 #include "shots.h"
 #include "extra_gun.h"
 #include "gfx_wrapper.h"
@@ -124,8 +125,7 @@ guns_once_init (void)
         (gun_struct *) memory_allocation (GUNS_MAXOF * sizeof (gun_struct));
       if (extra_guns == NULL)
         {
-          fprintf (stderr, "(!)extra_gun.c/guns_once_init(): "
-                   "not enough memory to allocate 'gun_struct'\n");
+          LOG_ERR ("not enough memory to allocate 'gun_struct'");
           return FALSE;
         }
     }
@@ -134,6 +134,53 @@ guns_once_init (void)
   return TRUE;
 }
 
+/**
+ * Convert extra guns from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+guns_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/extra-guns/extra-gun-x/extra-gun-xx.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/extra-guns"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < GUNS_NUMOF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/extra-guns/extra-gun-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < GUNS_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/extra-guns/extra-gun-%01d/extra-gun-%02d.png",
+                   type + 1, frame);
+          if (!image_to_png (&guns_images[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /** 
  * Release memory of images and structures used for the etra guns
  */
@@ -190,8 +237,7 @@ guns_handle (void)
 #ifdef UNDER_DEVELOPMENT
       if (egun == NULL && i < (ship->num_of_extraguns - 1))
         {
-          fprintf (stderr, "(!)extra_gun.c/gun_handle(): "
-                   "egun->next is null %i/%i\n", i, ship->num_of_extraguns);
+          LOG_ERR ("egun->next is null %i/%i", i, ship->num_of_extraguns);
           break;
         }
 #endif
@@ -199,8 +245,8 @@ guns_handle (void)
 
       /* update vertical coordinate of the gun */
       egun->ycoord =
-        (Sint16) (ship->spr.ycoord) + ship->spr.img[ship->spr.current_image]->h -
-        egun_img->h;
+        (Sint16) (ship->spr.ycoord) +
+        ship->spr.img[ship->spr.current_image]->h - egun_img->h;
 
       /* update horizontal coordinate of the right gun */
       if (egun->position == 0)
@@ -291,7 +337,7 @@ guns_handle (void)
                                  bullet->spr.img[bullet->img_angle]->y_gc);
                       bullet->timelife = 400;
                       /* set angle of the projectile */
-                      bullet->angle = PI_SUR_16 * bullet->img_angle;
+                      bullet->angle = PI_BY_16 * bullet->img_angle;
                       /* set speed of the displacement */
                       bullet->spr.speed = 9.0;
                     }
@@ -421,7 +467,7 @@ gun_check_chained_list (void)
   Uint32 i;
   gun_struct *egun;
   spaceship_struct *ship = spaceship_get ();
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < GUNS_MAXOF; i++)
     {
       egun = &extra_guns[i];
@@ -432,10 +478,9 @@ gun_check_chained_list (void)
     }
   if (count != ship->num_of_extraguns)
     {
-      fprintf (stderr, "(!)extra_gun.c/"
-               "gun_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, =%i\n", count, ship->num_of_extraguns);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, ship->num_of_extraguns=%i",
+               count, ship->num_of_extraguns);
     }
   count = 0;
   egun = gun_first;
@@ -447,10 +492,8 @@ gun_check_chained_list (void)
   while (egun != NULL && count <= (GUNS_MAXOF + 1));
   if (count != ship->num_of_extraguns)
     {
-      fprintf (stderr, "(!)extra_gun.c/"
-               "gun_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, ship->num_of_extraguns=%i\n", count,
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, ship->num_of_extraguns=%i", count,
                ship->num_of_extraguns);
     }
   count = 0;
@@ -463,10 +506,8 @@ gun_check_chained_list (void)
   while (egun != NULL && count <= (GUNS_MAXOF + 1));
   if (count != ship->num_of_extraguns)
     {
-      fprintf (stderr, "(!)extra_gun.c/"
-               "gun_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, ship->num_of_extraguns=%i\n", count,
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, ship->num_of_extraguns=%i", count,
                ship->num_of_extraguns);
     }
 }
@@ -509,8 +550,7 @@ gun_get (void)
 #endif
       return egun;
     }
-  fprintf (stderr, "(!)extra_gun.c/gun_get() "
-           "no more element gun is available\n");
+  LOG_ERR ("no more element gun is available");
   return NULL;
 }
 
@@ -565,8 +605,7 @@ guns_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
 #ifdef UNDER_DEVELOPMENT
       if (egun == NULL && i < (ship->num_of_extraguns - 1))
         {
-          fprintf (stderr, "(!)extra_gun.c/guns_enemy_collisions(): "
-                   "egun->next is null %i/%i\n", i, ship->num_of_extraguns);
+          LOG_ERR ("egun->next is null %i/%i", i, ship->num_of_extraguns);
           break;
         }
 #endif
@@ -575,7 +614,8 @@ guns_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
         {
           continue;
         }
-      for (l = 0; l < egun->img[egun->current_image]->numof_collisions_points; l++)
+      for (l = 0; l < egun->img[egun->current_image]->numof_collisions_points;
+           l++)
         {
           /* coordinates of the collision point of the gun */
           x1 =
@@ -585,33 +625,42 @@ guns_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
             egun->ycoord +
             egun->img[egun->current_image]->collisions_points[l][YCOORD];
           /* for each collision zone of the enemy */
-          for (m = 0; m < foe->spr.img[foe->spr.current_image]->numof_collisions_zones; m++)
+          for (m = 0;
+               m <
+               foe->spr.img[foe->spr.current_image]->numof_collisions_zones;
+               m++)
             {
               /* coordinates of the collision zone of the enemy */
               x2 =
                 (Sint32) foe->spr.xcoord +
-                foe->spr.img[foe->spr.current_image]->collisions_coords[m][XCOORD];
+                foe->spr.img[foe->spr.current_image]->
+                collisions_coords[m][XCOORD];
               y2 =
                 (Sint32) foe->spr.ycoord +
-                foe->spr.img[foe->spr.current_image]->collisions_coords[m][YCOORD];
+                foe->spr.img[foe->spr.current_image]->
+                collisions_coords[m][YCOORD];
               /* check if gun collision point is into enemy collision zone */
               if (x1 >= x2 && y1 >= y2
                   && x1 <
                   (x2 +
-                   foe->spr.img[foe->spr.current_image]->collisions_sizes[m][IMAGE_WIDTH])
+                   foe->spr.img[foe->spr.current_image]->collisions_sizes[m]
+                   [IMAGE_WIDTH])
                   && y1 <
                   (y2 +
-                   foe->spr.img[foe->spr.current_image]->
-                   collisions_sizes[m][IMAGE_HEIGHT]))
+                   foe->spr.img[foe->spr.
+                                current_image]->collisions_sizes[m]
+                   [IMAGE_HEIGHT]))
                 {
                   /* decrease energy level of enemy */
-                  foe->spr.energy_level -= egun->pow_of_dest;
+                  foe->spr.energy_level =
+                    (Sint16) (foe->spr.energy_level - egun->pow_of_dest);
                   if (foe->type >= THANIKEE)
                     {
                       energy_gauge_guard_is_update = TRUE;
                     }
                   /* decrease energy level of gun */
-                  egun->energy_level -= foe->spr.pow_of_dest;
+                  egun->energy_level =
+                    (Sint16) (egun->energy_level - foe->spr.pow_of_dest);
                   /* check if gun is destroyed */
                   if (egun->energy_level <= 0)
                     {
@@ -636,11 +685,13 @@ guns_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
                           if (num_of_fragments > 0)
                             {
                               explosions_fragments_add (foe->spr.xcoord +
-                                                        foe->spr.img[foe->spr.current_image]->
-                                                        x_gc - 8,
+                                                        foe->spr.img[foe->spr.
+                                                                     current_image]->x_gc
+                                                        - 8,
                                                         foe->spr.ycoord +
-                                                        foe->spr.img[foe->spr.current_image]->
-                                                        y_gc - 8, 1.0,
+                                                        foe->spr.img[foe->spr.
+                                                                     current_image]->y_gc
+                                                        - 8, 1.0,
                                                         num_of_fragments, 0,
                                                         2);
                             }
@@ -695,8 +746,7 @@ guns_shot_collisions (Sint32 x1, Sint32 y1, shot_struct * bullet)
 #ifdef UNDER_DEVELOPMENT
       if (egun == NULL && i < (ship->num_of_extraguns - 1))
         {
-          fprintf (stderr, "(!)extra_gun.c/guns_shot_collisions(): "
-                   "egun->next is null %i/%i\n", i, ship->num_of_extraguns);
+          LOG_ERR ("egun->next is null %i/%i", i, ship->num_of_extraguns);
           break;
         }
 #endif
@@ -706,7 +756,8 @@ guns_shot_collisions (Sint32 x1, Sint32 y1, shot_struct * bullet)
           continue;
         }
       /* for each collision zone of the gun */
-      for (j = 0; j < egun->img[egun->current_image]->numof_collisions_zones; j++)
+      for (j = 0; j < egun->img[egun->current_image]->numof_collisions_zones;
+           j++)
         {
           /* coordinates of the collision zone of the gun */
           x2 =
@@ -720,13 +771,16 @@ guns_shot_collisions (Sint32 x1, Sint32 y1, shot_struct * bullet)
               y1 >= y2 &&
               x1 <
               (x2 +
-               egun->img[egun->current_image]->collisions_sizes[j][IMAGE_WIDTH])
+               egun->img[egun->current_image]->
+               collisions_sizes[j][IMAGE_WIDTH])
               && y1 <
               (y2 +
-               egun->img[egun->current_image]->collisions_sizes[j][IMAGE_HEIGHT]))
+               egun->img[egun->current_image]->
+               collisions_sizes[j][IMAGE_HEIGHT]))
             {
               /* decrease energy level of gun */
-              egun->energy_level -= bullet->spr.pow_of_dest;
+              egun->energy_level =
+                (Sint16) (egun->energy_level - bullet->spr.pow_of_dest);
               /* check if gun is destroyed */
               if (egun->energy_level <= 0)
                 {
