@@ -2,13 +2,13 @@
  * @file guardians.c 
  * @brief handle the guardians 
  * @created 1998-04-21
- * @date 2007-08-30
+ * @date 2012-08-25 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /*
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: guardians.c,v 1.49 2007/08/31 20:46:43 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: guardians.c,v 1.63 2012/08/25 19:18:32 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -44,6 +44,7 @@
 #include "grid_phase.h"
 #include "guardians.h"
 #include "images.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "menu_sections.h"
 #include "meteors_phase.h"
@@ -74,8 +75,7 @@ guardians_once_init (void)
         (guardian_struct *) memory_allocation (sizeof (guardian_struct));
       if (guardian == NULL)
         {
-          fprintf (stderr, "(!)guardians.c/guardians_once_init():"
-                   "not enough memory to allocate 'guardian_struct'!\n");
+          LOG_ERR ("not enough memory to allocate 'guardian_struct'!");
           return FALSE;
         }
     }
@@ -131,8 +131,8 @@ guardians_free (void)
  * @param speed Speed of the sprite
  */
 static enemy *
-guardian_init (Uint32 index, Uint32 type, Sint32 current_image,
-               Uint32 energy_level, Uint32 anim_speed, Uint32 fire_rate,
+guardian_init (Uint32 index, Uint32 type, Sint16 current_image,
+               Uint32 energy_level, Sint16 anim_speed, Uint32 fire_rate,
                float speed)
 {
   Sint32 i;
@@ -145,7 +145,8 @@ guardian_init (Uint32 index, Uint32 type, Sint32 current_image,
     }
   guard->spr.pow_of_dest = (Sint16) ((ship->type << 1) + type);
   guard->spr.energy_level =
-    (ship->type << 2) + (guard->spr.pow_of_dest << 3) / 3 + energy_level;
+    (Sint16) ((ship->type << 2) + (guard->spr.pow_of_dest << 3) / 3 +
+              energy_level);
   guard->spr.max_energy_level = guard->spr.energy_level;
   guard->spr.numof_images = 32;
   guard->spr.current_image = current_image;
@@ -162,7 +163,7 @@ guardian_init (Uint32 index, Uint32 type, Sint32 current_image,
   guard->type = type;
   guard->dead = FALSE;
   guard->visible = TRUE;
-  guardian->enemy[index] = guard;
+  guardian->foe[index] = guard;
   return guard;
 }
 
@@ -265,10 +266,12 @@ guardian_02_init (void)
   guardian_set_direction_toward_bottom ();
   guardian_set_direction_toward_top ();
   guardian_set_direction_toward_right ();
-  guardian->x_min = offscreen_clipsize - 10;
-  guardian->x_max = offscreen_clipsize + offscreen_width_visible + 40;
-  guardian->y_min = offscreen_clipsize - 15;
-  guardian->y_max = offscreen_clipsize + offscreen_height_visible + 40;
+  guardian->x_min = (float) (offscreen_clipsize - 10);
+  guardian->x_max
+    = (float) (offscreen_clipsize + offscreen_width_visible + 40);
+  guardian->y_min = (float) (offscreen_clipsize - 15);
+  guardian->y_max
+    = (float) (offscreen_clipsize + offscreen_height_visible + 40);
   return TRUE;
 }
 
@@ -377,8 +380,8 @@ guardian_06_init (void)
     {
       return FALSE;
     }
-  guard->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-  guard->spr.ycoord = guardian->enemy[0]->spr.ycoord + 63;
+  guard->spr.xcoord = guardian->foe[0]->spr.xcoord;
+  guard->spr.ycoord = guardian->foe[0]->spr.ycoord + 63;
   guard->spr.energy_level = (guard->spr.pow_of_dest << 3) / 3;
   guard->spr.max_energy_level = guard->spr.energy_level;
   guardian_set_direction_toward_right ();
@@ -465,8 +468,8 @@ guardian_09_init (void)
     }
   guard->spr.energy_level = (guard->spr.pow_of_dest * 3) / 2;
   guard->spr.max_energy_level = guard->spr.energy_level;
-  guard->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-  guard->spr.ycoord = guardian->enemy[0]->spr.ycoord;
+  guard->spr.xcoord = guardian->foe[0]->spr.xcoord;
+  guard->spr.ycoord = guardian->foe[0]->spr.ycoord;
   guardian_set_direction_toward_right ();
   guardian_set_direction_toward_left ();
   guardian->lonely_foe_delay = 0;
@@ -497,8 +500,8 @@ guardian_10_init (void)
     {
       return FALSE;
     }
-  guard->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-  guard->spr.ycoord = guardian->enemy[0]->spr.ycoord;
+  guard->spr.xcoord = guardian->foe[0]->spr.xcoord;
+  guard->spr.ycoord = guardian->foe[0]->spr.ycoord;
   guardian->move_current = GUARD_MOVEMENT_TOWARD_BOTTOM;
   guardian->lonely_foe_delay = 0;
   if (num_of_enemies < (MAX_OF_ENEMIES - 2))
@@ -561,8 +564,9 @@ guardian_12_init (void)
   guardian_add_move (GUARD_MOVEMENT_TOWARD_RIGHT, 50, 2);
   guardian_add_move (GUARD_IMMOBILE, 50, 0);
   guardian_add_move (GUARD_MOVEMENT_TOWARD_LEFT, 50, 2);
-  guardian->y_min = offscreen_clipsize;
-  guardian->y_max = offscreen_clipsize + offscreen_height_visible + 30;
+  guardian->y_min = (float) (offscreen_clipsize);
+  guardian->y_max
+    = (float) (offscreen_clipsize + offscreen_height_visible + 30);
   return TRUE;
 }
 
@@ -587,10 +591,11 @@ guardian_13_init (void)
   guardian_add_move (GUARD_MOVEMENT_TOWARD_RIGHT, 400, 3);
   guardian_add_move (GUARD_IMMOBILE, 10, 0);
   guardian_add_move (GUARD_MOVEMENT_TOWARD_LEFT, 400, 3);
-  guardian->x_min = offscreen_clipsize - 20;
-  guardian->x_max = offscreen_clipsize + offscreen_width_visible + 20;
-  guardian->y_min = offscreen_clipsize;
-  guardian->y_max = offscreen_clipsize + offscreen_height_visible;
+  guardian->x_min = (float) (offscreen_clipsize - 20);
+  guardian->x_max
+    = (float) (offscreen_clipsize + offscreen_width_visible + 20);
+  guardian->y_min = (float) (offscreen_clipsize);
+  guardian->y_max = (float) (offscreen_clipsize + offscreen_height_visible);
   return TRUE;
 }
 
@@ -612,8 +617,9 @@ guardian_14_init (void)
   guard->spr.ycoord = (float) (offscreen_starty - guard->spr.img[15]->h);
   guardian_add_move (GUARD_MOVEMENT_TOWARD_RIGHT, 400, 2);
   guardian_add_move (GUARD_MOVEMENT_TOWARD_LEFT, 400, 2);
-  guardian->x_min = offscreen_clipsize + 10;
-  guardian->x_max = offscreen_clipsize + offscreen_width_visible - 10;
+  guardian->x_min = (float) (offscreen_clipsize + 10);
+  guardian->x_max
+    = (float) (offscreen_clipsize + offscreen_width_visible - 10);
   guardian->perturbians_delay = 0;
   guardian->saakamin_delay = 0;
   return TRUE;
@@ -638,10 +644,10 @@ guardian_new (Uint32 guardian_num)
   guardian->current_images_set = 0;
   guardian->move_current = 0;
   guardian->move_max = 0;
-  guardian->x_min = offscreen_clipsize;
-  guardian->x_max = offscreen_clipsize + offscreen_width_visible;
-  guardian->y_min = offscreen_clipsize;
-  guardian->y_max = offscreen_clipsize + offscreen_height_visible;
+  guardian->x_min = (float) offscreen_clipsize;
+  guardian->x_max = (float) (offscreen_clipsize + offscreen_width_visible);
+  guardian->y_min = (float) offscreen_clipsize;
+  guardian->y_max = (float) (offscreen_clipsize + offscreen_height_visible);
   guardian->y_inc = 0;
   switch (guardian_num)
     {
@@ -726,9 +732,10 @@ guardian_appears_from_top (enemy * guard)
  * @return Number of bullets fired
  */
 static Uint32
-guardian_fire (enemy * guard, Sint32 power, float speed)
+guardian_fire (enemy * guard, Sint16 power, float speed)
 {
-  Uint32 cannon_num, numof_bullets;
+  Sint32 cannon_num;
+  Uint32 numof_bullets;
   if (player_pause || menu_status != MENU_OFF
       || menu_section != NO_SECTION_SELECTED)
     {
@@ -763,10 +770,10 @@ guardian_fire (enemy * guard, Sint32 power, float speed)
  * @return Pointer to the new enemy element
  */
 static enemy *
-guardian_add_missile (Uint32 type, Uint32 current_image, Sint32 img_angle,
+guardian_add_missile (Uint32 type, Sint16 current_image, Sint16 img_angle,
                       float angle_tir)
 {
-  Uint32 i;
+  Sint32 i;
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
   foe = enemy_get ();
@@ -807,10 +814,10 @@ guardian_add_missile (Uint32 type, Uint32 current_image, Sint32 img_angle,
  * @return TRUE if at least one missile was added or FALSE otherwise
  */
 static void
-guardian_add_missiles (enemy * guard, Uint32 inc, Uint32 max_counter,
+guardian_add_missiles (enemy * guard, Uint32 inc, Sint32 max_counter,
                        Uint32 numof_miss)
 {
-  Sint32 img_angle;
+  Sint16 img_angle;
   float angle_tir;
   Uint32 i;
   enemy *foe;
@@ -874,11 +881,11 @@ guardian_add_missiles (enemy * guard, Uint32 inc, Uint32 max_counter,
  * @return Pointer to the new enemy element
  */
 static enemy *
-guardian_add_foe (Uint32 type, Uint32 pow_of_des, Uint32 energy_level,
-                  Uint32 current_image, Uint32 anim_speed, Uint32 fire_rate,
+guardian_add_foe (Uint32 type, Sint16 pow_of_des, Sint16 energy_level,
+                  Sint16 current_image, Sint16 anim_speed, Uint32 fire_rate,
                   float speed)
 {
-  Uint32 i;
+  Sint32 i;
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
   foe = enemy_get ();
@@ -886,7 +893,7 @@ guardian_add_foe (Uint32 type, Uint32 pow_of_des, Uint32 energy_level,
     {
       return NULL;
     }
-  foe->spr.pow_of_dest = (ship->type << 1) + pow_of_des;
+  foe->spr.pow_of_dest = (Sint16) ((ship->type << 1) + pow_of_des);
   foe->spr.energy_level = energy_level;
   foe->spr.numof_images = 32;
   foe->spr.current_image = current_image;
@@ -912,7 +919,7 @@ guardian_add_foe (Uint32 type, Uint32 pow_of_des, Uint32 energy_level,
  * @param foe_num Foe number of -1 if foe is automatically selected  
  */
 static void
-guardian_add_lonely_foe (Uint32 max_counter, Sint32 foe_num)
+guardian_add_lonely_foe (Sint32 max_counter, Sint32 foe_num)
 {
   guardian->lonely_foe_delay++;
   if (guardian->lonely_foe_delay < max_counter)
@@ -933,7 +940,7 @@ guardian_add_lonely_foe (Uint32 max_counter, Sint32 foe_num)
  * @param max_counter Delay before send a Soukee 
  */
 static void
-guardian_add_soukee (enemy * guard, Uint32 inc, Uint32 max_counter)
+guardian_add_soukee (enemy * guard, Sint32 inc, Sint32 max_counter)
 {
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
@@ -958,7 +965,7 @@ guardian_add_soukee (enemy * guard, Uint32 inc, Uint32 max_counter)
         guard->spr.ycoord + guard->spr.img[guard->spr.current_image]->y_gc -
         foe->spr.img[0]->h / 2;
       foe->img_angle = 8;
-      foe->angle_tir = PI_SUR_2;
+      foe->angle_tir = HALF_PI;
       foe->img_old_angle = foe->img_angle;
       foe->agilite = 0.018f;
 #ifdef USE_SDLMIXER
@@ -973,7 +980,7 @@ guardian_add_soukee (enemy * guard, Uint32 inc, Uint32 max_counter)
  * @param max_counter Delay before send a Shuriky 
  */
 void
-guardian_add_shuriky (enemy * guard, Uint32 max_counter)
+guardian_add_shuriky (enemy * guard, Sint32 max_counter)
 {
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
@@ -1002,12 +1009,11 @@ guardian_add_shuriky (enemy * guard, Uint32 max_counter)
 
 /**
  * Add a Devilians foe to the enemies list
- * @param guard Pointer the main enemy structure of the guardian
  * @param max_counter Delay before send a Quibouly 
  * @param max_foes Number of foes launched before disable
  */
-void
-guardian_add_devilians (enemy * guard, Uint32 max_counter, Uint32 max_foes)
+static void
+guardian_add_devilians (Sint32 max_counter, Sint32 max_foes)
 {
   if (!guardian->devilians_enable)
     {
@@ -1034,7 +1040,7 @@ guardian_add_devilians (enemy * guard, Uint32 max_counter, Uint32 max_foes)
  * @param max_counter Delay before send a Quibouly 
  */
 void
-guardian_add_quibouly (enemy * guard, Uint32 max_counter)
+guardian_add_quibouly (enemy * guard, Sint32 max_counter)
 {
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
@@ -1062,11 +1068,10 @@ guardian_add_quibouly (enemy * guard, Uint32 max_counter)
 
 /**
  * Add a Shuriky foe to the enemies list
- * @param guard Pointer the main enemy structure of the guardian
  * @param max_counter Delay before send a Shuriky 
  */
-void
-guardian_add_tournadee (enemy * guard, Uint32 max_counter)
+static void
+guardian_add_tournadee (Sint32 max_counter)
 {
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
@@ -1086,7 +1091,7 @@ guardian_add_tournadee (enemy * guard, Uint32 max_counter)
   if (guardian->is_tournadee_left_pos)
     {
       guardian->is_tournadee_left_pos = FALSE;
-      foe->spr.xcoord = offscreen_startx - 2;
+      foe->spr.xcoord = (float) (offscreen_startx - 2);
     }
   else
     {
@@ -1095,7 +1100,8 @@ guardian_add_tournadee (enemy * guard, Uint32 max_counter)
         (float) (offscreen_startx + offscreen_width_visible -
                  foe->spr.img[0]->w + 2);
     }
-  foe->spr.ycoord = offscreen_starty + 32 + offscreen_height_visible;
+  foe->spr.ycoord
+    = (float) (offscreen_starty + 32 + offscreen_height_visible);
 #ifdef USE_SDLMIXER
   sound_play (SOUND_GUARDIAN_FIRE_2);
 #endif
@@ -1103,14 +1109,12 @@ guardian_add_tournadee (enemy * guard, Uint32 max_counter)
 
 /**
  * Add a Sapouch foe to the enemies list
- * @param guard Pointer the main enemy structure of the guardian
  * @param numof Number of Sapouch launched 1 or 2
  * @param max_counter Delay before send a Sapouch 
  * @param is_left TRUE if first Sapouch will be launched on left side
  */
 static void
-guardian_add_sapouch (enemy * guard, Uint32 numof, Uint32 max_counter,
-                      bool is_left)
+guardian_add_sapouch (Uint32 numof, Sint32 max_counter, bool is_left)
 {
   float ycoord, speed;
   Uint32 i;
@@ -1122,7 +1126,7 @@ guardian_add_sapouch (enemy * guard, Uint32 numof, Uint32 max_counter,
       return;
     }
   guardian->sapouch_delay = 0;
-  ycoord = offscreen_starty - 64;
+  ycoord = (float) (offscreen_starty - 64);
   speed = 2.5f + (float) (((long) rand () % (100))) / 100.0f;
   for (i = 0; i < numof; i++)
     {
@@ -1135,12 +1139,13 @@ guardian_add_sapouch (enemy * guard, Uint32 numof, Uint32 max_counter,
         }
       if (is_left)
         {
-          foe->spr.xcoord = offscreen_startx;
+          foe->spr.xcoord = (float) (offscreen_startx);
         }
       else
         {
           foe->spr.xcoord =
-            offscreen_startx + offscreen_width_visible - foe->spr.img[0]->w;
+            (float) (offscreen_startx +
+                     offscreen_width_visible - foe->spr.img[0]->w);
         }
       foe->spr.ycoord = ycoord - foe->spr.img[0]->h;
       foe->retournement = FALSE;
@@ -1160,8 +1165,7 @@ guardian_add_sapouch (enemy * guard, Uint32 numof, Uint32 max_counter,
  * @param is_left TRUE if first Perturbians will be launched on left side
  */
 static void
-guardian_add_perturbians (enemy * guard, Uint32 numof, Uint32 max_counter,
-                          bool is_left)
+guardian_add_perturbians (Uint32 numof, Sint32 max_counter, bool is_left)
 {
   Uint32 i, fire_rate, power;
   enemy *foe;
@@ -1178,8 +1182,8 @@ guardian_add_perturbians (enemy * guard, Uint32 numof, Uint32 max_counter,
     {
       foe =
         guardian_add_foe (PERTURBIANS,
-                          (Sint32) ((ship->type << 1) + PERTURBIANS - 40),
-                          (Sint32) ((ship->type << 2) + (power << 3) / 3 +
+                          (Sint16) ((ship->type << 1) + PERTURBIANS - 40),
+                          (Sint16) ((ship->type << 2) + (power << 3) / 3 +
                                     10), 0, 6, fire_rate, 0.2f);
       if (foe == NULL)
         {
@@ -1187,12 +1191,13 @@ guardian_add_perturbians (enemy * guard, Uint32 numof, Uint32 max_counter,
         }
       if (is_left)
         {
-          foe->spr.xcoord = offscreen_startx;
+          foe->spr.xcoord = (float) (offscreen_startx);
         }
       else
         {
           foe->spr.xcoord =
-            offscreen_startx + offscreen_width_visible - foe->spr.img[0]->w;
+            (float) (offscreen_startx + offscreen_width_visible
+                     - foe->spr.img[0]->w);
         }
       foe->spr.ycoord = (float) (offscreen_starty - 64 - foe->spr.img[0]->h);
 #ifdef USE_SDLMIXER
@@ -1208,7 +1213,7 @@ guardian_add_perturbians (enemy * guard, Uint32 numof, Uint32 max_counter,
  * @param max_counter Delay before send a Perturbians 
  */
 static void
-guardian_add_saakamin (enemy * guard, Uint32 max_counter, Uint32 numof)
+guardian_add_saakamin (enemy * guard, Sint32 max_counter, Uint32 numof)
 {
   enemy *foe;
   spaceship_struct *ship = spaceship_get ();
@@ -1227,7 +1232,7 @@ guardian_add_saakamin (enemy * guard, Uint32 max_counter, Uint32 numof)
         {
           return;
         }
-      foe->num_courbe = (Sint32) (((long) rand () % (121)));
+      foe->num_courbe = (Sint16) (rand () % 121);
       foe->pos_vaiss[POS_CURVE] = 0;
       foe->spr.xcoord =
         (guard->spr.xcoord +
@@ -1278,7 +1283,7 @@ guardian_get_next_trajectory (void)
  * @param reach Image number to reach
  */
 static void
-guardian_flip_image (enemy * guard, Sint32 delay, Sint32 reach)
+guardian_flip_image (enemy * guard, Uint32 delay, Sint32 reach)
 {
   guardian->anim_delay_count++;
   if (guardian->anim_delay_count < delay)
@@ -1309,8 +1314,8 @@ guardian_flip_image (enemy * guard, Sint32 delay, Sint32 reach)
  * @param first Image number of the first image 
  */
 static void
-guardian_loop_flip (enemy * guard, Sint32 delay, Sint32 inc, Sint32 limit,
-                    Sint32 first)
+guardian_loop_flip (enemy * guard, Uint32 delay, Sint16 inc, Sint32 limit,
+                    Sint16 first)
 {
   guardian->anim_delay_count++;
   if (guardian->anim_delay_count < delay)
@@ -1318,7 +1323,7 @@ guardian_loop_flip (enemy * guard, Sint32 delay, Sint32 inc, Sint32 limit,
       return;
     }
   guardian->anim_delay_count = 0;
-  guard->spr.current_image += inc;
+  guard->spr.current_image = (Sint16) (guard->spr.current_image + inc);
   if ((inc > 0 && guard->spr.current_image > limit)
       || (inc < 0 && guard->spr.current_image < limit))
     {
@@ -1334,7 +1339,7 @@ guardian_loop_flip (enemy * guard, Sint32 delay, Sint32 inc, Sint32 limit,
 static void
 guardian_change_images_set (enemy * guard, Uint32 images_num)
 {
-  Uint32 i;
+  Sint32 i;
   for (i = 0; i < guard->spr.numof_images; i++)
     {
       guard->spr.img[i] = (image *) & gardi[images_num][i];
@@ -1349,7 +1354,7 @@ guardian_change_images_set (enemy * guard, Uint32 images_num)
  * @param current Current image number
  */
 static void
-guardian_change_images (enemy * guard, Uint32 images_num, Uint32 current)
+guardian_change_images (enemy * guard, Uint32 images_num, Sint16 current)
 {
   guard->spr.current_image = current;
   guardian_change_images_set (guard, images_num);
@@ -1632,7 +1637,7 @@ guardian_04 (enemy * guard)
     }
   else
     {
-      guardian_add_devilians (guard, 141, 3);
+      guardian_add_devilians (141, 3);
       if (--guardian->move_time_delay > 0)
         {
           if (guardian->move_direction[guardian->move_current] ==
@@ -1809,18 +1814,17 @@ guardian_06 (enemy * guard)
   Uint32 numof_bullets;
   if (guardian->is_appearing)
     {
-      if (guard == guardian->enemy[0])
+      if (guard == guardian->foe[0])
         {
           guardian_appears_from_top (guard);
-          guardian->enemy[1]->spr.xcoord = guard->spr.xcoord;
-          guardian->enemy[1]->spr.ycoord = guard->spr.ycoord + 63;
+          guardian->foe[1]->spr.xcoord = guard->spr.xcoord;
+          guardian->foe[1]->spr.ycoord = guard->spr.ycoord + 63;
         }
     }
   else
     {
       if (!player_pause && menu_status == MENU_OFF
-          && guard == guardian->enemy[0]
-          && menu_section == NO_SECTION_SELECTED)
+          && guard == guardian->foe[0] && menu_section == NO_SECTION_SELECTED)
         {
           guardian->move_time_delay--;
           if (guardian->move_time_delay > 0)
@@ -1871,12 +1875,12 @@ guardian_06 (enemy * guard)
             }
         }
       /* articulated arm enable? */
-      if (guard == guardian->enemy[1]
+      if (guard == guardian->foe[1]
           && guard->displacement == DISPLACEMENT_GUARDIAN
           && guard->is_enabled)
         {
-          guard->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-          guard->spr.ycoord = guardian->enemy[0]->spr.ycoord + 63;
+          guard->spr.xcoord = guardian->foe[0]->spr.xcoord;
+          guard->spr.ycoord = guardian->foe[0]->spr.ycoord + 63;
           guard->spr.anim_count++;
           if (!(guard->spr.anim_count &= (guard->spr.anim_speed - 1)))
             {
@@ -1968,7 +1972,7 @@ guardian_08 (enemy * guard)
   if (guardian_fire (guard, 8, 2.0) > 0)
     {
       guardian_add_lonely_foe (40, -1);
-      guardian_add_tournadee (guard, 12);
+      guardian_add_tournadee (12);
     }
 }
 
@@ -1982,18 +1986,17 @@ guardian_09 (enemy * guard)
 {
   if (guardian->is_appearing)
     {
-      if (guard == guardian->enemy[0])
+      if (guard == guardian->foe[0])
         {
           guardian_appears_from_top (guard);
-          guardian->enemy[1]->spr.xcoord = guard->spr.xcoord;
-          guardian->enemy[1]->spr.ycoord = guard->spr.ycoord;
+          guardian->foe[1]->spr.xcoord = guard->spr.xcoord;
+          guardian->foe[1]->spr.ycoord = guard->spr.ycoord;
         }
     }
   else
     {
       if (!player_pause && menu_status == MENU_OFF
-          && guard == guardian->enemy[0]
-          && menu_section == NO_SECTION_SELECTED)
+          && guard == guardian->foe[0] && menu_section == NO_SECTION_SELECTED)
         {
           if (--guardian->move_time_delay > 0)
             {
@@ -2045,12 +2048,12 @@ guardian_09 (enemy * guard)
             }
         }
 
-      if (guard == guardian->enemy[1]
+      if (guard == guardian->foe[1]
           && guard->displacement == DISPLACEMENT_GUARDIAN
           && guard->is_enabled)
         {
-          guard->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-          guard->spr.ycoord = guardian->enemy[0]->spr.ycoord;
+          guard->spr.xcoord = guardian->foe[0]->spr.xcoord;
+          guard->spr.ycoord = guardian->foe[0]->spr.ycoord;
           guard->spr.anim_count++;
           if (!(guard->spr.anim_count &= (guard->spr.anim_speed - 1)))
             {
@@ -2076,22 +2079,21 @@ guardian_10 (enemy * guard)
   float angle;
   Uint32 i;
   Sint32 anim_count, length1, length2;
-  enemy *guard2 = guardian->enemy[1];
+  enemy *guard2 = guardian->foe[1];
   spaceship_struct *ship = spaceship_get ();
   if (guardian->is_appearing)
     {
-      if (guard == guardian->enemy[0])
+      if (guard == guardian->foe[0])
         {
           guardian_appears_from_top (guard);
-          guardian->enemy[1]->spr.xcoord = guard->spr.xcoord;
-          guardian->enemy[1]->spr.ycoord = guard->spr.ycoord;
+          guardian->foe[1]->spr.xcoord = guard->spr.xcoord;
+          guardian->foe[1]->spr.ycoord = guard->spr.ycoord;
         }
     }
   else
     {
       if (!player_pause && menu_status == MENU_OFF
-          && guard == guardian->enemy[0]
-          && menu_section == NO_SECTION_SELECTED)
+          && guard == guardian->foe[0] && menu_section == NO_SECTION_SELECTED)
         {
           if (guardian->move_current == GUARD_MOVEMENT_TOWARD_RIGHT)
             {
@@ -2143,7 +2145,7 @@ guardian_10 (enemy * guard)
             }
         }
 
-      if (guard == guardian->enemy[0])
+      if (guard == guardian->foe[0])
         {
           guard->spr.anim_count++;
           if (guard->spr.anim_count >= guard->spr.anim_speed)
@@ -2160,8 +2162,8 @@ guardian_10 (enemy * guard)
       /* check if second part of the guardian existing */
       if (guard2->displacement == DISPLACEMENT_GUARDIAN)
         {
-          guard2->spr.xcoord = guardian->enemy[0]->spr.xcoord;
-          guard2->spr.ycoord = guardian->enemy[0]->spr.ycoord;
+          guard2->spr.xcoord = guardian->foe[0]->spr.xcoord;
+          guard2->spr.ycoord = guardian->foe[0]->spr.ycoord;
           /* cannon rotation to follow the player's spaceship */
           if (guard2->img_angle != guard2->spr.current_image)
             {
@@ -2251,13 +2253,13 @@ guardian_10 (enemy * guard)
                                          ship->spr.img[ship->spr.
                                                        current_image]->y_gc));
           /* search image to draw determined upon angle */
-          if (sign (angle < 0))
+          if (sign (angle) < 0)
             {
-              guard2->img_angle = (Sint16) ((angle + DEUX_PI) / PI_SUR_16);
+              guard2->img_angle = (Sint16) ((angle + TWO_PI) / PI_BY_16);
             }
           else
             {
-              guard2->img_angle = (Sint16) (angle / PI_SUR_16);
+              guard2->img_angle = (Sint16) (angle / PI_BY_16);
             }
           /* avoid a negative table index */
           guard2->img_angle = (Sint16) abs (guard2->img_angle);
@@ -2411,7 +2413,7 @@ guardian_12 (enemy * guard)
                       else if (guardian_get_next_trajectory () ==
                                GUARD_MOVEMENT_TOWARD_LEFT)
                         {
-                          guardian_add_sapouch (guard, 2, 80, TRUE);
+                          guardian_add_sapouch (2, 80, TRUE);
                         }
                     }
                   else
@@ -2483,7 +2485,7 @@ guardian_13 (enemy * guard)
         {
           if (--guardian->move_time_delay > 0)
             {
-              guardian_add_devilians (guard, 121, 3);
+              guardian_add_devilians (121, 3);
               if (guardian->move_direction[guardian->move_current] <
                   GUARD_IMMOBILE)
                 {
@@ -2595,7 +2597,7 @@ guardian_14 (enemy * guard)
               guardian_next_trajectory ();
             }
         }
-      guardian_add_perturbians (guard, 2, 210, TRUE);
+      guardian_add_perturbians (2, 210, TRUE);
     }
   numof_bullets = guardian_fire (guard, 4, 2.0);
   if (numof_bullets > 0)
@@ -2717,7 +2719,7 @@ guardian_handle (enemy * guard)
   /* common part */
   if (guardian->is_appearing)
     {
-      if (guard == guardian->enemy[0])
+      if (guard == guardian->foe[0])
         {
           /* guardian blink: display once on two */
           if (guardian->is_blinking)
@@ -2726,8 +2728,8 @@ guardian_handle (enemy * guard)
               if (guardian->number == 6 || guardian->number == 9
                   || guardian->number == 10)
                 {
-                  guardian_draw (guardian->enemy[0]);
-                  guardian_draw (guardian->enemy[1]);
+                  guardian_draw (guardian->foe[0]);
+                  guardian_draw (guardian->foe[1]);
                 }
               else
                 {
@@ -2766,12 +2768,7 @@ bool
 guardian_load (Sint32 guardian_num)
 {
   Uint32 num_of_sprites;
-#ifdef VERBOSE
-  if (power_conf->verbose > 0)
-    {
-      fprintf (stdout, "> guardians.c/guardian_load(%i)\n", guardian_num);
-    }
-#endif
+  LOG_INF ("Load guardian %i", guardian_num);
   guardian_images_free ();
 
   switch (guardian_num)
@@ -2801,6 +2798,80 @@ guardian_load (Sint32 guardian_num)
   return TRUE;
 }
 
+/**
+ * Convert guardians from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+guardians_extract (void)
+{
+  Uint32 num_of_sprites, guardian_num, sprite_num, frame;
+  const char *model = EXPORT_DIR "/guardians/guardian-xx/guardian-x-xx.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/guardians"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+
+  for (guardian_num = 1; guardian_num <= 14; guardian_num++)
+    {
+      if (!guardian_load (guardian_num))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      switch (guardian_num)
+        {
+        case 2:
+        case 4:
+        case 5:
+        case 6:
+        case 9:
+        case 10:
+        case 12:
+        case 13:
+        case 14:
+          num_of_sprites = 2;
+          break;
+        default:
+          num_of_sprites = 1;
+          break;
+        }
+      sprintf (filename, EXPORT_DIR "/guardians/guardian-%02d", guardian_num);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (sprite_num = 0; sprite_num < num_of_sprites; sprite_num++)
+        {
+          for (frame = 0; frame < ENEMIES_SPECIAL_NUM_OF_IMAGES; frame++)
+            {
+              sprintf (filename,
+                       EXPORT_DIR
+                       "/guardians/guardian-%02d/guardian-%01d-%02d.png",
+                       guardian_num, sprite_num + 1, frame);
+              if (!image_to_png (&gardi[sprite_num][frame], filename))
+                {
+                  free_memory (filename);
+                  return FALSE;
+                }
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /** 
  * Prepare next level if end of guardian
  */
@@ -2953,10 +3024,4 @@ lonely foe sympas :
 - 28 LONELY_DIVERTIZERS    vaisseau tourne va de haut en bas
 - 31 LONELY_CARRYONIANS    vaisseau bas ailes va de bas en haut
 - 39 LONELY_MADIRIANS      vaisseau canon gauche a droite
-
-
-
-
-
 */
-    /* initialize guardian 1 */
