@@ -2,13 +2,13 @@
  * @file images.c
  * @brief Read and extract data from sprite and bitmap file 
  * @created 2006-12-13 
- * @date 2007-08-19
+ * @date 2014-09-17 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: images.c,v 1.10 2007/08/19 13:16:39 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: images.c,v 1.34 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,21 +25,25 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "display.h"
 #include "images.h"
+#include "log_recorder.h"
+#ifdef PNG_EXPORT_ENABLE
+#include <zlib.h>
+#include <png.h>
+#endif
 
 static char *bitmap_read (bitmap * bmp, Uint32 num_of_obj,
                           Uint32 num_of_images, char *addr,
-                          Uint32 max_of_anims, Uint32 width);
-static char *image_extract (image * img, char *filename);
-static char *bitmap_extract (bitmap * bmp, char *filedata, Uint32 width);
+                          Uint32 max_of_anims);
+static char *image_extract (image * img, const char *filename);
+static char *bitmap_extract (bitmap * bmp, char *filedata);
 static char *read_pixels (Uint32 numofpixels, char *source,
                           char *destination);
-static char *read_compress (Uint32 filesize, char *filedata, char *compress,
-                            Uint32 sprite_with);
+static char *read_compress (Uint32 filesize, char *filedata, char *compress);
 
 /** 
  * Load and extract a file *.spr into 'image' structure
@@ -50,7 +54,7 @@ static char *read_compress (Uint32 filesize, char *filedata, char *compress,
  * @return TRUE if it completed successfully or FALSE otherwise
  */
 bool
-image_load (char *fname, image * img, Uint32 num_of_sprites,
+image_load (const char *fname, image * img, Uint32 num_of_sprites,
             Uint32 num_of_anims)
 {
   char *data;
@@ -80,8 +84,8 @@ image_load (char *fname, image * img, Uint32 num_of_sprites,
  * @return TRUE if it completed successfully or FALSE otherwise
  */
 bool
-image_load_num (char *fname, Sint32 num, image * img, Uint32 num_of_sprites,
-                Uint32 num_of_anims)
+image_load_num (const char *fname, Sint32 num, image * img,
+                Uint32 num_of_sprites, Uint32 num_of_anims)
 {
   char *data;
   char *file = loadfile_num (fname, num);
@@ -102,8 +106,8 @@ image_load_num (char *fname, Sint32 num, image * img, Uint32 num_of_sprites,
  *  Load and extract a file *.spr into 'fonte' structure
  */
 bool
-bitmap_load (char *fname, bitmap * fonte, Uint32 num_of_obj,
-             Uint32 num_of_images, Uint32 width)
+bitmap_load (const char *fname, bitmap * fonte, Uint32 num_of_obj,
+             Uint32 num_of_images)
 {
   char *addr;
   char *file = load_file (fname);
@@ -111,10 +115,7 @@ bitmap_load (char *fname, bitmap * fonte, Uint32 num_of_obj,
     {
       return FALSE;
     }
-  addr = file;
-  addr =
-    bitmap_read (fonte, num_of_obj, num_of_images, addr, num_of_images,
-                 width);
+  addr = bitmap_read (fonte, num_of_obj, num_of_images, file, num_of_images);
   if (addr == NULL)
     {
       free_memory (file);
@@ -145,8 +146,7 @@ images_read (image * img, Uint32 num_of_sprites, Uint32 num_of_anims,
           addr = image_extract (img + (i * max_of_anims) + j, addr);
           if (addr == NULL)
             {
-              fprintf (stderr, "(!)images.c/images_read(): "
-                       "image_extract failed!\n");
+              LOG_ERR ("image_extract failed!");
               return NULL;
             }
         }
@@ -197,18 +197,17 @@ images_free (image * first_image, Uint32 num_of_sprites, Uint32 num_of_anims,
  */
 static char *
 bitmap_read (bitmap * bmp, Uint32 num_of_obj, Uint32 num_of_images,
-             char *addr, Uint32 max_of_anims, Uint32 width)
+             char *addr, Uint32 max_of_anims)
 {
   Uint32 i, j;
   for (i = 0; i < num_of_obj; i++)
     {
       for (j = 0; j < num_of_images; j++)
         {
-          addr = bitmap_extract (bmp + (i * max_of_anims) + j, addr, width);
+          addr = bitmap_extract (bmp + (i * max_of_anims) + j, addr);
           if (addr == NULL)
             {
-              fprintf (stderr, "(!)images.c/bitmap_read(): "
-                       "bitmap_extract() failed!\n");
+              LOG_ERR ("bitmap_extract() failed!");
               return NULL;
             }
         }
@@ -251,7 +250,7 @@ bitmap_free (bitmap * first_bitmap, Uint32 num_of_bitmap, Uint32 num_of_anims,
  * @return TRUE if it completed successfully or FALSE otherwise
  */
 bool
-image_load_single (char *filename, image * img)
+image_load_single (const char *filename, image * img)
 {
   char *addr;
   char *filedata = load_file (filename);
@@ -262,8 +261,7 @@ image_load_single (char *filename, image * img)
   addr = image_extract (img, filedata);
   if (addr == NULL)
     {
-      fprintf (stderr, "(!)images.c/image_load_single(): "
-               "image_extract() failed!\n");
+      LOG_ERR ("image_extract() failed!");
       free_memory (filedata);
       return FALSE;
     }
@@ -286,10 +284,9 @@ image_load_single (char *filename, image * img)
  * @return Pointer to the end of source sprite filedata
  */
 static char *
-image_extract (image * img, char *file)
+image_extract (image * img, const char *file)
 {
   Uint32 i;
-  Uint16 img_width;
   Sint16 *dest;
   /* pointer to the file (8/16/32-bit access */
   char *ptr8;
@@ -307,7 +304,6 @@ image_extract (image * img, char *file)
   /* image width and height */
   img->w = little_endian_to_short (ptr16++);
   img->h = little_endian_to_short (ptr16++);
-  img_width = img->w;
 
   /* 
    * read zones and points of collision
@@ -377,7 +373,7 @@ image_extract (image * img, char *file)
     }
   /* 8-bit access */
   ptr8 = (char *) ptr32;
-  ptr8 = read_compress (img->nbr_data_comp, ptr8, img->compress, img_width);
+  ptr8 = read_compress (img->nbr_data_comp, ptr8, img->compress);
   return ptr8;
 }
 
@@ -385,11 +381,10 @@ image_extract (image * img, char *file)
  * Extract a "*.spr" file data into a 'bitmap' structure 
  * @param bmp Pointer to a bitmap structure
  * @param filedata Pointer to the file data
- * @param width Width of the bitmap in pixels
  * @return The source pointer incremented
  */
 static char *
-bitmap_extract (bitmap * bmp, char *filedata, Uint32 width)
+bitmap_extract (bitmap * bmp, char *filedata)
 {
   char *ptr8;
   Sint32 *ptr32;
@@ -425,7 +420,7 @@ bitmap_extract (bitmap * bmp, char *filedata, Uint32 width)
     }
   /* 8-bit access */
   ptr8 = (char *) ptr32;
-  ptr8 = read_compress (bmp->nbr_data_comp, ptr8, bmp->compress, width);
+  ptr8 = read_compress (bmp->nbr_data_comp, ptr8, bmp->compress);
   return ptr8;
 }
 
@@ -517,15 +512,13 @@ read_pixels (Uint32 numofpixels, char *source, char *destination)
  *                 rep;stosl
  * - filedata + 3: (unsigned char) number of consecutives bytes (rep;stosb)
  * - ...   
- * @param filesize Size of the source filedata in bytess
+ * @param filesize Size of the source filedata in bytes
  * @param filedata Source filedata of the sprite
  * @param destination Pointer to 'compress' structure of sprite or bitmap 
- * @param image_width Width of the sprite or bitmap (not used) 
  * @return The destination pointer incremented
  */
 static char *
-read_compress (Uint32 filesize, char *filedata,
-               char *destination, Uint32 image_width)
+read_compress (Uint32 filesize, char *filedata, char *destination)
 {
   Uint32 i = 0;
   Uint32 offset;
@@ -677,3 +670,397 @@ read_compress (Uint32 filesize, char *filedata,
     }
   return filedata;
 }
+
+#ifdef PNG_EXPORT_ENABLE
+/**
+ * Copy a image structure into a buffer
+ * @param width Height of the sprite in pixels 
+ * @param height Width of the sprite in pixels
+ * @param source Buffer containing 256 color pixels of the sprite
+ * @param repeats Buffer containing values of offset and the number of
+ *                contiguous pixels to be copied.
+ * @param size_counter Size of 'repeats' buffer
+ * @param size_of_line The width of the offscreen of the game.
+ *                     Always 512 pixels.
+ * @return A pointer to the buffer
+ */
+static char *
+image_to_buffer_32_bit (Uint32 width, Uint32 height, unsigned char *source,
+                        char *repeats, Uint32 size_counter,
+                        Uint32 size_of_line)
+{
+  _compress *t;
+  register Uint32 offset;
+#if __WORDSIZE == 64
+  Uint64 real_size;
+#else
+  Uint32 real_size;
+#endif
+  unsigned char *buffer, *p, *pal, pixel;
+  Uint32 buffer_size, modulo_line;
+  Uint32 line_jumps;
+  Uint16 count, i;
+  if (width < 1 || height < 1 || width > size_of_line
+      || height > size_of_line)
+    {
+      LOG_ERR ("(!) size of image: %ix%i", width, height);
+      return NULL;
+    }
+
+  /* allocate the destination buffer that will contain the 32-bit bitmap */
+  buffer_size = width * height * 4;
+  buffer = (unsigned char *) memory_allocation (buffer_size);
+  if (buffer == NULL)
+    {
+      return NULL;
+    }
+  size_counter = size_counter >> 2;
+  p = (unsigned char *) buffer;
+  count = 0;
+  t = (_compress *) repeats;
+  do
+    {
+      offset = t->offset;
+      if (offset >= size_of_line)
+        {
+          line_jumps = offset / size_of_line;
+          modulo_line = offset % size_of_line;
+          offset =
+            (offset - line_jumps * size_of_line) + (line_jumps * width);
+          if (modulo_line > width)
+            {
+              offset = offset - size_of_line + width;
+            }
+        }
+      else
+        {
+          if (offset >= width)
+            {
+              offset = offset - size_of_line + width;
+            }
+        }
+      /* offset destination */
+      p = p + offset * 4;
+      /* num of 32 words to copy */
+      count = t->r1;
+      for (i = 0; i < count * 4; i++)
+        {
+          pixel = *(source++);
+          pal = &palette_24[pixel * 3];
+#if __WORDSIZE == 64
+          real_size = ((Uint64) (p + 3) - (Uint64) buffer);
+#else
+          real_size = ((Uint32) (p + 3) - (Uint32) buffer);
+#endif
+          if (real_size > buffer_size)
+            {
+              LOG_ERR ("1) count = %i", count);
+              p += 3;
+              continue;
+            }
+          *(p++) = pal[0];
+          *(p++) = pal[1];
+          *(p++) = pal[2];
+          if (pal[0] < 64 && pal[1] < 64 && pal[2] < 64)
+            {
+              *(p++) = 255;
+            }
+          else
+            {
+              *(p++) = 255;
+            }
+        }
+      /* 8 bits data */
+      count = t->r2;
+      for (i = 0; i < count; i++)
+        {
+          pixel = *(source++);
+          pal = &palette_24[pixel * 3];
+#if __WORDSIZE == 64
+          real_size = ((Uint64) (p + 3) - (Uint64) buffer);
+#else
+          real_size = ((Uint32) (p + 3) - (Uint32) buffer);
+#endif
+          if (real_size > buffer_size)
+            {
+              LOG_ERR ("2) count = %i", count);
+              p += 3;
+              continue;
+            }
+          *(p++) = pal[0];
+          *(p++) = pal[1];
+          *(p++) = pal[2];
+          if (pal[0] < 64 && pal[1] < 64 && pal[2] < 64)
+            {
+              *(p++) = 255;
+            }
+          else
+            {
+              *(p++) = 255;
+            }
+        }
+      t++;
+      size_counter--;
+    }
+  while (size_counter > 0);
+#if __WORDSIZE == 64
+  real_size = ((Uint64) p - (Uint64) buffer);
+#else
+  real_size = ((Uint32) p - (Uint32) buffer);
+#endif
+  if (real_size > buffer_size)
+    {
+      LOG_ERR ("%i is greater than %i (%ix%i)",
+               (Sint32) real_size, buffer_size, width, height);
+    }
+  LOG_DBG ("width: %i, height: %i, real_size: %i, buffer_size: %i", width,
+           height, real_size, buffer_size);
+  return (char *) buffer;
+}
+
+static png_text text[5] = {
+#ifdef PNG_iTXt_SUPPORTED
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Title", "Powermanga Graphics", 19, 0, NULL,
+   NULL},
+  {
+
+   PNG_TEXT_COMPRESSION_NONE, "Author",
+   "Jean-Michel Martin de Santero, David Igreja", 43, 0, NULL, NULL},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Description", "Image of Powermanga Game", 24,
+   0, NULL, NULL},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Copyright", "TLK Games", 9, 0, NULL, NULL},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Software", "GNU Linux", 9, 0, NULL, NULL},
+#else
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Title", "Powermanga Graphics", 19},
+  {
+
+   PNG_TEXT_COMPRESSION_NONE, "Author",
+   "Jean-Michel Martin de Santero, David Igreja", 43},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Description", "Image of Powermanga Game", 24},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Copyright", "TLK Games", 9},
+  {
+   PNG_TEXT_COMPRESSION_NONE, "Software", "GNU Linux", 9},
+#endif
+};
+
+
+
+/**
+ * This function tries to determine the width and height of a sprite.
+ * Because a sprite structure "bitmap" have no size. The result is not reliable.
+ * @param bmp Pointer to an 'bitmap' structure
+ * @param size_of_line The width of the offscreen of the game.
+ *                     Always 512 pixels.
+ */
+#ifdef __BITMAP_CHECK_SIZE__
+static bool
+bitmap_check_size (bitmap * bmp, Uint32 size_of_line)
+{
+  _compress *compress;
+  register Uint32 offset;
+  Uint16 pixel_counter;
+  Uint32 modulo_line, line_jumps, estimated_width, estimated_height,
+    min_xoffset, yoffset, i, xpos, total_size;
+  char *repeats = bmp->compress;
+  Uint32 size_counter = bmp->nbr_data_comp;
+  size_counter = size_counter >> 2;
+  compress = (_compress *) repeats;
+  estimated_width = estimated_height = i = xpos = total_size = yoffset = 0;
+  min_xoffset = size_of_line;
+  do
+    {
+      offset = compress->offset;
+      if (offset >= size_of_line)
+        {
+          line_jumps = offset / size_of_line;
+          modulo_line = offset % size_of_line;
+          estimated_height += line_jumps;
+          xpos = modulo_line;
+          total_size += modulo_line;
+          if (xpos < min_xoffset)
+            {
+              min_xoffset = xpos;
+            }
+          if (i == 0)
+            {
+              yoffset = line_jumps;
+            }
+        }
+      else
+        {
+          total_size += offset;
+          if ((xpos + offset) > size_of_line)
+            {
+              xpos = offset - (size_of_line - xpos);
+              estimated_height++;
+              if (xpos < min_xoffset)
+                {
+                  min_xoffset = xpos;
+                }
+            }
+          else
+            {
+              xpos += offset;
+            }
+        }
+      /* number of pixels to be copied by 4 bytes */
+      pixel_counter = compress->r1 * 4;
+      /* number of pixels to copy a single byte at a time */
+      pixel_counter += compress->r2;
+      total_size += pixel_counter;
+      xpos += pixel_counter;
+      if (xpos > estimated_width)
+        {
+          estimated_width = xpos;
+        }
+      size_counter--;
+      compress++;
+      i++;
+    }
+  while (size_counter > 0);
+  estimated_height++;
+  estimated_height += yoffset;
+  estimated_width += min_xoffset;
+  LOG_INF
+    ("estimated width: %i, estimated height: %i, total_size: %i, min_xoffset: %i, yoffset = %i \n",
+     estimated_width, estimated_height, total_size, min_xoffset, yoffset);
+  return TRUE;
+}
+#endif
+
+/**
+ * Write PNG image data
+ * @param buffer Image data
+ * @param filename A filename of the PNG image to save
+ * @param width Image width in pixels
+ * @param height Image height in pixels
+ * @param depth The bit depth of the image.
+ *              Valid values shall include 1, 2, 4, 8, 16. 
+ * @return TRUE if it completed successfully or FALSE otherwise
+ */
+static bool
+png_create (char *buffer, const char *filename, Uint32 width, Uint32 height,
+            Sint32 depth)
+{
+  Uint32 i;
+  FILE *out;
+  LOG_DBG ("Write %s", filename);
+  if (buffer == NULL)
+    {
+      LOG_ERR ("image_to_buffer() failed! (filename = %s)", filename);
+      return FALSE;
+    }
+  out = fopen_data (filename, "w");
+  if (out == NULL)
+    {
+      LOG_ERR ("can't open \"%s\"", filename);
+      return FALSE;
+    }
+
+  /* allocate and initialize png_ptr struct for writing */
+  png_structp png_ptr = png_create_write_struct (PNG_LIBPNG_VER_STRING,
+                                                 /* error_ptr */
+                                                 (png_voidp) NULL,
+                                                 /* error_fn */
+                                                 NULL,
+                                                 /* warn_fn */
+                                                 NULL);
+  if (png_ptr == NULL)
+    {
+      LOG_ERR ("png_create_write_struct() failed");
+      return FALSE;
+    }
+
+  /* allocate and initialize the info structure */
+  png_infop info_ptr = png_create_info_struct (png_ptr);
+  if (png_ptr == NULL)
+    {
+      LOG_ERR ("png_create_info_struct() failed");
+      return FALSE;
+    }
+
+  /* initialize input/output for PNG file to the default functions */
+  png_init_io (png_ptr, out);
+
+  /* set library compression level */
+  png_set_IHDR (png_ptr, info_ptr,
+                /* width */
+                width,
+                /* height */
+                height,
+                /* bit depth */
+                depth,
+                PNG_COLOR_TYPE_RGB_ALPHA,
+                PNG_INTERLACE_NONE,
+                PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_DEFAULT);
+  png_set_compression_level (png_ptr, Z_BEST_COMPRESSION);
+
+  png_set_text (png_ptr, info_ptr, text, sizeof text / sizeof text[0]);
+  png_color_16 background;
+  background.red = 0;
+  background.green = 0;
+  background.blue = 0;
+  png_set_bKGD (png_ptr, info_ptr, &background);
+  png_write_info (png_ptr, info_ptr);
+  for (i = 0; i < height; i++)
+    {
+      {
+        png_write_row (png_ptr, (png_byte *) & buffer[i * width * 4]);
+      }
+    }
+  png_write_end (png_ptr, info_ptr);
+  png_destroy_write_struct (&png_ptr, &info_ptr);
+  fclose (out);
+  return TRUE;
+}
+
+/**
+ * Converts a 'image' structure in a PNG file.
+ * @param img Pointer to an 'image' structure
+ * @param filename A filename of the PNG image to save
+ * @return TRUE if it completed successfully or FALSE otherwise
+ */
+bool
+image_to_png (image * img, const char *filename)
+{
+  bool res;
+  char *buffer =
+    image_to_buffer_32_bit (img->w, img->h, (unsigned char *) img->img,
+                            img->compress, img->nbr_data_comp,
+                            offscreen_pitch);
+  res = png_create (buffer, filename, img->w, img->h, 8);
+  free_memory (buffer);
+  return res;
+}
+
+/**
+ * Converts a 'bitmap' structure in a PNG file.
+ * @param bmp Pointer to an 'bitmap' structure
+ * @param filename A filename of the PNG image to save
+ * @param width Height of the sprite in pixels 
+ * @param height Width of the sprite in pixels
+ * @return TRUE if it completed successfully or FALSE otherwise
+ */
+bool
+bitmap_to_png (bitmap * bmp, const char *filename, Uint32 width,
+               Uint32 height, Uint32 size_of_line)
+{
+  bool res;
+#ifdef __BITMAP_CHECK_SIZE__
+  bitmap_check_size (bmp, size_of_line);
+#endif
+  char *buffer =
+    image_to_buffer_32_bit (width, height, (unsigned char *) bmp->img,
+                            bmp->compress, bmp->nbr_data_comp, size_of_line);
+  res = png_create (buffer, filename, width, height, 8);
+  free_memory (buffer);
+  return res;
+}
+#endif
