@@ -2,7 +2,7 @@
  * @file lispreader.c 
  * @brief Parse configuration file 
  * @created 2007-06-15
- * @date 2007-09-02
+ * @date 2012-08-26 
  * @author Mark Probst 
  * @author Ingo Ruhnke <grumbel@gmx.de>
  * @author Bruno Ethvignot
@@ -10,8 +10,8 @@
 /*
  * copyright (c) 1998-2000 Mark Probst
  * copyright (c) 2002 Ingo Ruhnke <grumbel@gmx.de>
- * copyright (c) 2007 TLK Games all rights reserved
- * $Id: lispreader.c,v 1.9 2007/09/02 14:55:29 gurumeditation Exp $
+ * copyright (c) 2007-2012 TLK Games all rights reserved
+ * $Id: lispreader.c,v 1.19 2012/08/26 15:44:26 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,14 +28,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
-#include <assert.h>
-#include <stdlib.h>
-#include <string.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "lispreader.h"
-
+#include "log_recorder.h"
 
 typedef enum
 {
@@ -46,16 +43,14 @@ typedef enum
   LISP_PATTERN_REAL,
   LISP_PATTERN_BOOLEAN,
   LISP_PATTERN_LIST,
-  LISP_PATTERN_OR,
+  LISP_PATTERN_OR
 } LISP_PATTERN_ENUM;
 
-
-
 typedef enum
 {
   LISP_STREAM_FILE = 1,
   LISP_STREAM_STRING,
-  LISP_STREAM_ANY,
+  LISP_STREAM_ANY
 } LISP_STREAM_ENUM;
 
 typedef enum
@@ -78,7 +73,6 @@ typedef enum
 #define lisp_nil()           ((lisp_object_t*)0)
 #define lisp_nil_p(obj)      (obj == 0)
 #define lisp_integer_p(obj)  (lisp_type((obj)) == LISP_TYPE_INTEGER)
-#define lisp_real_p(obj)     (lisp_type((obj)) == LISP_TYPE_REAL)
 #define lisp_symbol_p(obj)   (lisp_type((obj)) == LISP_TYPE_SYMBOL)
 #define lisp_string_p(obj)   (lisp_type((obj)) == LISP_TYPE_STRING)
 #define lisp_cons_p(obj)     (lisp_type((obj)) == LISP_TYPE_CONS)
@@ -90,14 +84,14 @@ static lisp_object_t error_object = { LISP_TYPE_PARSE_ERROR, {{0, 0}} };
 static lisp_object_t close_paren_marker = { LISP_TYPE_PARSE_ERROR, {{0, 0}} };
 static lisp_object_t dot_marker = { LISP_TYPE_PARSE_ERROR, {{0, 0}} };
 
-/* static Sint32 _match_pattern (lisp_object_t *pattern, lisp_object_t *obj, lisp_object_t **vars); */
 static char *lisp_string (lisp_object_t * obj);
 static Sint32 lisp_integer (lisp_object_t * obj);
 static float lisp_real (lisp_object_t * obj);
 static Sint32 lisp_type (lisp_object_t * obj);
+static void lisp_dump (lisp_object_t * obj, FILE * out);
 
 /**
- *
+ * Clear the current string
  */
 static void
 _token_clear (void)
@@ -107,8 +101,8 @@ _token_clear (void)
 }
 
 /**
- *
- * @param c
+ *  Copy current string
+ * @param c A character code of string read currently
  */
 static void
 _token_append (char c)
@@ -174,17 +168,18 @@ _unget_char (char c, lisp_stream_t * stream)
 
 /**
  * Scan the configuration file 
- * @input stream
- * @return
+ * @input stream A pointer to a lisp_stream_t struture
+ * @return A return code
  */
 static Sint32
 _scan (lisp_stream_t * stream)
 {
-  static char *delims = "\"();";
+  static const char *delims = "\"();";
   Sint32 c;
   Sint32 have_nondigits;
   Sint32 have_digits;
   Sint32 have_floating_point;
+  bool search = TRUE;
   _token_clear ();
   do
     {
@@ -193,20 +188,22 @@ _scan (lisp_stream_t * stream)
         {
           return TOKEN_EOF;
         }
-      /* comment start */
+      /* comment start : all comments are ignored */
       else if (c == ';')
-        while (1)
-          {
-            c = _next_char (stream);
-            if (c == EOF)
-              {
-                return TOKEN_EOF;
-              }
-            else if (c == '\n')
-              {
-                break;
-              }
-          }
+        {
+          while (search)
+            {
+              c = _next_char (stream);
+              if (c == EOF)
+                {
+                  return TOKEN_EOF;
+                }
+              else if (c == '\n')
+                {
+                  break;
+                }
+            }
+        }
     }
   while (isspace (c));
 
@@ -219,7 +216,7 @@ _scan (lisp_stream_t * stream)
       return TOKEN_CLOSE_PAREN;
 
     case '"':
-      while (1)
+      while (search)
         {
           c = _next_char (stream);
           if (c == EOF)
@@ -227,7 +224,9 @@ _scan (lisp_stream_t * stream)
               return TOKEN_ERROR;
             }
           if (c == '"')
-            break;
+            {
+              break;
+            }
           if (c == '\\')
             {
               c = _next_char (stream);
@@ -245,7 +244,7 @@ _scan (lisp_stream_t * stream)
                   break;
                 }
             }
-          _token_append (c);
+          _token_append ((char) c);
         }
       return TOKEN_STRING;
 
@@ -294,7 +293,7 @@ _scan (lisp_stream_t * stream)
                 {
                   have_floating_point++;
                 }
-              _token_append (c);
+              _token_append ((char) c);
               c = _next_char (stream);
               if (c != EOF && !isdigit (c) && !isspace (c) && c != '.'
                   && !strchr (delims, c))
@@ -305,7 +304,7 @@ _scan (lisp_stream_t * stream)
           while (c != EOF && !isspace (c) && !strchr (delims, c));
           if (c != EOF)
             {
-              _unget_char (c, stream);
+              _unget_char ((char) c, stream);
             }
           if (have_nondigits || !have_digits || have_floating_point > 1)
             {
@@ -331,29 +330,28 @@ _scan (lisp_stream_t * stream)
                 }
               else
                 {
-                  _unget_char (c, stream);
+                  _unget_char ((char) c, stream);
                   return TOKEN_DOT;
                 }
             }
           do
             {
-              _token_append (c);
+              _token_append ((char) c);
               c = _next_char (stream);
             }
           while (c != EOF && !isspace (c) && !strchr (delims, c));
           if (c != EOF)
             {
-              _unget_char (c, stream);
+              _unget_char ((char) c, stream);
             }
           return TOKEN_SYMBOL;
         }
     }
-  assert (0);
-  return TOKEN_ERROR;
 }
 
 /**
- *
+ * Release a object type
+ * @param obj A pointer to a lisp_object_t structure
  */
 void
 lisp_free (lisp_object_t * obj)
@@ -384,8 +382,13 @@ lisp_free (lisp_object_t * obj)
   free_memory ((char *) obj);
 }
 
+/**
+ * Create a lisp_object_t structure
+ * @param type A object type code
+ * @return A pointer to a lisp_object_t
+ */
 static lisp_object_t *
-lisp_object_alloc (int type)
+lisp_object_alloc (Sint32 type)
 {
   lisp_object_t *obj =
     (lisp_object_t *) memory_allocation (sizeof (lisp_object_t));
@@ -393,6 +396,12 @@ lisp_object_alloc (int type)
   return obj;
 }
 
+/**
+ * Initialize string of steam
+ * @param stream A pointer to a lisp_stream_t structure
+ * @param buf Pointer to string
+ * @return A pointer to a lisp_stream_t structure
+ */
 lisp_stream_t *
 lisp_stream_init_string (lisp_stream_t * stream, char *buf)
 {
@@ -402,14 +411,24 @@ lisp_stream_init_string (lisp_stream_t * stream, char *buf)
   return stream;
 }
 
+/**
+ * Create a integer type
+ * @param value A interger value
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
-lisp_make_integer (int value)
+lisp_make_integer (Sint32 value)
 {
   lisp_object_t *obj = lisp_object_alloc (LISP_TYPE_INTEGER);
   obj->v.integer = value;
   return obj;
 }
 
+/**
+ * Create a real type
+ * @param value A real value
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
 lisp_make_real (float value)
 {
@@ -418,6 +437,11 @@ lisp_make_real (float value)
   return obj;
 }
 
+/**
+ * Create a symbol type
+ * @param value
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
 lisp_make_symbol (const char *value)
 {
@@ -426,6 +450,11 @@ lisp_make_symbol (const char *value)
   return obj;
 }
 
+/**
+ * Create a string type
+ * @param value
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
 lisp_make_string (const char *value)
 {
@@ -434,44 +463,57 @@ lisp_make_string (const char *value)
   return obj;
 }
 
+/**
+ * Create a "cons" element 
+ * @param car Contents of Address register (first element)
+ * @param value cdr (Contents of Decrement register) 
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
 lisp_make_cons (lisp_object_t * car, lisp_object_t * cdr)
 {
   lisp_object_t *obj = lisp_object_alloc (LISP_TYPE_CONS);
-
   obj->v.cons.car = car;
   obj->v.cons.cdr = cdr;
-
   return obj;
 }
 
+/**
+ * Create a boolean type
+ * @param value
+ * @return A pointer to a lisp_object_t structure 
+ */
 lisp_object_t *
-lisp_make_boolean (int value)
+lisp_make_boolean (Sint32 value)
 {
   lisp_object_t *obj = lisp_object_alloc (LISP_TYPE_BOOLEAN);
-
   obj->v.integer = value ? 1 : 0;
-
   return obj;
 }
 
+/**
+ * @param car
+ * @param cdr
+ * @return A pointer to a lisp_object_t structure
+ */
 static lisp_object_t *
 lisp_make_pattern_cons (lisp_object_t * car, lisp_object_t * cdr)
 {
   lisp_object_t *obj = lisp_object_alloc (LISP_TYPE_PATTERN_CONS);
-
   obj->v.cons.car = car;
   obj->v.cons.cdr = cdr;
-
   return obj;
 }
 
 /**
  * Parse the configuration file
+ * @param in A pointer to a lisp_stream_t structure
+ * @return A pointer to a lisp_object_t structure
  */
 lisp_object_t *
 lisp_read (lisp_stream_t * in)
 {
+  lisp_object_t *last, *car;
   Sint32 token = _scan (in);
   lisp_object_t *obj = lisp_nil ();
   if (token == TOKEN_EOF)
@@ -488,7 +530,7 @@ lisp_read (lisp_stream_t * in)
     case TOKEN_OPEN_PAREN:
     case TOKEN_PATTERN_OPEN_PAREN:
       {
-        lisp_object_t *last = lisp_nil (), *car;
+        last = lisp_nil ();
         do
           {
             car = lisp_read (in);
@@ -533,6 +575,7 @@ lisp_read (lisp_stream_t * in)
                        TOKEN_OPEN_PAREN ? lisp_make_cons (car,
                                                           lisp_nil ()) :
                        lisp_make_pattern_cons (car, lisp_nil ()));
+
                   }
                 else
                   {
@@ -575,6 +618,11 @@ lisp_read (lisp_stream_t * in)
 }
 
 
+/**
+ * Return the code of an object type
+ * @param obj A pointer to a lisp_object_t structure
+ * @return An object type code
+ */
 Sint32
 lisp_type (lisp_object_t * obj)
 {
@@ -585,6 +633,11 @@ lisp_type (lisp_object_t * obj)
   return obj->type;
 }
 
+/**
+ * Return integer value of an integer type
+ * @param obj A pointer to a lisp_object_t structure
+ * @return A interger value
+ */
 Sint32
 lisp_integer (lisp_object_t * obj)
 {
@@ -593,16 +646,22 @@ lisp_integer (lisp_object_t * obj)
 }
 
 /** 
- *
+ * Return string of a symbol type
+ * @param obj A pointer to a lisp_object_t structure
+ * @return A pointer to a string
  */
 char *
 lisp_symbol (lisp_object_t * obj)
 {
   assert (obj->type == LISP_TYPE_SYMBOL);
-
   return obj->v.string;
 }
 
+/** 
+ * Return a string of a string object
+ * @param obj A pointer to a lisp_object_t structure
+ * @return A pointer to a string
+ */
 char *
 lisp_string (lisp_object_t * obj)
 {
@@ -610,6 +669,11 @@ lisp_string (lisp_object_t * obj)
   return obj->v.string;
 }
 
+/** 
+ * Return value of a boolean object
+ * @param obj A pointer to a lisp_object_t structure
+ * @return 0 or 1
+ */
 Sint32
 lisp_boolean (lisp_object_t * obj)
 {
@@ -617,18 +681,26 @@ lisp_boolean (lisp_object_t * obj)
   return obj->v.integer;
 }
 
+/** 
+ * Return float value of a real type
+ * @param obj A pointer to a lisp_object_t structure
+ * @return A float value
+ */
 float
 lisp_real (lisp_object_t * obj)
 {
   assert (obj->type == LISP_TYPE_REAL || obj->type == LISP_TYPE_INTEGER);
-
   if (obj->type == LISP_TYPE_INTEGER)
-    return obj->v.integer;
+    {
+      return (float) (obj->v.integer);
+    }
   return obj->v.real;
 }
 
 /**
  *
+ * @param obj A pointer to a lisp_object_t structure
+ * @return
  */
 lisp_object_t *
 lisp_car (lisp_object_t * obj)
@@ -639,6 +711,8 @@ lisp_car (lisp_object_t * obj)
 
 /**
  *
+ * @param obj A pointer to a lisp_object_t structure
+ * @return
  */
 lisp_object_t *
 lisp_cdr (lisp_object_t * obj)
@@ -647,9 +721,15 @@ lisp_cdr (lisp_object_t * obj)
   return obj->v.cons.cdr;
 }
 
+/** 
+ * Dump a lisp_object_t structure
+ * @param obj A pointer to a lisp_object_t structure
+ * @param FILE A output stream
+ */
 void
 lisp_dump (lisp_object_t * obj, FILE * out)
 {
+  char *p;
   if (obj == 0)
     {
       fprintf (out, "()");
@@ -680,8 +760,6 @@ lisp_dump (lisp_object_t * obj, FILE * out)
 
     case LISP_TYPE_STRING:
       {
-        char *p;
-
         fputc ('"', out);
         for (p = lisp_string (obj); *p != 0; ++p)
           {
@@ -740,16 +818,15 @@ lisp_dump (lisp_object_t * obj, FILE * out)
 static lisp_object_t *
 search_for (lisp_object_t * lst, const char *name)
 {
+  lisp_object_t *cur;
   lisp_object_t *cursor = lst;
   while (!lisp_nil_p (cursor))
     {
-      lisp_object_t *cur = lisp_car (cursor);
-
+      cur = lisp_car (cursor);
       if (!lisp_cons_p (cur) || !lisp_symbol_p (lisp_car (cur)))
         {
           lisp_dump (cur, stdout);
-          fprintf (stderr, "(!)lispreader.c/search_for(): "
-                   "Read error in search\n");
+          LOG_ERR ("Read error in search");
         }
       else
         {
@@ -783,8 +860,7 @@ lisp_read_int (lisp_object_t * lst, const char *name, Sint32 * i)
     }
   if (!lisp_integer_p (lisp_car (obj)))
     {
-      fprintf (stderr, "lispreader.c/lisp_read_bool() "
-               "LispReader expected type integer at token: %s", name);
+      LOG_ERR ("LispReader expected type integer at token: %s", name);
       return FALSE;
     }
   *i = lisp_integer (lisp_car (obj));
@@ -811,8 +887,7 @@ lisp_read_bool (lisp_object_t * lst, const char *name, bool * b)
 
   if (!lisp_boolean_p (lisp_car (obj)))
     {
-      fprintf (stderr, "lispreader.c/lisp_read_bool() "
-               "LispReader expected type bool at token: %s", name);
+      LOG_ERR ("LispReader expected type bool at token: %s", name);
       return FALSE;
     }
   *b = lisp_boolean (lisp_car (obj));
@@ -838,8 +913,7 @@ lisp_read_string (lisp_object_t * lst, const char *name, char **str)
     }
   if (!lisp_string_p (lisp_car (obj)))
     {
-      fprintf (stderr, "lispreader.c/read_string() "
-               "expected type real at token: %s", name);
+      LOG_ERR ("expected type real at token: %s", name);
       return FALSE;
     }
   *str = lisp_string (lisp_car (obj));
@@ -868,8 +942,7 @@ lisp_read_file (char *filename)
   stream = (lisp_stream_t *) memory_allocation (sizeof (lisp_stream_t));
   if (stream == NULL)
     {
-      fprintf (stderr, "(!)lispreader.c/lisp_read_file(%s) :"
-               "not enough memmory to allocate 'lisp_stream_t'\n", filename);
+      LOG_ERR ("not enough memmory to allocate 'lisp_stream_t'", filename);
       free_memory (filedata);
       return NULL;
     }
