@@ -2,13 +2,13 @@
  * @file lonely_foes.c
  * @brief Handle lonely foes (come out randomly as penality) 
  * @created 1999-09-09
- * @date 2007-08-31
+ * @date 2010-01-01
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /*
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: lonely_foes.c,v 1.22 2007/08/31 20:46:43 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: lonely_foes.c,v 1.30 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -50,10 +50,10 @@ static Uint32 lonely_foes_count = 0;
  * @return Pointer to the new enemy element
  */
 static enemy *
-lonely_foe_new (Sint32 power, Sint32 energy, Sint32 current_image,
+lonely_foe_new (Sint16 power, Sint16 energy, Sint16 current_image,
                 Sint32 type, Sint32 shot_delay)
 {
-  Uint32 i;
+  Sint32 i;
   enemy *foe;
   foe = enemy_get ();
   if (foe == NULL)
@@ -87,12 +87,12 @@ lonely_foe_new (Sint32 power, Sint32 energy, Sint32 current_image,
  * @return Pointer to the new enemy element
  */
 static enemy *
-lonely_foe_create (Sint32 delay_next, Sint32 type, Sint32 shot_delay,
+lonely_foe_create (Sint16 delay_next, Sint32 type, Sint32 shot_delay,
                    float speed)
 {
   spaceship_struct *ship = spaceship_get ();
-  Sint32 power = (Sint32) ((ship->type << 1) + type - 40);
-  Sint32 energy = (Sint32) ((ship->type << 2) + (power << 3) / 3 + 10);
+  Sint16 power = (Sint16) ((ship->type << 1) + type - 40);
+  Sint16 energy = (Sint16) ((ship->type << 2) + (power << 3) / 3 + 10);
   enemy *foe = lonely_foe_new (power, energy, 0, type, shot_delay);
   if (foe == NULL)
     {
@@ -110,13 +110,14 @@ lonely_foe_create (Sint32 delay_next, Sint32 type, Sint32 shot_delay,
 void
 lonely_foe_add_gozuky (enemy * foe, Uint32 cannon_pos)
 {
-  Sint32 xcoord, ycoord, power, current_image;
+  Sint32 xcoord, ycoord;
+  Sint16 power, current_image;
   spaceship_struct *ship = spaceship_get ();
   sprite *spr = &foe->spr;
   xcoord =
     (Sint32) (spr->xcoord +
-              spr->img[spr->current_image]->
-              cannons_coords[cannon_pos][XCOORD]);
+              spr->img[spr->
+                       current_image]->cannons_coords[cannon_pos][XCOORD]);
   /* check if the sprite is visible or not  */
   if (xcoord <= offscreen_startx ||
       xcoord >= (offscreen_startx + offscreen_width_visible - 1))
@@ -125,10 +126,10 @@ lonely_foe_add_gozuky (enemy * foe, Uint32 cannon_pos)
     }
   ycoord =
     (Sint32) (spr->ycoord +
-              spr->img[spr->current_image]->
-              cannons_coords[cannon_pos][YCOORD]);
-  power = (Sint32) ((ship->type << 1) + 10);
-  current_image = (Sint32) (((long) rand () % ENEMIES_SPECIAL_NUM_OF_IMAGES));
+              spr->img[spr->
+                       current_image]->cannons_coords[cannon_pos][YCOORD]);
+  power = (Sint16) ((ship->type << 1) + 10);
+  current_image = (Sint16) (rand () % ENEMIES_SPECIAL_NUM_OF_IMAGES);
   foe = lonely_foe_new (power, power, current_image, GOZUKY, 6000);
   if (foe == NULL)
     {
@@ -150,12 +151,13 @@ void
 lonely_foe_curve_create (Sint32 type, Sint32 shot_delay)
 {
   enemy *foe;
-  Sint32 curve_num, current_image, power, energy;
+  Sint16 curve_num;
+  Sint16 current_image, power, energy;
   spaceship_struct *ship = spaceship_get ();
-  curve_num = 51 + (Sint32) (((long) rand () % (4)));
+  curve_num = 51 + (Sint16) (rand () % 4);
   current_image = initial_curve[curve_num].angle[0];
-  power = (Sint32) ((ship->type << 1) + type - 40);
-  energy = (Sint32) ((ship->type << 2) + (power << 3) / 3 + 10);
+  power = (Sint16) ((ship->type << 1) + type - 40);
+  energy = (Sint16) ((ship->type << 2) + (power << 3) / 3 + 10);
   foe = lonely_foe_new (power, energy, current_image, type, shot_delay);
   if (foe == NULL)
     {
@@ -222,7 +224,8 @@ lonely_foe_add (Sint32 foe_num)
         {
           break;
         }
-      foe->spr.xcoord = offscreen_startx + 64 + offscreen_width_visible;
+      foe->spr.xcoord
+        = (float) (offscreen_startx + 64 + offscreen_width_visible);
       foe->spr.ycoord =
         offscreen_starty +
         (float) (((long) rand () %
@@ -256,7 +259,8 @@ lonely_foe_add (Sint32 foe_num)
         offscreen_startx +
         (float) (((long) rand () %
                   (offscreen_width_visible - foe->spr.img[0]->w)));
-      foe->spr.ycoord = offscreen_starty + 64 + offscreen_height_visible;
+      foe->spr.ycoord
+        = (float) offscreen_starty + 64 + offscreen_height_visible;
       break;
 
       /* TOUBOUG */
@@ -369,7 +373,8 @@ lonely_foe_add (Sint32 foe_num)
         offscreen_startx +
         (float) (((long) rand () %
                   (offscreen_width_visible - foe->spr.img[0]->w)));
-      foe->spr.ycoord = offscreen_starty + 64 + offscreen_height_visible;
+      foe->spr.ycoord
+        = (float) (offscreen_starty + 64 + offscreen_height_visible);
       break;
 
       /* TODHAIRIES */
@@ -470,7 +475,8 @@ lonely_foe_add (Sint32 foe_num)
         {
           break;
         }
-      foe->spr.xcoord = offscreen_startx + 64 + offscreen_width_visible;
+      foe->spr.xcoord
+        = (float) (offscreen_startx + 64 + offscreen_width_visible);
       foe->spr.ycoord =
         offscreen_starty +
         (float) (((long) rand () %
@@ -496,7 +502,8 @@ lonely_foe_add (Sint32 foe_num)
         offscreen_startx +
         (float) (((long) rand () %
                   (offscreen_width_visible - foe->spr.img[0]->w)));
-      foe->spr.ycoord = offscreen_starty + 64 + offscreen_height_visible;
+      foe->spr.ycoord
+        = (float) (offscreen_starty + 64 + offscreen_height_visible);
       break;
 
       /* CLOWNIES */
@@ -543,7 +550,8 @@ lonely_foe_add (Sint32 foe_num)
         {
           break;
         }
-      foe->spr.xcoord = offscreen_startx + 64 + offscreen_width_visible;
+      foe->spr.xcoord
+        = (float) (offscreen_startx + 64 + offscreen_width_visible);
       foe->spr.ycoord =
         offscreen_starty +
         (float) (((long) rand () %
@@ -644,7 +652,8 @@ lonely_foe_add (Sint32 foe_num)
         {
           break;
         }
-      foe->spr.xcoord = offscreen_startx + 64 + offscreen_width_visible;
+      foe->spr.xcoord
+        = (float) (offscreen_startx + 64 + offscreen_width_visible);
       foe->spr.ycoord =
         offscreen_starty +
         (float) (((long) rand () %
@@ -716,7 +725,8 @@ lonely_foe_add (Sint32 foe_num)
         offscreen_startx +
         (float) (((long) rand () %
                   (offscreen_width_visible - foe->spr.img[0]->w)));
-      foe->spr.ycoord = offscreen_starty + 64 + offscreen_height_visible;
+      foe->spr.ycoord
+        = (float) (offscreen_starty + 64 + offscreen_height_visible);
       break;
 
       /* DEVILIANS */
