@@ -2,11 +2,11 @@
  * @file menu.h 
  * @brief handle displaying and updating the graphical components of the game 
  * @created 2006-12-07 
- * @date 2007-06-01
+ * @date 2011-02-17 
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: menu.h,v 1.8 2007/07/09 20:21:37 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: menu.h,v 1.15 2012/06/03 17:06:15 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,22 +31,26 @@ extern "C"
 {
 #endif
 
-bool menu_once_init (void);
-void menu_free (void);
-void menu_handle (void);
+  bool menu_once_init (void);
+  void menu_free (void);
+  void menu_handle (void);
+  bool menu_check_button (void);
+#ifdef PNG_EXPORT_ENABLE
+  bool menu_extract ();
+#endif
 
 /** The different possible status for the menu */
-typedef enum
-{
-  MENU_OFF,
-  MENU_ON,
-  MENU_UP,
-  MENU_DOWN
-}
-MENU_STATUS;
+  typedef enum
+  {
+    MENU_OFF,
+    MENU_ON,
+    MENU_UP,
+    MENU_DOWN
+  }
+  MENU_STATUS;
 
-extern Sint32 menu_status;
-extern Sint32 menu_coord_y;
+  extern Sint32 menu_status;
+  extern Sint32 menu_coord_y;
 #ifdef __cplusplus
 }
 #endif
