@@ -2,12 +2,12 @@
  * @file menu_sections.c 
  * @brief hanlde high score table, about and order menu sections 
  * @created 1998-06-29 
- * @date 2007-08-31
+ * @date 2012-08-26 
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: menu_sections.c,v 1.27 2007/09/02 16:13:56 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: menu_sections.c,v 1.42 2012/08/26 15:44:26 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -33,14 +33,10 @@
 #include "menu.h"
 #include "scrolltext.h"
 #include "sprites_string.h"
+#include "log_recorder.h"
 #include "menu_sections.h"
 #include "texts.h"
 #include "config_file.h"
-#ifndef POWERMANGA_SDL
-#include <X11/keysym.h>
-#include <X11/keysymdef.h>
-#endif
-#include <errno.h>
 /** Names of the score filenames follow the difficulty level */
 static const char *score_filenames[] =
   { SCOREFILE "-easy", SCOREFILE, SCOREFILE "-hard" };
@@ -55,9 +51,9 @@ const Uint32 KEYSTOKE_NUM_OF_COLS = 16;
 /** Size of the file for keystroke */
 const Uint32 KEYSTROKE_SIZE_OF_FILE = 20480;
 /** Pause code of keystroke */
-const Uint32 KEYSTROKE_PAUSE = 0x4c1;
+const Sint16 KEYSTROKE_PAUSE = 0x4c1;
 /** End text code of keystroke */
-const Uint32 KEYSTROKE_EOF = 0x4c2;
+const Sint16 KEYSTROKE_EOF = 0x4c2;
 
 /*
  * High score table
@@ -101,7 +97,7 @@ static Sint32 generate_byte_checksum (unsigned char *buffer, Uint32 size);
 static void high_score_draw (void);
 static void gameover_run (void);
 static void high_scores_draw (void);
-static void about_draw (bool is_menu_enabled);
+static void about_draw (void);
 static void order_run (void);
 static void order_clear_screen (void);
 static void order_insert_line (Uint32 line_num);
@@ -115,8 +111,7 @@ static void check_if_enable_menu (void);
  * 'game over' section
  */
 /* working table */
-static char high_scores_values[32] =
-{
+static char high_scores_values[32] = {
   0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 0, 0,
@@ -124,8 +119,7 @@ static char high_scores_values[32] =
 };
 
 /* default scores table */
-static char high_scores_names[MAX_OF_HIGH_SCORES][4] =
-{
+static char high_scores_names[MAX_OF_HIGH_SCORES][4] = {
   {'T', 'L', 'K', 0},
   {'J', 'M', 'M', 0},
   {'E', 'T', 'B', 0},
@@ -172,7 +166,7 @@ Uint16 *order_keystroke = NULL;
 /** Index on the command table */
 Uint32 order_index = 0;
 /** Time delay before next command */
-Sint32 order_delay_counter = 0;
+Sint16 order_delay_counter = 0;
 Uint16 order_last_keycode = 0;
 /** Type of order section file  */
 bool order_cmd_type = FALSE;
@@ -347,8 +341,6 @@ about_release_memory ()
 void
 menu_sections_run (void)
 {
-  /* main menu enabled or not? */
-  bool is_main_menu_enabled = menu_status == MENU_OFF ? FALSE : TRUE;
   switch (menu_section)
     {
       /* game over: the player lost his last spaceship */
@@ -363,7 +355,7 @@ menu_sections_run (void)
 
       /* about section: display credits */
     case SECTION_ABOUT:
-      about_draw (is_main_menu_enabled);
+      about_draw ();
       break;
 
       /* order section: display license information */
@@ -470,12 +462,7 @@ static void
 destroy (void)
 {
   Uint32 i;
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "menu_sections.c/destroy()\n");
-    }
-#endif
+  LOG_DBG ("Release memory used by the menu sections");
   if (about_string != NULL)
     {
       sprites_string_delete (about_string);
@@ -531,7 +518,7 @@ game_over_initialize (Sint32 rank)
 {
   Uint32 index = 0;
   Uint32 angle = 0;
-  Uint32 inc_angle = 1;
+  Sint32 inc_angle = 1;
   Uint32 xradius = 200;
   Uint32 yradius = 160;
   Uint32 i = 0;
@@ -589,8 +576,7 @@ high_scores_initialize ()
                                                            **));
       if (scores_chars_sprites == NULL)
         {
-          fprintf (stderr, "(!)menu_sections.c/high_scores_initialize(): "
-                   "allocation of 'scores_chars_sprites' failed!\n");
+          LOG_ERR ("allocation of 'scores_chars_sprites' failed!");
           return FALSE;
         }
     }
@@ -604,8 +590,7 @@ high_scores_initialize ()
                                                       **));
       if (scores_strings == NULL)
         {
-          fprintf (stderr, "(!)menu_sections.c/high_scores_initialize(): "
-                   "allocation of 'scores_strings' failed!\n");
+          LOG_ERR ("allocation of 'scores_strings' failed!");
           return FALSE;
         }
     }
@@ -618,19 +603,18 @@ high_scores_initialize ()
         {
           scores_strings[str_index] =
             sprites_string_create (str, strlen (str), FONT_GAME,
-                                   SCORE_TABLE_XCOORD1, ycoord);
+                                   SCORE_TABLE_XCOORD1, (float) ycoord);
           if (scores_strings[str_index] == NULL)
             {
-              fprintf (stderr, "(!)menu_sections.c/high_scores_initialize(): "
-                       "allocation of 'sprite_string_struct' failed!\n");
+              LOG_ERR ("allocation of 'sprite_string_struct' failed!");
               return FALSE;
             }
         }
       else
         {
           scores_strings[str_index]->coord_x = SCORE_TABLE_XCOORD1;
-          scores_strings[str_index]->coord_y = ycoord;
-          sprite_string_set_char (scores_strings[str_index], str);
+          scores_strings[str_index]->coord_y = (float) ycoord;
+          /* sprite_string_set_char (scores_strings[str_index], str); */
         }
 
       ycoord += SCORE_TABLE_VSPACE;
@@ -650,18 +634,17 @@ high_scores_initialize ()
         {
           scores_strings[str_index] =
             sprites_string_new (high_scores_values, 0, FONT_GAME,
-                                SCORE_TABLE_XCOORD2, ycoord);
+                                SCORE_TABLE_XCOORD2, (float) ycoord);
           if (scores_strings[str_index] == NULL)
             {
-              fprintf (stderr, "(!)menu_sections.c/high_scores_initialize(): "
-                       "allocation of 'sprite_string_struct' failed!\n");
+              LOG_ERR ("allocation of 'sprite_string_struct' failed!");
               return FALSE;
             }
         }
       else
         {
           scores_strings[str_index]->coord_x = SCORE_TABLE_XCOORD2;
-          scores_strings[str_index]->coord_y = ycoord;
+          scores_strings[str_index]->coord_y = (float) ycoord;
           sprite_string_set_char (scores_strings[str_index],
                                   high_scores_values);
         }
@@ -782,64 +765,60 @@ high_scores_sort (void)
 static char *
 high_scores_load_file (void)
 {
-  Sint32 fhandle;
-  struct stat sb;
+  size_t fsize;
+  FILE *fstream;
   char *filedata;
-#ifdef WIN32
-  fhandle = open (score_filenames[power_conf->difficulty],
-                  O_RDONLY | O_BINARY, 0);
-#else
-  fhandle = open (score_filenames[power_conf->difficulty], O_RDONLY, 0);
+  const char *filename = score_filenames[power_conf->difficulty];
+#if defined(_WIN32_WCE)
+  char *pathname = locate_data_file (filename);
+  if (pathname == NULL)
+    {
+      LOG_ERR ("can't locate file: %s", filename);
+      return FALSE;
+    }
+  filename = pathname;
 #endif
-  if (fhandle == -1)
+
+  fstream = fopen (filename, "rb");
+#if defined(_WIN32_WCE)
+  free_memory (pathname);
+#endif
+  if (fstream == NULL)
     {
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load_file() "
-               "open(%s) return %s\n",
-               score_filenames[power_conf->difficulty], strerror (errno));
-      return NULL;
-    }
-  if (fstat (fhandle, &sb))
-    {
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load_file() "
-               "fstat(%s) return %s\n",
-               score_filenames[power_conf->difficulty], strerror (errno));
+#if defined(_WIN32_WCE)
+      LOG_ERR ("fopen(%s) failed", filename);
+#else
+      LOG_ERR ("fopen(%s) return %s", filename, strerror (errno));
+#endif
       return NULL;
     }
+  fsize = get_file_size (fstream);
   /* fix by Andrey Bogomolov, prevent segmentation
    * fault if file is empty under FreeBSD 6.2! */
-  if (sb.st_size == 0)
+  if (fsize == 0)
     {
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load_file() "
-               "%s file is empty!\n",
-               score_filenames[power_conf->difficulty]);
+      LOG_ERR ("%s file is empty!", filename);
       return NULL;
     }
   /* allocate memory for the file data */
-  filedata = memory_allocation (sb.st_size);
+  filedata = memory_allocation (fsize);
   if (filedata == NULL)
     {
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load_file()"
-               "no enough memory to allocate %i bytes\n",
-               (Sint32) sb.st_size);
+      LOG_ERR ("no enough memory to allocate %i bytes", (Sint32) fsize);
       return NULL;
     }
-  if (read (fhandle, filedata, sb.st_size) != sb.st_size)
+  if (fread (filedata, sizeof (char), fsize, fstream) != fsize)
     {
       free_memory (filedata);
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load_file() "
-               "read(%s) return %s\n",
-               score_filenames[power_conf->difficulty], strerror (errno));
+#if defined(_WIN32_WCE)
+      LOG_ERR ("fread(%s) failed", filename);
+#else
+      LOG_ERR ("fread(%s) return %s", filename, strerror (errno));
+#endif
       return NULL;
     }
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "menu_sections.c/high_scores_load_file()"
-               "file \"%s\" was loaded in memory\n",
-               score_filenames[power_conf->difficulty]);
-    }
-#endif
-  close (fhandle);
+  LOG_DBG ("file \"%s\" was loaded in memory", filename);
+  fclose (fstream);
   return filedata;
 }
 
@@ -878,21 +857,20 @@ high_scores_load (void)
   ptr32 = (Sint32 *) ptr8;
   for (i = 0; i < MAX_OF_HIGH_SCORES; i++)
     {
-      //high_scores_points[i] = *(ptr32++);
       high_scores_points[i] = little_endian_to_int (ptr32++);
     }
 
   /* file checksum */
   sum2 = little_endian_to_int (ptr32);
   sum1 =
-    generate_byte_checksum ((unsigned char*)filedata, SIZE_OF_SCORES_FILE - sizeof (Sint32));
+    generate_byte_checksum ((unsigned char *) filedata,
+                            SIZE_OF_SCORES_FILE - sizeof (Sint32));
 
   /* file corrupt: create a new high score table */
   if (sum2 != sum1)
     {
-      fprintf (stderr, "(!)menu_sections.c/high_scores_load(): "
-               "high score table: bad checksum read:%i != generate:%i "
-               "/ read:%x != generate:%x\n", sum2, sum1, sum2, sum1);
+      LOG_ERR ("high score table: bad checksum read:%i != generate:%i "
+               "/ read:%x != generate:%x", sum2, sum1, sum2, sum1);
       high_scores_create ();
     }
   free_memory (filedata);
@@ -932,18 +910,19 @@ high_score_save (void)
 {
   Sint32 sum;
   Uint32 i, j;
-  Uint32 fhandle;
   Sint32 *buffer32;
   char *filedata, *buffer;
+#if defined(_WIN32_WCE)
+  char *pathname;
+#endif
+  const char *filename = score_filenames[power_conf->difficulty];
 
   /* allocate a temporary buffer */
   filedata = memory_allocation (SIZE_OF_SCORES_FILE);
   if (filedata == NULL)
     {
-      fprintf (stderr,
-               "(!)menu_sections.c/high_score_save() "
-               "not enough memory to allocate %i "
-               " bytes!\n", SIZE_OF_SCORES_FILE);
+      LOG_ERR ("not enough memory to allocate %i "
+               " bytes!", (Uint32) (SIZE_OF_SCORES_FILE));
       return;
     }
 
@@ -959,55 +938,35 @@ high_score_save (void)
   buffer32 = (Sint32 *) buffer;
   for (i = 0; i < MAX_OF_HIGH_SCORES; i++)
     {
-      //*(buffer32++) = high_scores_points[i];
       int_to_little_endian (high_scores_points[i], buffer32++);
     }
   sum =
-    generate_byte_checksum ((unsigned char *)filedata, SIZE_OF_SCORES_FILE - sizeof (Sint32));
+    generate_byte_checksum ((unsigned char *) filedata,
+                            SIZE_OF_SCORES_FILE - sizeof (Sint32));
   int_to_little_endian (sum, buffer32);
 
-  /* set umask so that files are group-writable */
-#ifdef WIN32
-  _umask (0002);
-#else
-  umask (0002);
-#endif
-  fhandle =
-    open (score_filenames[power_conf->difficulty], O_WRONLY | O_CREAT, 00666);
-  if (fhandle == -1)
+#if defined(_WIN32_WCE)
+  pathname = locate_data_file (filename);
+  if (pathname == NULL)
     {
-      fprintf (stderr,
-               "(!)menu_sections.c/high_score_save() "
-               "open (%s) return: %s\n",
-               score_filenames[power_conf->difficulty], strerror (errno));
-      free_memory (filedata);
+      LOG_ERR ("can't locate file: %s", filename);
       return;
     }
-#ifdef WIN32
-  _write (fhandle, filedata, SIZE_OF_SCORES_FILE);
-#else
-  write (fhandle, filedata, SIZE_OF_SCORES_FILE);
+  filename = pathname;
 #endif
-  if (close (fhandle) != 0)
+  if (!file_write (filename, filedata, SIZE_OF_SCORES_FILE))
     {
-      fprintf (stderr,
-               "(!)menu_sections.c/high_score_save() "
-               "close (%s) return: %s\n",
-               score_filenames[power_conf->difficulty], strerror (errno));
-      free_memory (filedata);
-      return;
+      LOG_ERR ("file_write (%s) failed", filename);
     }
-
+  else
+    {
+      LOG_INF ("\"%s\" file was saved", filename);
+    }
+#if defined(_WIN32_WCE)
+  free_memory (pathname);
+#endif
   free_memory (filedata);
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "menu_sections.c/high_score_save() "
-               "file %s was saved\n",
-               score_filenames[power_conf->difficulty]);
-
-    }
-#endif
+  return;
 }
 
 /**
@@ -1024,31 +983,12 @@ generate_byte_checksum (unsigned char *buffer, Uint32 size)
   Sint32 val = 0;
   for (i = 0; i < size; i++)
     {
-      c = *(buffer++); 
+      c = *(buffer++);
       val += c;
     }
   return val;
 }
 
-/**
- * Generate checksum for the high score file and text order file
- * @param buffer Pointer to the buffer to generate checksum fot
- * @param size Size of the buffer
- * @return The checksum
- */
-/*
-static Sint32
-generate_checksum (Sint32 * buffer, Uint32 size)
-{
-  Uint32 i;
-  Sint32 val = 0;
-  for (i = 0; i < size; i++)
-    {
-      val |= *(buffer++);
-    }
-  return val;
-}*/
-
 /**
  * Game over: appearance of score table, input name, display 'GAME * OVER'
  * @input is_menu_enabled FALSE if main menu is disable, otherwise TRUE
@@ -1190,8 +1130,8 @@ high_scores_draw (void)
         for (i = 0; i < MAX_OF_HIGH_SCORES; i++, index++)
           {
             scores_strings[index]->coord_y =
-              ycoord + menu_coord_y - (offscreen_clipsize +
-                                       offscreen_height_visible);
+              (float) (ycoord + menu_coord_y - (offscreen_clipsize +
+                                                offscreen_height_visible));
             sprite_string_coords (scores_strings[index]);
             sprite_string_anim (scores_strings[index], TRUE);
             sprite_string_draw (scores_strings[index]);
@@ -1202,8 +1142,8 @@ high_scores_draw (void)
         for (i = 0; i < MAX_OF_HIGH_SCORES; i++, index++)
           {
             scores_strings[index]->coord_y =
-              ycoord + menu_coord_y - (offscreen_clipsize +
-                                       offscreen_height_visible);
+              (float) (ycoord + menu_coord_y - (offscreen_clipsize +
+                                                offscreen_height_visible));
             sprite_string_coords (scores_strings[index]);
             sprite_string_anim (scores_strings[index], TRUE);
             sprite_string_draw (scores_strings[index]);
@@ -1284,8 +1224,7 @@ about_initialize (void)
     }
   if (about_string == NULL)
     {
-      fprintf (stderr, "(!)menu_sections.c/about_initialize(): "
-               "creation of 'about' sprites string failed\n");
+      LOG_ERR ("creation of 'about' sprites string failed");
       return FALSE;
     }
   sprite_string_init_anim (about_string, 1, 6, TRUE, 0);
@@ -1295,10 +1234,9 @@ about_initialize (void)
 
 /**
  * About section: draw and move chars
- * @input is_menu_enabled: FALSE if main menu is disable, otherwise TRUE
  */
 static void
-about_draw (bool is_menu_enabled)
+about_draw (void)
 {
   Uint32 i, font_type;
   Sint32 ycoord, xcoord;
@@ -1510,8 +1448,7 @@ order_initialize (void)
                                                       **));
       if (order_strings == NULL)
         {
-          fprintf (stderr, "(!)menu_sections.c/order_initialize(): "
-                   "allocation of 'order_strings' failed!\n");
+          LOG_ERR ("allocation of 'order_strings' failed!");
           return FALSE;
         }
     }
@@ -1523,8 +1460,7 @@ order_initialize (void)
         memory_allocation (KEYSTROKE_NUM_OF_LINES * KEYSTOKE_NUM_OF_COLS);
       if (order_text_data == NULL)
         {
-          fprintf (stderr, "(!)menu_sections.c/order_initialize(): "
-                   "not enough memory to allocate %i bytes!\n",
+          LOG_ERR ("not enough memory to allocate %i bytes!",
                    KEYSTROKE_NUM_OF_LINES * KEYSTOKE_NUM_OF_COLS);
           return FALSE;
         }
@@ -1542,12 +1478,11 @@ order_initialize (void)
       if (order_strings[i] == NULL)
         {
           order_strings[i] =
-            sprites_string_create (str, KEYSTOKE_NUM_OF_COLS, FONT_GAME, 128,
-                                   ycoord);
+            sprites_string_create (str, KEYSTOKE_NUM_OF_COLS, FONT_GAME,
+                                   128, (float) ycoord);
           if (order_strings[i] == NULL)
             {
-              fprintf (stderr, "(!)menu_sections.c/order_initialize(): "
-                       "allocation of 'sprite_string_struct' failed!\n");
+              LOG_ERR ("allocation of 'sprite_string_struct' failed!");
               return FALSE;
             }
           sprite_string_coords (order_strings[i]);
@@ -1559,8 +1494,7 @@ order_initialize (void)
   order_y_cursor = 0;
   if (!order_load_data ())
     {
-      fprintf (stderr, "menu_sections.c/order_initialize()"
-               "order_load_data() failed!\n");
+      LOG_ERR ("order_load_data() failed!");
       /* return FALSE; */
     }
   if (!order_cmd_type)
@@ -1592,7 +1526,7 @@ order_run (void)
   ycoord = menu_coord_y - offscreen_height_visible + 7;
   for (i = 0; i < KEYSTROKE_NUM_OF_LINES; i++)
     {
-      order_strings[i]->coord_y = ycoord;
+      order_strings[i]->coord_y = (float) ycoord;
       sprite_string_coords (order_strings[i]);
       ycoord += 16;
     }
@@ -1633,7 +1567,7 @@ order_run (void)
                 order_set_keycode (order_delay_counter);
                 order_delay_counter = 0;
               }
-            order_set_keycode (keycode);
+            order_set_keycode ((Sint16) keycode);
           }
         if (menu_status == MENU_ON || menu_status == MENU_UP)
           {
@@ -1670,7 +1604,7 @@ order_run (void)
                       }
                     else
                       {
-                        order_delay_counter = 30 + rand () % 30;
+                        order_delay_counter = (Sint16) (30 + rand () % 30);
                         if ((rand () % 100) < 25)
                           {
                             order_delay_counter += 20;
@@ -1878,7 +1812,7 @@ order_run (void)
  * Order section: clear all screen
  */
 static void
-order_clear_screen ()
+order_clear_screen (void)
 {
   char *c;
   Uint32 i;
@@ -1976,14 +1910,13 @@ order_load_data (void)
       ptr32 = (Sint32 *) order_keystroke;
       sum1 = little_endian_to_int (ptr32);
       sum2 =
-        generate_byte_checksum ((unsigned char *)(order_keystroke) + sizeof(Sint32),
-                           KEYSTROKE_SIZE_OF_FILE - sizeof(Sint32));
+        generate_byte_checksum ((unsigned char *) (order_keystroke) +
+                                sizeof (Sint32),
+                                KEYSTROKE_SIZE_OF_FILE - sizeof (Sint32));
       if (sum2 != sum1)
         {
-          fprintf (stderr, "menu_sections.c/order_load_data() "
-              "bad checksum read:%i != generate:%i"
-              " / read:%x != generate:%x \n",
-              sum1, sum2, sum1, sum2);
+          LOG_ERR ("bad checksum read:%i != generate:%i"
+                   " / read:%x != generate:%x", sum1, sum2, sum1, sum2);
           /* input text */
           current_phase = 0;
         }
@@ -2081,32 +2014,36 @@ order_release_data ()
 static void
 order_save_keystroke (void)
 {
+#if defined(_WIN32_WCE)
+  /* FIXME to implement */
+  LOG_ERR ("not implemented");
+#else
   Sint32 *ptr32;
   Sint32 filehandle;
+  Uint32 size = 0;
   Sint32 sum =
-    generate_byte_checksum ((unsigned char *)(order_keystroke) + sizeof(Sint32),
-                       KEYSTROKE_SIZE_OF_FILE - sizeof(Sint32));
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "menu_sections.c/order_save_keystroke() "
-               "checksum: %i\n", sum);
-    }
-#endif
+    generate_byte_checksum ((unsigned char *) (order_keystroke) +
+                            sizeof (Sint32),
+                            KEYSTROKE_SIZE_OF_FILE - sizeof (Sint32));
+  LOG_INF ("checksum: %i", sum);
   ptr32 = (Sint32 *) order_keystroke;
   int_to_little_endian (sum, ptr32);
   filehandle =
     open ("data/menu_order_keystrokes.bin", O_WRONLY | O_CREAT, 0666);
   if (filehandle == -1)
     {
-      fprintf (stderr, "order_save_keystroke(): \n"
-               "can't open file : \"menu_order_keystrokes.bin\"\n\n");
+      LOG_ERR ("can't open file : \"menu_order_keystrokes.bin\"");
     }
   else
     {
-      write (filehandle, order_keystroke, KEYSTROKE_SIZE_OF_FILE);
+      size = write (filehandle, order_keystroke, KEYSTROKE_SIZE_OF_FILE);
+      if (size != KEYSTROKE_SIZE_OF_FILE)
+        {
+          LOG_ERR ("write() return: %s", strerror (errno));
+        }
       close (filehandle);
     }
+#endif
 }
 
 /**
@@ -2130,7 +2067,7 @@ static Uint16
 order_get_keycode (void)
 {
   Uint16 val;
-  Uint32 val2;
+  Uint16 val2;
   if (!order_cmd_type)
     {
       val = (Uint16) order_keystroke[order_index++];
@@ -2138,13 +2075,7 @@ order_get_keycode (void)
         {
           order_clear_screen ();
           order_index = 2;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            {
-              fprintf (stdout, "- menu_sections.c/order_get_keycode(): "
-                       "end of file 'menu_order_keystrokes.bin'\n");
-            }
-#endif
+          LOG_DBG ("end of file 'menu_order_keystrokes.bin'");
         }
     }
   else
@@ -2160,13 +2091,7 @@ order_get_keycode (void)
         {
           order_clear_screen ();
           order_index = 2;
-#ifdef VERBOSE
-          if (power_conf->verbose)
-            {
-              fprintf (stdout, "- menu_sections.c/order_get_keycode(): "
-                       "end of file 'menu_order_keystrokes.bin'\n");
-            }
-#endif
+          LOG_DBG ("end of file 'menu_order_keystrokes.bin'");
         }
     }
   return val;
