@@ -2,11 +2,12 @@
  * @file menu_sections.h
  * @brief hanlde high score table, about and order menu sections 
  * @created 1998-06-29 
- * @date 2007-06-01
+ * @date 2012-08-26 
+ * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: menu_sections.h,v 1.4 2007/07/09 20:21:37 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: menu_sections.h,v 1.10 2012/08/26 15:44:26 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,24 +28,25 @@
 #define __MENU_SECTIONS__
 
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif
 
-typedef enum
-{
-   NO_SECTION_SELECTED,
-   SECTION_GAME_OVER,
-   SECTION_HIGH_SCORE,
-   SECTION_ABOUT,
-   SECTION_ORDER
-} SECTIONS_ENUM;
+  typedef enum
+  {
+    NO_SECTION_SELECTED,
+    SECTION_GAME_OVER,
+    SECTION_HIGH_SCORE,
+    SECTION_ABOUT,
+    SECTION_ORDER
+  } SECTIONS_ENUM;
 
-extern Uint32 menu_section;
-bool menu_sections_once_init (void);
-void menu_sections_free (void);
-void menu_sections_run ();
-bool menu_section_set (Uint32 section);
-bool is_playername_input ();
+  extern Uint32 menu_section;
+  bool menu_sections_once_init (void);
+  void menu_sections_free (void);
+  void menu_sections_run ();
+  bool menu_section_set (Uint32 section);
+  bool is_playername_input ();
 
 #ifdef __cplusplus
 }
