@@ -2,11 +2,11 @@
  * @file meteors_phase.h
  * @brief Handle the meteor storm 
  * @created 2006-11-28 
- * @date 2007-06-01
+ * @date 2009-01-11
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: meteors_phase.h,v 1.8 2007/07/09 20:21:37 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: meteors_phase.h,v 1.16 2012/06/03 17:06:15 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,18 +31,21 @@ extern "C"
 {
 #endif
 
-bool meteors_once_init (void);
-void meteors_free (void);
-bool meteors_load (Sint32 meteor_num);
-void meteors_handle (void);
-bool meteors_finished (void);
-void meteors_images_free (void);
+  bool meteors_once_init (void);
+  void meteors_free (void);
+  bool meteors_load (Sint32 meteor_num);
+#ifdef PNG_EXPORT_ENABLE
+  bool meteors_extract (void);
+#endif
+  void meteors_handle (void);
+  bool meteors_finished (void);
+  void meteors_images_free (void);
 
 /** Number of images of the meteors */
 #define METEOR_NUMOF_IMAGES 32
 
-extern Sint32 num_of_meteors;
-extern bool meteor_activity; 
+  extern Sint32 num_of_meteors;
+  extern bool meteor_activity;
 
 #ifdef __cplusplus
 }
