@@ -1,13 +1,13 @@
 /** 
  * @file options_panel.c 
  * @brief Handle right options panel 
- * @date 2007-09-02
+ * @date 2011-02-26 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: options_panel.c,v 1.16 2007/09/02 16:13:56 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: options_panel.c,v 1.29 2012/06/03 17:06:15 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
+#include "config_file.h"
 #include "tools.h"
 #include "images.h"
 #include "display.h"
@@ -35,6 +36,7 @@
 #include "shots.h"
 #include "extra_gun.h"
 #include "gfx_wrapper.h"
+#include "log_recorder.h"
 #include "options_panel.h"
 #include "satellite_protections.h"
 #include "sdl_mixer.h"
@@ -42,8 +44,18 @@
 
 /** Maximum number of images that can be combined in an option box */
 #define OPTION_BOX_MAX_IMAGES 33
+/** The numbers of different images multipliers scores */
+typedef enum
+{
+  MULTIPLIER_CLEAR,
+  MULTIPLIER_X2_RED,
+  MULTIPLIER_X2_YELLOW,
+  MULTIPLIER_X4_RED,
+  MULTIPLIER_X4_YELLOW,
+  MULTIPLIERS_NUM_OF_IMAGES
+} MULTIPLIERS_ENUM;
 /** Images data of the scores multiplier */
-static bitmap multiplier_bmp[5];
+static bitmap multiplier_bmp[MULTIPLIERS_NUM_OF_IMAGES];
 /** Structures data of the state of the options box */
 option option_boxes[OPTIONS_MAX_OF_TYPES];
 /** Images data of the options box */
@@ -57,9 +69,8 @@ bool option_change = FALSE;
 /** Tempo display for option selected */
 static Sint32 option_cursor_delay_count = 0;
 static Sint32 option_selected_pos = 0;
-/** Option box coordinates into the left panel  */
-static Uint32 pOptionsPositions[11][2] =
-{
+/** Option box (28 width x 28 height) coordinates into the left panel */
+static Uint32 options_positions[OPTIONS_PANEL_NUMOF][2] = {
   {260 - 256, 169 - 16},
   {290 - 256, 154 - 16},
   {260 - 256, 139 - 16},
@@ -72,6 +83,13 @@ static Uint32 pOptionsPositions[11][2] =
   {290 - 256, 34 - 16},
   {260 - 256, 19 - 16}
 };
+
+typedef struct options_collision_coord
+{
+  Sint32 x;
+  Sint32 y;
+} options_collision_coord;
+static options_collision_coord *options_collision = NULL;
 static bool options_load (void);
 static void option_selected_cursor (Sint32);
 static void option_close_playanim (Sint32);
@@ -111,8 +129,8 @@ options_once_init (void)
                                                    (option_change_coord));
       if (options_refresh == NULL)
         {
-          fprintf (stderr, "options_panel.c/options_once_init () "
-                   "options_refresh out of memory");
+          LOG_ERR ("not enough memory to alloc %i bytes!",
+                   sizeof (option_change_coord));
           return FALSE;
         }
     }
@@ -124,6 +142,28 @@ options_once_init (void)
       option_boxes[i].current_image = 0;
       option_boxes[i].next_image_pause_cnt = 0;
     }
+
+  /* generates the table to test the collision of the mouse or stylus */
+  if (options_collision == NULL)
+    {
+      options_collision =
+        (options_collision_coord *) memory_allocation (OPTIONS_PANEL_NUMOF *
+                                                       sizeof
+                                                       (options_collision_coord));
+      if (options_collision == NULL)
+        {
+          LOG_ERR ("not enough memory to alloc %i bytes!",
+                   sizeof (options_collision_coord));
+          return FALSE;
+        }
+      for (i = 0; i < OPTIONS_PANEL_NUMOF; i++)
+        {
+          options_collision[i].x =
+            options_positions[i][0] + offscreen_width_visible;
+          options_collision[i].y =
+            options_positions[i][1] + score_offscreen_height;
+        }
+    }
   options_close_all ();
   return TRUE;
 }
@@ -145,11 +185,26 @@ options_load (void)
 
   /* extract box options animations  bitmap images (387,761 bytes) */
   if (!bitmap_load ("graphics/bitmap/options_panel_anims.spr",
-                    &options[0][0], OPTIONS_MAX_OF_TYPES, OPTION_BOX_MAX_IMAGES, 32))
+                    &options[0][0], OPTIONS_MAX_OF_TYPES,
+                    OPTION_BOX_MAX_IMAGES))
     {
       return FALSE;
     }
 
+  /* extract score multipliers bitmap images (760 bytes) */
+  if (!bitmap_load
+      ("graphics/bitmap/scores_multiplier.spr", &multiplier_bmp[0], 1,
+       MULTIPLIERS_NUM_OF_IMAGES))
+    {
+      return FALSE;
+    }
+
+  if (power_conf->extract_to_png)
+    {
+      return TRUE;
+    }
+
+  /* modifies the display offsets of box animations */
   for (i = 0; i < OPTIONS_MAX_OF_TYPES; i++)
     {
       for (j = 0; j < OPTION_BOX_MAX_IMAGES; j++)
@@ -173,12 +228,9 @@ options_load (void)
           while (--size > 0);
         }
     }
-  /* extract scores multiplier bitmap images (760 bytes) */
-  if (!bitmap_load ("graphics/bitmap/scores_multiplier.spr", &multiplier_bmp[0], 1, 5, 1))
-    {
-      return FALSE;
-    }
-  for (j = 0; j < 5; j++)
+
+  /* modifies the display offsets of score multipliers */
+  for (j = 0; j < MULTIPLIERS_NUM_OF_IMAGES; j++)
     {
       bmp = &multiplier_bmp[j];
       repeats = (Uint32 *) bmp->compress;
@@ -201,19 +253,87 @@ options_load (void)
   return TRUE;
 }
 
+/**
+ * Convert menu items from data bitmaps to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+options_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/options/option-xx/option-xx.png";
+  //const char *model = EXPORT_DIR "/multipliers/multiplier-x.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/options"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < OPTIONS_MAX_OF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/options/option-%02d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < OPTION_BOX_MAX_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/options/option-%02d/option-%02d.png",
+                   type + 1, frame);
+          if (!bitmap_to_png (&options[type][frame], filename, 28, 28, 320))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  if (!create_dir (EXPORT_DIR "/multipliers"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (frame = 0; frame < MULTIPLIERS_NUM_OF_IMAGES; frame++)
+    {
+      sprintf (filename, EXPORT_DIR "/multipliers/multiplier-%1d", frame);
+      if (!bitmap_to_png (&multiplier_bmp[frame], filename, 14, 8, 320))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /** 
  * Free some options panel data
  */
 void
 options_free (void)
 {
-  bitmap_free (&options[0][0], OPTIONS_MAX_OF_TYPES, OPTION_BOX_MAX_IMAGES, OPTION_BOX_MAX_IMAGES);
+  bitmap_free (&options[0][0], OPTIONS_MAX_OF_TYPES, OPTION_BOX_MAX_IMAGES,
+               OPTION_BOX_MAX_IMAGES);
   bitmap_free (&multiplier_bmp[0], 1, 5, 5);
   if (options_refresh != NULL)
     {
       free_memory ((char *) options_refresh);
       options_refresh = NULL;
     }
+  if (options_collision != NULL)
+    {
+      free_memory ((char *) options_collision);
+      options_collision = NULL;
+    }
 }
 
 /** 
@@ -237,11 +357,11 @@ option_execution (void)
         {
           /* clear the number of bonus collected */
           ship->gems_count = 0;
-          if(!gun_add ()) 
-           {
-                /* cannot install more than 2 guns */
-           }
-       }
+          if (!gun_add ())
+            {
+              /* cannot install more than 2 guns */
+            }
+        }
       /* change the option box selected */
       option_selected_pos = ship->gems_count;
       option_change = FALSE;
@@ -476,8 +596,26 @@ void
 options_check_selected (void)
 {
   spaceship_struct *ship = spaceship_get ();
-  if ((keys_down[K_CTRL] || option_button_down) && option_selected_pos
-      && !option_button_pressed)
+  bool leftb = FALSE;
+
+  /* detects the collision of the stylus or the mouse 
+   * in the options panel */
+  if (option_selected_pos > 0 && mouse_b == 1)
+    {
+      if (mouse_x >= options_collision[option_selected_pos - 1].x &&
+          mouse_x < options_collision[option_selected_pos - 1].x + OPTION_SIZE
+          && mouse_y >= options_collision[option_selected_pos - 1].y
+          && mouse_y <
+          options_collision[option_selected_pos - 1].y + OPTION_SIZE)
+        {
+          leftb = TRUE;
+        }
+    }
+
+  if ((keys_down[K_CTRL] || option_button_down || leftb)
+      && option_selected_pos > 0 && !option_button_pressed)
+
+
     {
       switch (option_selected_pos)
         {
@@ -513,7 +651,9 @@ options_check_selected (void)
               /* increase energy level */
               ship->spr.energy_level += 20;
               if (ship->spr.energy_level > ship->spr.pow_of_dest)
-                ship->spr.energy_level = ship->spr.pow_of_dest;
+                {
+                  ship->spr.energy_level = ship->spr.pow_of_dest;
+                }
               energy_gauge_spaceship_is_update = TRUE;
               ship->gems_count = 0;
               option_change = TRUE;
@@ -846,14 +986,18 @@ options_check_selected (void)
       if (score_multiplier_clear == 2)
         {
           /* clear X4 score multiplier */
-          draw_bitmap_in_options (&multiplier_bmp[0], 41, 5);
+          draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_CLEAR],
+                                  SCORE_MULTIPLIER_XCOORD,
+                                  SCORE_MULTIPLIER_TROP_YCOORD);
           score_x4_refresh = TRUE;
           score_multiplier_clear--;
         }
       if (score_multiplier_clear == 1)
         {
           /* clear X2 score multiplier */
-          draw_bitmap_in_options (&multiplier_bmp[0], 41, 171);
+          draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_CLEAR],
+                                  SCORE_MULTIPLIER_XCOORD,
+                                  SCORE_MULTIPLIER_BOTTOM_YCOORD);
           score_x2_refresh = TRUE;
           score_multiplier_clear--;
         }
@@ -867,12 +1011,16 @@ options_check_selected (void)
           /* display in red */
           if (aff_x4_rj & 1)
             {
-              draw_bitmap_in_options (&multiplier_bmp[3], 41, 5);
+              draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_X4_RED],
+                                      SCORE_MULTIPLIER_XCOORD,
+                                      SCORE_MULTIPLIER_TROP_YCOORD);
             }
           /* display in yellow */
           else
             {
-              draw_bitmap_in_options (&multiplier_bmp[4], 41, 5);
+              draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_X4_YELLOW],
+                                      SCORE_MULTIPLIER_XCOORD,
+                                      SCORE_MULTIPLIER_TROP_YCOORD);
             }
           aff_x4_rj++;
         }
@@ -886,18 +1034,24 @@ options_check_selected (void)
           /* display in red */
           if (aff_x2_rj & 1)
             {
-              draw_bitmap_in_options (&multiplier_bmp[1], 41, 171);
+              draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_X2_RED],
+                                      SCORE_MULTIPLIER_XCOORD,
+                                      SCORE_MULTIPLIER_BOTTOM_YCOORD);
             }
           /* display in yellow */
           else
             {
-              draw_bitmap_in_options (&multiplier_bmp[2], 41, 171);
+              draw_bitmap_in_options (&multiplier_bmp[MULTIPLIER_X2_YELLOW],
+                                      SCORE_MULTIPLIER_XCOORD,
+                                      SCORE_MULTIPLIER_BOTTOM_YCOORD);
             }
           aff_x2_rj++;
           /* clear X4 score multiplier */
           if (score_multiplier == 1)
             {
-              draw_bitmap_in_options (&multiplier_bmp[0], 41, 5);
+              draw_bitmap_in_options (&multiplier_bmp[0],
+                                      SCORE_MULTIPLIER_XCOORD,
+                                      SCORE_MULTIPLIER_TROP_YCOORD);
             }
         }
       cmpt_vbls_x2++;
@@ -917,8 +1071,10 @@ option_box_animation (Sint32 num_option)
   Sint32 coord_y;
 
   bitmap *img;
-  option_boxes[num_option].next_image_pause_cnt +=
-    option_boxes[num_option].next_image_pause_offset;
+  option_boxes[num_option].next_image_pause_cnt =
+    (Sint16) (option_boxes[num_option].next_image_pause_cnt +
+              option_boxes[num_option].next_image_pause_offset);
+
   if (option_boxes[num_option].next_image_pause_cnt >=
       option_boxes[num_option].next_image_pause)
     {
@@ -932,8 +1088,8 @@ option_box_animation (Sint32 num_option)
         }
     }
   img = &options[num_option][option_boxes[num_option].current_image];
-  coord_x = pOptionsPositions[num_option][0];
-  coord_y = pOptionsPositions[num_option][1];
+  coord_x = options_positions[num_option][0];
+  coord_y = options_positions[num_option][1];
 
   /* display option box image */
   draw_bitmap_in_options (img, coord_x, coord_y);
@@ -1023,8 +1179,8 @@ option_clear (Sint32 num_option)
         }
       break;
     }
-  coord_x = pOptionsPositions[num_option][0];
-  coord_y = pOptionsPositions[num_option][1];
+  coord_x = options_positions[num_option][0];
+  coord_y = options_positions[num_option][1];
   draw_bitmap_in_options (img, coord_x, coord_y);
   options_refresh[++opt_refresh_index].coord_x = coord_x;
   options_refresh[opt_refresh_index].coord_y = coord_y;
@@ -1039,8 +1195,9 @@ option_close_playanim (Sint32 num_option)
 {
   Sint32 coord_x;
   Sint32 coord_y;
-  option_boxes[num_option].next_image_pause_cnt +=
-    option_boxes[num_option].next_image_pause_offset;
+  option_boxes[num_option].next_image_pause_cnt =
+    (Sint16) (option_boxes[num_option].next_image_pause_cnt +
+              option_boxes[num_option].next_image_pause_offset);
   if (option_boxes[num_option].next_image_pause_cnt >=
       option_boxes[num_option].next_image_pause)
     {
@@ -1055,10 +1212,11 @@ option_close_playanim (Sint32 num_option)
     }
   /* state of the option box is currently closing */
   option_boxes[num_option].close_option = 1;
-  coord_x = pOptionsPositions[num_option][0];
-  coord_y = pOptionsPositions[num_option][1];
-  draw_bitmap_in_options (&options[11][option_boxes[num_option].current_image], coord_x,
-                  coord_y);
+  coord_x = options_positions[num_option][0];
+  coord_y = options_positions[num_option][1];
+  draw_bitmap_in_options (&options[11]
+                          [option_boxes[num_option].current_image], coord_x,
+                          coord_y);
   options_refresh[++opt_refresh_index].coord_x = coord_x;
   options_refresh[opt_refresh_index].coord_y = coord_y;
 }
@@ -1076,8 +1234,9 @@ option_open_playanim (Sint32 num_option)
 
   num_ouverture = 12;
   /* incrase delay counter */
-  option_boxes[num_option].next_image_pause_cnt +=
-    option_boxes[num_option].next_image_pause_offset;
+  option_boxes[num_option].next_image_pause_cnt =
+    (Sint16) (option_boxes[num_option].next_image_pause_cnt +
+              option_boxes[num_option].next_image_pause_offset);
   if (option_boxes[num_option].next_image_pause_cnt >=
       option_boxes[num_option].next_image_pause)
     {
@@ -1095,10 +1254,11 @@ option_open_playanim (Sint32 num_option)
     }
   /* state of the option box is currently opening */
   option_boxes[num_option].close_option = 0;
-  coord_x = pOptionsPositions[num_option][0];
-  coord_y = pOptionsPositions[num_option][1];
+  coord_x = options_positions[num_option][0];
+  coord_y = options_positions[num_option][1];
   draw_bitmap_in_options (&options[num_ouverture]
-                  [option_boxes[num_option].current_image], coord_x, coord_y);
+                          [option_boxes[num_option].current_image], coord_x,
+                          coord_y);
   options_refresh[++opt_refresh_index].coord_x = coord_x;
   options_refresh[opt_refresh_index].coord_y = coord_y;
 }
@@ -1136,8 +1296,8 @@ option_selected_cursor (Sint32 num_option)
   Sint32 coord_y;
   if (((option_cursor_delay_count++) & 7) > 4)
     {
-      coord_x = pOptionsPositions[num_option][0];
-      coord_y = pOptionsPositions[num_option][1];
+      coord_x = options_positions[num_option][0];
+      coord_y = options_positions[num_option][1];
       draw_bitmap_in_options (&options[11][32], coord_x, coord_y);
       options_refresh[++opt_refresh_index].coord_x = coord_x;
       options_refresh[opt_refresh_index].coord_y = coord_y;
@@ -1162,12 +1322,12 @@ options_close_all (void)
  * @param except Option number not to be opened
  */
 void
-options_open_all (Sint32 except)
+options_open_all (Sint32 opt_except)
 {
   Sint32 i;
   for (i = 0; i < OPTIONS_PANEL_NUMOF; i++)
     {
-      if (except == i) 
+      if (opt_except == i)
         {
           continue;
         }
