@@ -4,13 +4,13 @@
  *        player's spaceship and protect it from hostiles shots
  *        and enemies
  * @created 2006-11-10 
- * @date 2007-08-22
+ * @date 2012-08-25 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: satellite_protections.c,v 1.18 2007/08/24 07:55:17 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: satellite_protections.c,v 1.29 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -39,6 +39,7 @@
 #include "energy_gauge.h"
 #include "explosions.h"
 #include "gfx_wrapper.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "options_panel.h"
 #include "shots.h"
@@ -53,8 +54,8 @@
 /** Maximum number of images peer satellite */
 #define SATELLITES_NUMOF_IMAGES 16
 
-/* 
- * structure of the orbital satellite protections 
+/** 
+ * Structure of an orbital satellite protection
  */
 typedef struct satellite_struct
 {
@@ -110,7 +111,8 @@ static satellite_struct *satellite_get (void);
 bool
 satellites_once_init (void)
 {
-  Sint32 i, x, y, r;
+  Sint32 i, r;
+  Sint16 x, y;
   double a, step, pi;
   satellites_free ();
 
@@ -130,9 +132,7 @@ satellites_once_init (void)
                                                 sizeof (satellite_struct));
       if (satellites == NULL)
         {
-          fprintf (stderr,
-                   "(!)satellite_protections.c/satellites_once_init() "
-                   "not enough memory to allocate 'satellites'");
+          LOG_ERR ("not enough memory to allocate 'satellites'");
           return FALSE;
         }
     }
@@ -144,9 +144,7 @@ satellites_once_init (void)
                                       sizeof (Sint16));
       if (satellite_circle_x == NULL)
         {
-          fprintf (stderr,
-                   "(!)satellite_protections.c/satellites_once_init() "
-                   "not enough memory to allocate 'satellite_circle_x'");
+          LOG_ERR ("not enough memory to allocate 'satellite_circle_x'");
           return FALSE;
         }
       satellite_circle_y = satellite_circle_x + SATELLITE_NUMOF_POINTS_CIRCLE;
@@ -161,8 +159,8 @@ satellites_once_init (void)
   step = (pi * 2) / SATELLITE_NUMOF_POINTS_CIRCLE;
   for (i = 0; i < SATELLITE_NUMOF_POINTS_CIRCLE; i++)
     {
-      x = (Sint32) (cos (a) * r);
-      y = (Sint32) (sin (a) * r);
+      x = (Sint16) (cos (a) * r);
+      y = (Sint16) (sin (a) * r);
       a = a + step;
       satellite_circle_x[i] = x;
       satellite_circle_y[i] = y;
@@ -172,19 +170,60 @@ satellites_once_init (void)
   return TRUE;
 }
 
+/**
+ * Convert satellite from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+satellite_extract (void)
+{
+  Uint32 type, frame;
+  const char *model =
+    EXPORT_DIR "/satellites/satellite-%01d/satellite-%01d.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/satellites"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < SATELLITES_NUMOF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/satellites/satellite-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < SATELLITES_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/satellites/satellite-%01d/satellite-%01d.png",
+                   type + 1, frame);
+          if (!image_to_png (&satellites_images[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  return TRUE;
+}
+#endif
+
 /** 
  * Release memory used for the satellites 
  */
 void
 satellites_free (void)
 {
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "> satellite_protections.c/satellites_free(): "
-               "deallocates the memory used by the bitmap and structure\n");
-    }
-#endif
+  LOG_DBG ("deallocates the memory used by the bitmap and structure");
   images_free (&satellites_images[0][0], SATELLITES_NUMOF_TYPES,
                SATELLITES_NUMOF_IMAGES, SATELLITES_NUMOF_IMAGES);
   if (satellites != NULL)
@@ -243,8 +282,7 @@ satellites_handle (void)
 #ifdef UNDER_DEVELOPMENT
       if (sat == NULL && i < (num_of_satellites - 1))
         {
-          fprintf (stderr, "(!)satellite_protections.c/satellites_handle(): "
-                   "sat->next is null %i/%i\n", i, num_of_satellites);
+          LOG_ERR ("sat->next is null %i/%i", i, num_of_satellites);
           break;
         }
 #endif
@@ -277,7 +315,8 @@ satellites_handle (void)
               /* reset shot time-frequency */
               sat->fire_rate_count = sat->fire_rate;
               /* process each origin of the shot (location of the cannon) */
-              for (k = 0; k < sat->img[sat->current_image]->numof_cannons; k++)
+              for (k = 0; k < sat->img[sat->current_image]->numof_cannons;
+                   k++)
                 {
                   shot_satellite_add (sat->xcoord +
                                       sat->img[sat->current_image]->
@@ -413,7 +452,9 @@ satellite_add (void)
 void
 satellites_setup (void)
 {
-  Uint32 step, i, pos;
+  Sint32 i;
+  Sint16 step;
+  Sint16 pos;
   satellite_struct *sat;
   if (num_of_satellites < 1)
     {
@@ -424,15 +465,15 @@ satellites_setup (void)
     {
       return;
     }
-  step = SATELLITE_NUMOF_POINTS_CIRCLE / num_of_satellites;
+  step = (Sint16) (SATELLITE_NUMOF_POINTS_CIRCLE / num_of_satellites);
   pos = 0;
-  for (i = 0; i < num_of_satellites; i++, sat = sat->next, pos += step)
+  for (i = 0; i < num_of_satellites;
+       i++, sat = sat->next, pos = (Sint16) (pos + step))
     {
 #ifdef UNDER_DEVELOPMENT
       if (sat == NULL && i < (num_of_satellites - 1))
         {
-          fprintf (stderr, "(!)satellite_protections.c/satellites_setup(): "
-                   "sat->next is null %i/%i\n", i, num_of_satellites);
+          LOG_ERR ("sat->next is null %i/%i", i, num_of_satellites);
           break;
         }
 #endif
@@ -450,7 +491,7 @@ satellite_check_chained_list (void)
 {
   Uint32 i;
   satellite_struct *sat;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < SATELLITES_MAXOF; i++)
     {
       sat = &satellites[i];
@@ -461,10 +502,8 @@ satellite_check_chained_list (void)
     }
   if (count != num_of_satellites)
     {
-      fprintf (stderr, "(!)satellite_protections.c/"
-               "satellite_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, =%i\n", count, num_of_satellites);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, =%i", count, num_of_satellites);
     }
   count = 0;
   sat = satellite_first;
@@ -476,10 +515,8 @@ satellite_check_chained_list (void)
   while (sat != NULL && count <= (SATELLITES_MAXOF + 1));
   if (count != num_of_satellites)
     {
-      fprintf (stderr, "(!)satellite_protections.c/"
-               "satellite_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_satellites=%i\n", count, num_of_satellites);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_satellites=%i", count, num_of_satellites);
     }
   count = 0;
   sat = satellite_last;
@@ -491,10 +528,8 @@ satellite_check_chained_list (void)
   while (sat != NULL && count <= (SATELLITES_MAXOF + 1));
   if (count != num_of_satellites)
     {
-      fprintf (stderr, "(!)satellite_protections.c/"
-               "satellite_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_satellites=%i\n", count, num_of_satellites);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_satellites=%i", count, num_of_satellites);
     }
 }
 #endif
@@ -535,8 +570,7 @@ satellite_get (void)
 #endif
       return sat;
     }
-  fprintf (stderr, "(!)satellite_protections.c/satellite_get() "
-           "no more element char is available\n");
+  LOG_ERR ("no more element char is available");
   return NULL;
 }
 
@@ -593,9 +627,7 @@ satellites_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
 #ifdef UNDER_DEVELOPMENT
       if (sat == NULL && i < (num_of_satellites - 1))
         {
-          fprintf (stderr,
-                   "(!)satellite_protections.c/satellites_enemy_collisions(): "
-                   "sat->next is null %i/%i\n", i, num_of_satellites);
+          LOG_ERR ("sat->next is null %i/%i", i, num_of_satellites);
           break;
         }
 #endif
@@ -606,44 +638,56 @@ satellites_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
         }
 
       /* for each collision point of the satellite */
-      for (l = 0; l < sat->img[sat->current_image]->numof_collisions_points; l++)
+      for (l = 0; l < sat->img[sat->current_image]->numof_collisions_points;
+           l++)
         {
           /* coordinates of the collision point of the satellite */
           x1 =
-            sat->xcoord + sat->img[sat->current_image]->collisions_points[l][XCOORD];
+            sat->xcoord +
+            sat->img[sat->current_image]->collisions_points[l][XCOORD];
           y1 =
-            sat->ycoord + sat->img[sat->current_image]->collisions_points[l][YCOORD];
+            sat->ycoord +
+            sat->img[sat->current_image]->collisions_points[l][YCOORD];
 
           /* for each collision zone of the enemy */
-          for (m = 0; m < foe->spr.img[foe->spr.current_image]->numof_collisions_zones; m++)
+          for (m = 0;
+               m <
+               foe->spr.img[foe->spr.current_image]->numof_collisions_zones;
+               m++)
             {
               /* coordinates of the collision zone of the enemy */
               x2 =
                 (Sint32) foe->spr.xcoord +
-                foe->spr.img[foe->spr.current_image]->collisions_coords[m][XCOORD];
+                foe->spr.img[foe->spr.
+                             current_image]->collisions_coords[m][XCOORD];
               y2 =
                 (Sint32) foe->spr.ycoord +
-                foe->spr.img[foe->spr.current_image]->collisions_coords[m][YCOORD];
+                foe->spr.img[foe->spr.
+                             current_image]->collisions_coords[m][YCOORD];
 
               /* check if satellite collision point is into enemy collision zone */
               if (x1 >= x2 &&
                   y1 >= y2 &&
                   x1 <
                   (x2 +
-                   foe->spr.img[foe->spr.current_image]->collisions_sizes[m][IMAGE_WIDTH])
+                   foe->spr.img[foe->spr.
+                                current_image]->collisions_sizes[m]
+                   [IMAGE_WIDTH])
                   && y1 <
                   (y2 +
                    foe->spr.img[foe->spr.current_image]->
                    collisions_sizes[m][IMAGE_HEIGHT]))
                 {
                   /* decrease energy level of enemy */
-                  foe->spr.energy_level -= sat->pow_of_dest;
+                  foe->spr.energy_level =
+                    (Sint16) (foe->spr.energy_level - sat->pow_of_dest);
                   if (foe->type >= THANIKEE)
                     {
                       energy_gauge_guard_is_update = TRUE;
                     }
                   /* decrease energy level of satellite */
-                  sat->energy_level -= foe->spr.pow_of_dest;
+                  sat->energy_level =
+                    (Sint16) (sat->energy_level - foe->spr.pow_of_dest);
                   /* check if satellite is destroyed */
                   if (sat->energy_level <= 0)
                     {
@@ -670,10 +714,12 @@ satellites_enemy_collisions (enemy * foe, Sint32 num_of_fragments)
                           if (num_of_fragments > 0)
                             {
                               explosions_fragments_add (foe->spr.xcoord +
-                                                        foe->spr.img[foe->spr.current_image]->
+                                                        foe->spr.img[foe->
+                                                                     spr.current_image]->
                                                         x_gc - 8,
                                                         foe->spr.ycoord +
-                                                        foe->spr.img[foe->spr.current_image]->
+                                                        foe->spr.img[foe->
+                                                                     spr.current_image]->
                                                         y_gc - 8, 1.0,
                                                         num_of_fragments, 0,
                                                         2);
@@ -729,9 +775,7 @@ satellites_shot_collisions (Sint32 x1, Sint32 y1, shot_struct * projectile)
 #ifdef UNDER_DEVELOPMENT
       if (sat == NULL && i < (num_of_satellites - 1))
         {
-          fprintf (stderr,
-                   "(!)satellite_protections.c/satellites_shot_collisions(): "
-                   "sat->next is null %i/%i\n", i, num_of_satellites);
+          LOG_ERR ("sat->next is null %i/%i", i, num_of_satellites);
           break;
         }
 #endif
@@ -742,25 +786,31 @@ satellites_shot_collisions (Sint32 x1, Sint32 y1, shot_struct * projectile)
           continue;
         }
       /* for each collision point of the satellite */
-      for (m = 0; m < sat->img[sat->current_image]->numof_collisions_zones; m++)
+      for (m = 0; m < sat->img[sat->current_image]->numof_collisions_zones;
+           m++)
         {
           /* coordinates of the collision zone of the satellite */
           x2 =
-            sat->xcoord + sat->img[sat->current_image]->collisions_coords[m][XCOORD];
+            sat->xcoord +
+            sat->img[sat->current_image]->collisions_coords[m][XCOORD];
           y2 =
-            sat->ycoord + sat->img[sat->current_image]->collisions_coords[m][YCOORD];
+            sat->ycoord +
+            sat->img[sat->current_image]->collisions_coords[m][YCOORD];
 
           /* check if satellite collision point is into enemy collision zone */
           if (x1 >= x2 &&
               y1 >= y2 &&
               x1 <
-              (x2 + sat->img[sat->current_image]->collisions_sizes[m][IMAGE_WIDTH])
+              (x2 +
+               sat->img[sat->current_image]->collisions_sizes[m][IMAGE_WIDTH])
               && y1 <
               (y2 +
-               sat->img[sat->current_image]->collisions_sizes[m][IMAGE_HEIGHT]))
+               sat->img[sat->
+                        current_image]->collisions_sizes[m][IMAGE_HEIGHT]))
             {
               /* decrease energy level of satellite */
-              sat->energy_level -= projectile->spr.pow_of_dest;
+              sat->energy_level =
+                (Sint16) (sat->energy_level - projectile->spr.pow_of_dest);
 
               /* check if satellite is destroyed */
               if (sat->energy_level <= 0)
