@@ -2,14 +2,14 @@
  * @file shockwave.c
  * @brief  handle powerful circular shock wave propagated by spaceship 
  * @created 1999-09-05 
- * @date 2007-08-22
+ * @date 2012-08-25 
  * @author Jean-Michel Martin de Santero
  * @author Etienne Sobole
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: shockwave.c,v 1.12 2007/08/24 07:55:17 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: shockwave.c,v 1.21 2012/08/25 19:18:32 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "assembler.h"
@@ -35,6 +35,7 @@
 #include "display.h"
 #include "enemies.h"
 #include "bonus.h"
+#include "log_recorder.h"
 #include "shots.h"
 #include "sdl_mixer.h"
 #include "shockwave.h"
@@ -86,8 +87,8 @@ static Sint32 *shockwave_right_buffer = NULL;
 static Sint16 *shockwave_ring_x = NULL;
 static Sint16 *shockwave_ring_y = NULL;
 
-static shockwave_struct * shockwave_get (void);
-static void shockwave_del (shockwave_struct *shock);
+static shockwave_struct *shockwave_get (void);
+static void shockwave_del (shockwave_struct * shock);
 static void draw_polygon (char *, Sint32 *, Sint32 numofpts, Uint32);
 
 /**
@@ -98,7 +99,8 @@ bool
 shockwave_once_init (void)
 {
   double a, step, pi;
-  Sint32 i, j, n, r, x, y;
+  Sint32 i, j, n, r;
+  Sint16 x, y;
 
 
   /* allocate shockwaves data structure */
@@ -109,8 +111,7 @@ shockwave_once_init (void)
                                                 sizeof (shockwave_struct));
       if (shockwave == NULL)
         {
-          fprintf (stderr, "shockwave.c/shockwave_once_init() "
-                   "shockwave out of memory");
+          LOG_ERR ("shockwave out of memory");
           return FALSE;
         }
     }
@@ -120,8 +121,7 @@ shockwave_once_init (void)
         (Sint32 *) memory_allocation (offscreen_height * sizeof (Sint32));
       if (shockwave_right_buffer == NULL)
         {
-          fprintf (stderr, "shockwave.c/shockwave_once_init() "
-                   "shockwave_right_buffer out of memory");
+          LOG_ERR ("shockwave_right_buffer out of memory");
           return FALSE;
         }
 
@@ -132,8 +132,7 @@ shockwave_once_init (void)
         (Sint32 *) memory_allocation (offscreen_height * sizeof (Sint32));
       if (shockwave_left_buffer == NULL)
         {
-          fprintf (stderr, "shockwave.c/shockwave_once_init() "
-                   "shockwave_left_buffer out of memory");
+          LOG_ERR ("shockwave_left_buffer out of memory");
           return FALSE;
         }
 
@@ -147,8 +146,7 @@ shockwave_once_init (void)
                                       sizeof (Sint16));
       if (shockwave_ring_x == NULL)
         {
-          fprintf (stderr, "shockwave.c/shockwave_once_init() "
-                   "shockwave_ring_x out of memory");
+          LOG_ERR ("'shockwave_ring_x' out of memory");
           return FALSE;
         }
       shockwave_ring_y =
@@ -196,8 +194,8 @@ shockwave_once_init (void)
       a = 0.0;
       for (j = 0; j < (NUMOF_POINTS_SHOCKWAVE - 1); j++)
         {
-          x = (Sint32) (cos (a) * r);
-          y = (Sint32) (sin (a) * r);
+          x = (Sint16) (cos (a) * r);
+          y = (Sint16) (sin (a) * r);
           a = a + step;
           shockwave_ring_x[i * n + j] = x;
           shockwave_ring_y[i * n + j] = y;
@@ -216,13 +214,7 @@ shockwave_once_init (void)
 void
 shockwave_free (void)
 {
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "> shockwave.c/shockwave_free(): "
-               "deallocates the memory used by the shockwaves\n");
-    }
-#endif
+  LOG_DBG ("deallocates the memory used by the shockwaves");
   if (shockwave != NULL)
     {
       free_memory ((char *) shockwave);
@@ -271,8 +263,7 @@ shockwave_draw (void)
 #ifdef UNDER_DEVELOPMENT
       if (shock == NULL && i < (num_of_shockwaves - 1))
         {
-          fprintf (stderr, "(!)shockwave.c/shockwave_draw(): "
-                   "shock->next is null %i/%i\n", i, num_of_shockwaves);
+          LOG_ERR ("shock->next is null %i/%i", i, num_of_shockwaves);
           break;
         }
 #endif
@@ -312,8 +303,7 @@ shockwave_draw (void)
 
                   /* draw the polygon */
                   draw_polygon (game_offscreen, coords, 4,
-                                shockwave_colors[shock->
-                                                 color_index]);
+                                shockwave_colors[shock->color_index]);
                   /* at least a polygon is visibile */
                   visible = TRUE;
                 }
@@ -361,8 +351,12 @@ shockwave_add (void)
     }
   shock->ring_index = 0;
   shock->color_index = 0;
-  shock->center_x = (Sint32) (ship->spr.xcoord + ship->spr.img[ship->spr.current_image]->x_gc);
-  shock->center_y = (Sint32) (ship->spr.ycoord + ship->spr.img[ship->spr.current_image]->y_gc);
+  shock->center_x =
+    (Sint32) (ship->spr.xcoord +
+              ship->spr.img[ship->spr.current_image]->x_gc);
+  shock->center_y =
+    (Sint32) (ship->spr.ycoord +
+              ship->spr.img[ship->spr.current_image]->y_gc);
 #ifdef USE_SDLMIXER
   sound_play (SOUND_CIRCULAR_SHOCK);
 #endif
@@ -377,7 +371,7 @@ shockwave_check_chained_list (void)
 {
   Uint32 i;
   shockwave_struct *shock;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < MAX_NUMOF_SHOCKWAVES; i++)
     {
       shock = &shockwave[i];
@@ -388,37 +382,34 @@ shockwave_check_chained_list (void)
     }
   if (count != num_of_shockwaves)
     {
-      fprintf (stderr, "(!)shockwave.c/shockwave_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, num_of_shockwaves=%i\n", count, num_of_shockwaves);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, num_of_shockwaves=%i", count, num_of_shockwaves);
     }
   count = 0;
   shock = shockwave_first;
-  do 
+  do
     {
       count++;
       shock = shock->next;
-    } 
+    }
   while (shock != NULL && count <= (MAX_NUMOF_SHOCKWAVES + 1));
   if (count != num_of_shockwaves)
     {
-      fprintf (stderr, "(!)shockwave.c/shockwave_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_shockwaves=%i\n", count, num_of_shockwaves);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_shockwaves=%i", count, num_of_shockwaves);
     }
   count = 0;
   shock = shockwave_last;
-  do 
+  do
     {
       count++;
       shock = shock->previous;
-    } 
+    }
   while (shock != NULL && count <= (MAX_NUMOF_SHOCKWAVES + 1));
   if (count != num_of_shockwaves)
     {
-      fprintf (stderr, "(!)shockwave.c/shockwave_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_shockwaves=%i\n", count, num_of_shockwaves);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_shockwaves=%i", count, num_of_shockwaves);
     }
 }
 #endif
@@ -459,8 +450,7 @@ shockwave_get (void)
 #endif
       return shock;
     }
-  fprintf (stderr, "(!)shockwave.c/shockwave_get() "
-           "no more element enemy is available\n");
+  LOG_WARN ("no more element shockwave is available");
   return NULL;
 }
 
@@ -470,7 +460,7 @@ shockwave_get (void)
  * @param Pointer to a shockwave structure 
  */
 static void
-shockwave_del (shockwave_struct *shock)
+shockwave_del (shockwave_struct * shock)
 {
   shock->is_enabled = FALSE;
   num_of_shockwaves--;
@@ -498,7 +488,7 @@ shockwave_del (shockwave_struct *shock)
  * @return TRUE if collision occurs, otherwise FALSE
  */
 bool
-shockwave_collision (enemy *foe)
+shockwave_collision (enemy * foe)
 {
   shockwave_struct *shock;
   Sint32 i, centerx, centery, dist;
@@ -513,18 +503,15 @@ shockwave_collision (enemy *foe)
       return FALSE;
     }
   centerx =
-    (Sint32) (foe->spr.xcoord +
-              foe->spr.img[foe->spr.current_image]->x_gc);
+    (Sint32) (foe->spr.xcoord + foe->spr.img[foe->spr.current_image]->x_gc);
   centery =
-    (Sint32) (foe->spr.ycoord +
-              foe->spr.img[foe->spr.current_image]->y_gc);
+    (Sint32) (foe->spr.ycoord + foe->spr.img[foe->spr.current_image]->y_gc);
   /* process each shockwave */
   for (i = 0; i < num_of_shockwaves; i++, shock = shock->next)
     {
       if (shock == NULL && i < (num_of_shockwaves - 1))
         {
-          fprintf (stderr, "(!)shockwave.c/shockwave_collision(): "
-                   "shock->next is null %i/%i\n", i, num_of_shockwaves);
+          LOG_ERR ("shock->next is null %i/%i", i, num_of_shockwaves);
           break;
         }
       /* calculate the distance between shockwave center and enemy center */
