@@ -1,13 +1,13 @@
 /** 
  * @file shots.c
  * @brief Handle all shots elements 
- * @date 2007-08-22
+ * @date 2012-10-22
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: shots.c,v 1.23 2007/08/24 07:55:17 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: shots.c,v 1.34 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -39,6 +39,7 @@
 #include "energy_gauge.h"
 #include "gfx_wrapper.h"
 #include "guardians.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "menu_sections.h"
 #include "options_panel.h"
@@ -48,7 +49,7 @@
 
 /** The number of currently active shots */
 Sint32 num_of_shots = 0;
-image fire[MAX_TYP_OF_TIR][SHOT_NUMOF_IMAGES];
+image fire[SHOT_MAX_OF_TYPE][SHOT_NUMOF_IMAGES];
 /** Data structures of all shots */
 static shot_struct *shots;
 static shot_struct *shot_first = NULL;
@@ -57,9 +58,6 @@ static shot_struct *shot_last = NULL;
 static bool shot_moving (shot_struct * bullet);
 static bool shot_display (shot_struct * bullet);
 static void shot_delete (shot_struct * bullet);
-static shot_struct *shot_spaceship_add (Sint32 damage, Sint32 anim_speed,
-                                        Sint32 image_num, Sint32 angle,
-                                        Sint32 cannon_pos);
 static bool shot_enemies_collisions (shot_struct * bullet);
 
 /**
@@ -73,7 +71,7 @@ shots_once_init (void)
 
   /* extract shots sprites images (99,6131 bytes) */
   if (!image_load
-      ("graphics/sprites/all_shots.spr", &fire[0][0], MAX_TYP_OF_TIR,
+      ("graphics/sprites/all_shots.spr", &fire[0][0], SHOT_MAX_OF_TYPE,
        SHOT_NUMOF_IMAGES))
     {
       return FALSE;
@@ -87,8 +85,7 @@ shots_once_init (void)
                                            sizeof (shot_struct));
       if (shots == NULL)
         {
-          fprintf (stderr, "(!)shots.c/shots_once_init(): "
-                   "not enough memory to allocate 'shots'");
+          LOG_ERR ("not enough memory to allocate 'shots'");
           return FALSE;
         }
     }
@@ -97,6 +94,52 @@ shots_once_init (void)
   return TRUE;
 }
 
+/**
+ * Convert shots from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+shots_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/shots/shot-%03d/shot-%02d.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/shots"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < SHOT_MAX_OF_TYPE; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/shots/shot-%03d", type + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < SHOT_NUMOF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/shots/shot-%03d/shot-%02d.png",
+                   type + 1, frame);
+          if (!image_to_png (&fire[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  return TRUE;
+}
+#endif
+
 /** 
  * Release memory used for the shots 
  */
@@ -108,7 +151,7 @@ shots_free (void)
       free_memory ((char *) shots);
       shots = NULL;
     }
-  images_free (&fire[0][0], MAX_TYP_OF_TIR, SHOT_NUMOF_IMAGES,
+  images_free (&fire[0][0], SHOT_MAX_OF_TYPE, SHOT_NUMOF_IMAGES,
                SHOT_NUMOF_IMAGES);
 }
 
@@ -147,8 +190,7 @@ shots_handle (void)
 #ifdef UNDER_DEVELOPMENT
       if (bullet == NULL && i < (num_of_shots - 1))
         {
-          fprintf (stderr, "(!)shots.c/shots(): "
-                   "shot->next is null %i/%i\n", i, num_of_shots);
+          LOG_ERR ("shot->next is null %i/%i", i, num_of_shots);
           break;
         }
 #endif
@@ -263,16 +305,14 @@ shot_moving (shot_struct * bullet)
                                    (spr->xcoord +
                                     spr->img[bullet->img_old_angle]->x_gc),
                                    (Sint16) (spr->ycoord +
-                                             spr->img[bullet->img_old_angle]->
-                                             y_gc),
+                                             spr->img[bullet->
+                                                      img_old_angle]->y_gc),
                                    (Sint16) (foe->spr.xcoord +
-                                             foe->spr.img[foe->spr.
-                                                          current_image]->
-                                             x_gc),
+                                             foe->spr.img[foe->
+                                                          spr.current_image]->x_gc),
                                    (Sint16) (foe->spr.ycoord +
-                                             foe->spr.img[foe->spr.
-                                                          current_image]->
-                                             y_gc));
+                                             foe->spr.img[foe->
+                                                          spr.current_image]->y_gc));
             bullet->angle =
               get_new_angle (bullet->angle, a, bullet->velocity);
           }
@@ -282,8 +322,9 @@ shot_moving (shot_struct * bullet)
                                    (spr->xcoord +
                                     spr->img[bullet->img_old_angle]->x_gc),
                                    (Sint16) (spr->ycoord +
-                                             spr->img[bullet->img_old_angle]->
-                                             y_gc), 256, 0);
+                                             spr->img[bullet->
+                                                      img_old_angle]->y_gc),
+                                   256, 0);
             bullet->angle =
               get_new_angle (bullet->angle, a, bullet->velocity);
           }
@@ -316,11 +357,11 @@ shot_moving (shot_struct * bullet)
               }
             /* change x and y coordinates */
             spr->xcoord +=
-              (float) initial_curve[bullet->curve_num].
-              delta_x[bullet->curve_index];
+              (float) initial_curve[bullet->curve_num].delta_x[bullet->
+                                                               curve_index];
             spr->ycoord +=
-              (float) initial_curve[bullet->curve_num].
-              delta_y[bullet->curve_index];
+              (float) initial_curve[bullet->curve_num].delta_y[bullet->
+                                                               curve_index];
           }
       }
       break;
@@ -395,18 +436,20 @@ shot_display (shot_struct * bullet)
                 /* for each collision point of the shot */
                 for (k = 0;
                      k <
-                     bullet->spr.img[bullet->img_angle]->
-                     numof_collisions_points; k++)
+                     bullet->spr.img[bullet->
+                                     img_angle]->numof_collisions_points; k++)
                   {
                     /* coordinates of the collision point of the shot */
                     tmp_tsts_x =
                       (Sint16) bullet->spr.xcoord +
-                      bullet->spr.img[bullet->img_angle]->
-                      collisions_points[k][XCOORD];
+                      bullet->spr.img[bullet->
+                                      img_angle]->collisions_points[k]
+                      [XCOORD];
                     tmp_tsts_y =
                       (Sint16) bullet->spr.ycoord +
-                      bullet->spr.img[bullet->img_angle]->
-                      collisions_points[k][YCOORD];
+                      bullet->spr.img[bullet->
+                                      img_angle]->collisions_points[k]
+                      [YCOORD];
                     /* for each collision zone of the spaceship */
                     if (spaceship_shot_collision
                         (tmp_tsts_x, tmp_tsts_y, bullet))
@@ -441,14 +484,12 @@ shot_display (shot_struct * bullet)
         if (sign (bullet->angle) < 0)
           {
             bullet->img_angle =
-              (Sint16) ((bullet->angle + DEUX_PI) / PI_SUR_16);
+              (Sint16) ((bullet->angle + TWO_PI) / PI_BY_16);
           }
         else
           {
-            bullet->img_angle = (Sint16) (bullet->angle / PI_SUR_16);
+            bullet->img_angle = (Sint16) (bullet->angle / PI_BY_16);
           }
-        /* save current angle for the calculation of the next angle */
-        bullet->img_old_angle = bullet->img_angle;
         /* avoid negative indexes */
         bullet->img_angle = (Sint16) abs (bullet->img_angle);
         /* avoid a shot angle higher than the number of images */
@@ -456,9 +497,10 @@ shot_display (shot_struct * bullet)
           {
             bullet->img_angle = (Sint16) (bullet->spr.numof_images - 1);
           }
+        /* save current angle for the calculation of the next angle */
+        bullet->img_old_angle = bullet->img_angle;
         /* draw the shot sprite */
-        draw_sprite (bullet->spr.
-                     img[bullet->img_angle],
+        draw_sprite (bullet->spr.img[bullet->img_angle],
                      (Uint32) bullet->spr.xcoord,
                      (Uint32) bullet->spr.ycoord);
 
@@ -498,7 +540,7 @@ shot_display (shot_struct * bullet)
  * @param speed Speed of the displacement
  */
 shot_struct *
-shot_guardian_add (const enemy * const guard, Uint32 cannon, Sint32 power,
+shot_guardian_add (const enemy * const guard, Uint32 cannon, Sint16 power,
                    float speed)
 {
   Sint32 i;
@@ -520,7 +562,7 @@ shot_guardian_add (const enemy * const guard, Uint32 cannon, Sint32 power,
   bullet->spr.trajectory = FALSE;
   bullet->spr.numof_images = 32;
   /* set power of the destruction */
-  bullet->spr.pow_of_dest = 8;
+  bullet->spr.pow_of_dest = power;
   for (i = 0; i < bullet->spr.numof_images; i++)
     {
       bullet->spr.img[i] = (image *) & fire[TIR1P3E][i];
@@ -541,9 +583,9 @@ shot_guardian_add (const enemy * const guard, Uint32 cannon, Sint32 power,
     guard->spr.img[guard->spr.current_image]->cannons_coords[cannon][YCOORD] -
     bullet->spr.img[bullet->img_angle]->y_gc;
   bullet->timelife = 400;
-  bullet->angle = (float) (PI_SUR_16 * bullet->img_angle);
+  bullet->angle = (float) (PI_BY_16 * bullet->img_angle);
   /* set speed of the displacement */
-  bullet->spr.speed = 2.0;
+  bullet->spr.speed = speed;
   return bullet;
 }
 
@@ -629,7 +671,7 @@ shot_enemy_add (const enemy * const foe, Sint32 k)
     bullet->spr.img[bullet->img_angle]->y_gc;
   bullet->timelife = 400;
   /* set angle of the projectile */
-  bullet->angle = PI_SUR_16 * bullet->img_angle;
+  bullet->angle = PI_BY_16 * bullet->img_angle;
   /* set speed of the displacement */
   bullet->spr.speed = 1.0f + (float) num_level / 20.0f;
 }
@@ -643,7 +685,7 @@ shot_check_chained_list (void)
 {
   Uint32 i;
   shot_struct *bullet;
-  Uint32 count = 0;
+  Sint32 count = 0;
   for (i = 0; i < MAX_OF_SHOTS; i++)
     {
       bullet = &shots[i];
@@ -654,9 +696,8 @@ shot_check_chained_list (void)
     }
   if (count != num_of_shots)
     {
-      fprintf (stderr, "(!)shots.c/shot_check_chained_list (): "
-               "Counting of the enabled elements failed!"
-               "count=%i, num_of_shots=%i\n", count, num_of_shots);
+      LOG_ERR ("Counting of the enabled elements failed!"
+               "count=%i, num_of_shots=%i", count, num_of_shots);
     }
   count = 0;
   bullet = shot_first;
@@ -668,9 +709,8 @@ shot_check_chained_list (void)
   while (bullet != NULL && count <= (MAX_OF_SHOTS + 1));
   if (count != num_of_shots)
     {
-      fprintf (stderr, "(!)shots.c/shot_check_chained_list (): "
-               "Counting of the next elements failed!"
-               "count=%i, num_of_shots=%i\n", count, num_of_shots);
+      LOG_ERR ("Counting of the next elements failed!"
+               "count=%i, num_of_shots=%i", count, num_of_shots);
     }
   count = 0;
   bullet = shot_last;
@@ -682,9 +722,8 @@ shot_check_chained_list (void)
   while (bullet != NULL && count <= (MAX_OF_SHOTS + 1));
   if (count != num_of_shots)
     {
-      fprintf (stderr, "(!)shots.c/shot_check_chained_list (): "
-               "Counting of the previous elements failed!"
-               "count=%i, num_of_shots=%i\n", count, num_of_shots);
+      LOG_ERR ("Counting of the previous elements failed!"
+               "count=%i, num_of_shots=%i", count, num_of_shots);
     }
 }
 #endif
@@ -725,8 +764,7 @@ shot_get (void)
 #endif
       return bullet;
     }
-  fprintf (stderr, "(!)shots.c/shot_get() "
-           "no more element shot is available\n");
+  LOG_ERR ("no more element shot is available");
   return NULL;
 }
 
@@ -764,7 +802,7 @@ shot_delete (shot_struct * bullet)
  * @param sat Pointer to a satellite_struct
  */
 void
-shot_satellite_add (Sint32 xcoord, Sint32 ycoord, Uint32 img_angle)
+shot_satellite_add (Sint32 xcoord, Sint32 ycoord, Sint16 img_angle)
 {
   Sint32 i;
   shot_struct *bullet;
@@ -806,7 +844,7 @@ shot_satellite_add (Sint32 xcoord, Sint32 ycoord, Uint32 img_angle)
     (float) (ycoord - bullet->spr.img[bullet->img_angle]->y_gc);
   bullet->timelife = 400;
   /* set angle of the projectile */
-  bullet->angle = PI_SUR_16 * bullet->img_angle;
+  bullet->angle = PI_BY_16 * bullet->img_angle;
   /* set speed of the displacement */
   bullet->spr.speed = 9.0;
 }
@@ -820,8 +858,8 @@ shot_satellite_add (Sint32 xcoord, Sint32 ycoord, Uint32 img_angle)
  * @param Cannon_pos Cannon's position from 0 to 12
  */
 static shot_struct *
-shot_spaceship_add (Sint32 damage, Sint32 anim_speed,
-                    Sint32 image_num, Sint32 angle, Sint32 cannon_pos)
+shot_spaceship_add (Sint16 damage, Sint16 anim_speed,
+                    Sint32 image_num, Sint16 angle, Sint32 cannon_pos)
 {
   Sint32 j;
   sprite *spr;
@@ -857,12 +895,14 @@ shot_spaceship_add (Sint32 damage, Sint32 anim_speed,
   /* set x and y coordinates */
   spr->xcoord =
     ship->spr.xcoord +
-    ship->spr.img[ship->spr.current_image]->
-    cannons_coords[cannon_pos][XCOORD] - spr->img[bullet->img_angle]->x_gc;
+    ship->spr.img[ship->spr.
+                  current_image]->cannons_coords[cannon_pos][XCOORD] -
+    spr->img[bullet->img_angle]->x_gc;
   spr->ycoord =
     ship->spr.ycoord +
-    ship->spr.img[ship->spr.current_image]->
-    cannons_coords[cannon_pos][YCOORD] - spr->img[bullet->img_angle]->y_gc;
+    ship->spr.img[ship->spr.
+                  current_image]->cannons_coords[cannon_pos][YCOORD] -
+    spr->img[bullet->img_angle]->y_gc;
   bullet->timelife = 500;
   return bullet;
 }
@@ -877,8 +917,8 @@ shot_spaceship_add (Sint32 damage, Sint32 anim_speed,
  * @param speed speed of the displacement  
  */
 void
-shot_linear_spaceship_add (Sint32 damage, Sint32 anim_speed, Sint32 image_num,
-                           Sint32 angle, Sint32 cannon_pos, float speed)
+shot_linear_spaceship_add (Sint16 damage, Sint16 anim_speed, Sint32 image_num,
+                           Sint16 angle, Sint32 cannon_pos, float speed)
 {
   shot_struct *bullet;
   bullet =
@@ -901,7 +941,7 @@ shot_linear_spaceship_add (Sint32 damage, Sint32 anim_speed, Sint32 image_num,
  * @param shot_angle
  */
 void
-shot_calulated_spaceship_add (Sint32 damage, Sint32 image_num, Sint32 angle,
+shot_calulated_spaceship_add (Sint16 damage, Sint32 image_num, Sint16 angle,
                               Sint32 cannon_pos, float shot_angle)
 {
   shot_struct *bullet;
@@ -928,8 +968,8 @@ shot_calulated_spaceship_add (Sint32 damage, Sint32 image_num, Sint32 angle,
  * @param curve_num curve number follow by the shot 
  */
 void
-shot_curve_spaceship_add (Sint32 damage, Sint32 anim_speed, Sint32 image_num,
-                          Sint32 angle, Sint32 cannon_pos, Sint32 curve_num)
+shot_curve_spaceship_add (Sint16 damage, Sint16 anim_speed, Sint32 image_num,
+                          Sint16 angle, Sint32 cannon_pos, Sint16 curve_num)
 {
   shot_struct *bullet;
   bullet =
@@ -971,8 +1011,7 @@ shot_enemies_collisions (shot_struct * bullet)
 #ifdef UNDER_DEVELOPMENT
       if (foe == NULL && i < (num_of_enemies - 1))
         {
-          fprintf (stderr, "(!)shots.c/shot_enemies_collisions(): "
-                   "foe->next is null %i/%i\n", i, num_of_enemies);
+          LOG_ERR ("foe->next is null %i/%i", i, num_of_enemies);
           break;
         }
 #endif
@@ -1017,7 +1056,8 @@ shot_enemies_collisions (shot_struct * bullet)
                 }
 
               /* decrease in the level of energy  */
-              foe->spr.energy_level -= bullet->spr.pow_of_dest;
+              foe->spr.energy_level =
+                (Sint16) (foe->spr.energy_level - bullet->spr.pow_of_dest);
 
               /* enemy destroyed */
               if (foe->spr.energy_level <= 0)
