@@ -1,13 +1,13 @@
 /** 
  * @file spaceship.c
  * @brief Handle the player's spaceship 
- * @date 2007-08-01
+ * @date 2012-08-25 
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: spaceship.c,v 1.20 2007/08/19 13:16:39 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: spaceship.c,v 1.36 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -39,6 +39,7 @@
 #include "satellite_protections.h"
 #include "menu.h"
 #include "menu_sections.h"
+#include "log_recorder.h"
 #include "options_panel.h"
 #include "sdl_mixer.h"
 #include "spaceship.h"
@@ -48,13 +49,13 @@
 #define SPACESHIP_MAX_OF_IMAGES 5
 /** Differents players (always one player) */
 typedef enum
-  {
-    PLAYER_1,
-    /* never used */
-    PLAYER_2,
+{
+  PLAYER_1,
+  /* never used */
+  PLAYER_2,
     /** Maximum of players */
-    MAX_OF_PLAYERS
-  } PLAYERS_ENUM;
+  MAX_OF_PLAYERS
+} PLAYERS_ENUM;
 /** The player has lost his spaceship */
 bool spaceship_is_dead = FALSE;
  /** If TRUE spaceship disappearing */
@@ -78,18 +79,17 @@ spaceship_once_init (void)
 {
   Uint32 type, frame;
   char *filename;
-  const char *file_template =
+  const char *model =
     "graphics/sprites/spaceships/spaceship_%01d_frame_%1d.spr";
   spaceship_struct *ship = spaceship_get ();
   spaceship_free ();
 
   /* allocate a temporary string */
-  filename = memory_allocation (strlen (file_template) + 1);
+  filename = memory_allocation (strlen (model) + 1);
   if (filename == NULL)
     {
-      fprintf (stderr, "(!)spaceship_once_init(): "
-               "not enough memory to allocate %i bytes\n",
-               strlen (file_template) + 1);
+      LOG_ERR ("not enough memory to allocate %i bytes",
+               (Uint32) (strlen (model) + 1));
       return FALSE;
     }
 
@@ -98,7 +98,7 @@ spaceship_once_init (void)
     {
       for (frame = 0; frame < SPACESHIP_MAX_OF_IMAGES; frame++)
         {
-          sprintf (filename, file_template, type + 1, frame);
+          sprintf (filename, model, type + 1, frame);
           if (!image_load_single (filename, &spaceships_sprites[type][frame]))
             {
               free_memory (filename);
@@ -112,6 +112,51 @@ spaceship_once_init (void)
   return TRUE;
 }
 
+/**
+ * Convert from data image to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+spaceship_extract (void)
+{
+  Uint32 type, frame;
+  const char *model = EXPORT_DIR "/ships/ship-%01d/ship-%01d.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/ships"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (type = 0; type < SPACESHIP_NUM_OF_TYPES; type++)
+    {
+      sprintf (filename, EXPORT_DIR "/ships/ship-%01d", type + 1);
+      if (!create_dir (filename))
+        {
+          return FALSE;
+        }
+      for (frame = 0; frame < SPACESHIP_MAX_OF_IMAGES; frame++)
+        {
+          sprintf (filename, EXPORT_DIR "/ships/ship-%01d/ship-%01d.png",
+                   type + 1, frame);
+          if (!image_to_png (&spaceships_sprites[type][frame], filename))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /**
  * Release sprites images and of the player's spaceship
  * @return TRUE if successful
@@ -306,8 +351,7 @@ spaceship_initialize (void)
   /* set addresses of the sprites images buffer */
   for (i = 0; i < SPACESHIP_MAX_OF_IMAGES; i++)
     {
-      ship->spr.img[i] =
-        (image *) & spaceships_sprites[ship->type][i];
+      ship->spr.img[i] = (image *) & spaceships_sprites[ship->type][i];
     }
 }
 
@@ -415,8 +459,7 @@ spaceship_downgrading (void)
       /* set addresses of the sprites images buffer */
       for (i = 0; i < SPACESHIP_MAX_OF_IMAGES; i++)
         {
-          ship->spr.img[i] =
-            (image *) & spaceships_sprites[ship->type][i];
+          ship->spr.img[i] = (image *) & spaceships_sprites[ship->type][i];
         }
       /* remove protection satellites */
       satellites_init ();
@@ -435,7 +478,7 @@ spaceship_downgrading (void)
  * @param invincibility Invincibility counter time 
  */
 void
-spaceship_set_invincibility (Sint32 invincibility)
+spaceship_set_invincibility (Sint16 invincibility)
 {
   spaceship_struct *ship = spaceship_get ();
   ship->invincibility_delay = invincibility;
@@ -569,8 +612,7 @@ spaceship_upgrading (void)
   /* set addresses of the images buffer */
   for (i = 0; i < SPACESHIP_MAX_OF_IMAGES; i++)
     {
-      ship->spr.img[i] =
-        (image *) & spaceships_sprites[ship->type][i];
+      ship->spr.img[i] = (image *) & spaceships_sprites[ship->type][i];
     }
   /* remove protection satellites */
   satellites_init ();
@@ -624,8 +666,10 @@ spaceship_enemy_collision (enemy * foe, float speed_x, float speed_y)
       for (l = 0; l < foe_img->numof_collisions_zones; l++)
         {
           /* coordinates of the collision zone of the enemy */
-          x2 = (Sint32) foe->spr.xcoord + foe_img->collisions_coords[l][XCOORD];
-          y2 = (Sint32) foe->spr.ycoord + foe_img->collisions_coords[l][YCOORD];
+          x2 =
+            (Sint32) foe->spr.xcoord + foe_img->collisions_coords[l][XCOORD];
+          y2 =
+            (Sint32) foe->spr.ycoord + foe_img->collisions_coords[l][YCOORD];
 
           /* check if spaceship collision point is into enemy collision zone */
           if (x1 < x2 ||
@@ -650,7 +694,8 @@ spaceship_enemy_collision (enemy * foe, float speed_x, float speed_y)
                   option_anim_init (OPTION_PANEL_REPAIR, FALSE);
                 }
               /* decrease energy level of satellite */
-              ship->spr.energy_level -= foe->spr.pow_of_dest;
+              ship->spr.energy_level =
+                (Sint16) (ship->spr.energy_level - foe->spr.pow_of_dest);
             }
           /* update spaceship's energy gauge */
           energy_gauge_spaceship_is_update = TRUE;
@@ -708,7 +753,8 @@ spaceship_shot_collision (Sint32 x1, Sint32 y1, shot_struct * bullet)
       /* check if shot collision point is into spaceship collision zone */
       if (x1 < x2
           || x1 >= x2 + ship_img->collisions_sizes[i][IMAGE_WIDTH]
-          || y1 < y2 || y1 >= y2 + ship_img->collisions_sizes[i][IMAGE_HEIGHT])
+          || y1 < y2
+          || y1 >= y2 + ship_img->collisions_sizes[i][IMAGE_HEIGHT])
         {
           continue;
         }
@@ -722,7 +768,8 @@ spaceship_shot_collision (Sint32 x1, Sint32 y1, shot_struct * bullet)
               option_anim_init (OPTION_PANEL_REPAIR, FALSE);
             }
           /* decrease energy level of spaceship */
-          ship->spr.energy_level -= bullet->spr.pow_of_dest;
+          ship->spr.energy_level =
+            (Sint16) (ship->spr.energy_level - bullet->spr.pow_of_dest);
         }
       /* update spaceship's energy gauge */
       energy_gauge_spaceship_is_update = TRUE;
@@ -861,7 +908,6 @@ spaceship_speed_control (void)
           ship->y_speed = 0.0f;
         }
     }
-
 }
 
 /**
@@ -883,7 +929,8 @@ spaceship_draw (void)
       /* display white mask of the sprite */
       if (ship->is_white_mask_displayed)
         {
-          draw_sprite_mask (coulor[WHITE], ship->spr.img[ship->spr.current_image],
+          draw_sprite_mask (coulor[WHITE],
+                            ship->spr.img[ship->spr.current_image],
                             (Sint32) (ship->spr.xcoord),
                             (Sint32) (ship->spr.ycoord));
           ship->is_white_mask_displayed = FALSE;
