@@ -2,12 +2,12 @@
  * @file sprites_string.c 
  * @brief  handle the strings fonts of sprites 
  * @created 2006-12-18 
- * @date 2007-08-19
+ * @date 2012-08-25
  * @author Bruno Ethvignot 
  */
 /* 
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: sprites_string.c,v 1.19 2007/08/19 19:21:15 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: sprites_string.c,v 1.31 2012/08/25 15:55:00 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
@@ -32,11 +32,9 @@
 #include "display.h"
 #include "electrical_shock.h"
 #include "gfx_wrapper.h"
+#include "log_recorder.h"
 #include "scrolltext.h"
 #include "sprites_string.h"
-#ifdef POWERMANGA_X11
-#include <X11/keysym.h>
-#endif
 
 #define FONT_SCORE_MAXOF_CHARS 10
 #define FONT_BIG_MAXOF_CHARS 27
@@ -66,6 +64,7 @@ static unsigned char cycling_table[] = {
   64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 78,
   77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 0
 };
+
 static Uint32 cycling_delay = 0;
 static Uint32 cycling_index = 0;
 
@@ -110,9 +109,7 @@ sprites_string_once_init (void)
                                                       *));
       if (strings_list == NULL)
         {
-          fprintf (stderr,
-                   "(!)sprites_string.c/sprites_string_once_init(): "
-                   "not enough memory to allocate 'strings_list'");
+          LOG_ERR ("not enough memory to allocate 'strings_list'");
           return FALSE;
         }
     }
@@ -122,41 +119,140 @@ sprites_string_once_init (void)
   /* 159,654 bytes */
   if (!bitmap_load
       ("graphics/bitmap/fonts/font_game.spr", &fnt_game[0][0],
-       FONT_GAME_MAXOF_CHARS, FONTS_MAX_OF_IMAGES, 16))
+       FONT_GAME_MAXOF_CHARS, FONTS_MAX_OF_IMAGES))
     {
       return FALSE;
     }
   /* 149 950 bytes */
   if (!bitmap_load
       ("graphics/bitmap/fonts/font_big.spr", &fnt_big[0][0],
-       FONT_BIG_MAXOF_CHARS, FONTS_MAX_OF_IMAGES, 32))
+       FONT_BIG_MAXOF_CHARS, FONTS_MAX_OF_IMAGES))
     {
       return FALSE;
     }
   /* 52 480 bytes */
   if (!bitmap_load
       ("graphics/bitmap/fonts/font_score.spr", &fnt_score[0][0],
-       FONT_SCORE_MAXOF_CHARS, FONTS_MAX_OF_IMAGES, 16))
+       FONT_SCORE_MAXOF_CHARS, FONTS_MAX_OF_IMAGES))
     {
       return FALSE;
     }
   return TRUE;
 }
 
+/**
+ * Convert fonts from data bitmaps to PNG file
+ * @return TRUE if successful
+ */
+#ifdef PNG_EXPORT_ENABLE
+bool
+sprites_font_extract (void)
+{
+  Uint32 i, frame;
+  const char *model = EXPORT_DIR "/fonts/xxxxx/xx/xx.png";
+  char *filename = memory_allocation (strlen (model) + 1);
+  if (filename == NULL)
+    {
+      LOG_ERR ("not enough memory to allocate %i bytes\n",
+               (Uint32) (strlen (model) + 1));
+      return FALSE;
+    }
+  if (!create_dir (EXPORT_DIR "/fonts"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+
+  if (!create_dir (EXPORT_DIR "/fonts/game"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (i = 0; i < FONT_GAME_MAXOF_CHARS; i++)
+    {
+      sprintf (filename, EXPORT_DIR "/fonts/game/%02d", i + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < FONTS_MAX_OF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/fonts/game/%02d/%02d.png", i + 1, frame);
+          if (!bitmap_to_png
+              (&fnt_game[i][frame], filename, 16, 16, offscreen_pitch))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+
+  if (!create_dir (EXPORT_DIR "/fonts/big"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (i = 0; i < FONT_BIG_MAXOF_CHARS; i++)
+    {
+      sprintf (filename, EXPORT_DIR "/fonts/big/%02d", i + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < FONTS_MAX_OF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/fonts/big/%02d/%02d.png", i + 1, frame);
+          if (!bitmap_to_png
+              (&fnt_big[i][frame], filename, 32, 26, offscreen_pitch))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+
+  if (!create_dir (EXPORT_DIR "/fonts/score"))
+    {
+      free_memory (filename);
+      return FALSE;
+    }
+  for (i = 0; i < FONT_SCORE_MAXOF_CHARS; i++)
+    {
+      sprintf (filename, EXPORT_DIR "/fonts/score/%02d", i + 1);
+      if (!create_dir (filename))
+        {
+          free_memory (filename);
+          return FALSE;
+        }
+      for (frame = 0; frame < FONTS_MAX_OF_IMAGES; frame++)
+        {
+          sprintf (filename,
+                   EXPORT_DIR "/fonts/score/%02d/%02d.png", i + 1, frame);
+          if (!bitmap_to_png
+              (&fnt_score[i][frame], filename, 16, 16, score_offscreen_pitch))
+            {
+              free_memory (filename);
+              return FALSE;
+            }
+        }
+    }
+  free_memory (filename);
+  return TRUE;
+}
+#endif
+
 /**
  * Release all sprites strings structures
  */
 void
 sprites_string_free (void)
 {
-#ifdef VERBOSE
-  if (power_conf->verbose)
-    {
-      fprintf (stdout, "> sprites_string.c/sprites_string_free(): "
-               "deallocates the memory used by the bitmap\n");
-    }
-#endif
   Uint32 i;
+  LOG_DBG ("deallocates the memory used by the bitmap");
   if (strings_list == NULL)
     {
       return;
@@ -209,8 +305,7 @@ sprites_string_new (const char *const string, Uint32 more_chars, Uint32 type,
     }
   if (maxof_chars == 0)
     {
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_new() "
-               "size lenght is null!\n");
+      LOG_ERR ("The string's lenght is null!");
       return NULL;
     }
 
@@ -218,8 +313,7 @@ sprites_string_new (const char *const string, Uint32 more_chars, Uint32 type,
   string_allocated = memory_allocation (maxof_chars + 1);
   if (string_allocated == NULL)
     {
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_new(): "
-               "not enough memory to allocate a string!\n");
+      LOG_ERR ("not enough memory to allocate a string!");
       return NULL;
     }
   if (string != NULL)
@@ -240,8 +334,7 @@ sprites_string_new (const char *const string, Uint32 more_chars, Uint32 type,
   if (sprite_str == NULL)
     {
       free_memory (string_allocated);
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_new(): "
-               "sprites_string_create() failed!\n");
+      LOG_ERR ("sprites_string_create() failed!");
       return NULL;
     }
   sprite_str->num_of_chars = numof_chars;
@@ -268,8 +361,7 @@ sprites_string_create (char *string, Uint32 size, Uint32 type, float coordx,
   sprite_string_struct *sprite_str;
   if (num_of_sprites_strings >= MAX_OF_STRINGS)
     {
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_create(): "
-               "maximum number of sprites string reached!\n");
+      LOG_ERR ("maximum number of sprites string reached!");
       return NULL;
     }
 
@@ -277,10 +369,9 @@ sprites_string_create (char *string, Uint32 size, Uint32 type, float coordx,
   sprite_str =
     (sprite_string_struct *)
     memory_allocation (sizeof (sprite_string_struct));
-  if (strings_list == NULL)
+  if (sprite_str == NULL)
     {
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_create(): "
-               "not enough memory to allocate 'sprite_string_struct'!\n");
+      LOG_ERR ("not enough memory to allocate 'sprite_string_struct'!");
       return NULL;
     }
   sprite_str->string = string;
@@ -306,8 +397,7 @@ sprites_string_create (char *string, Uint32 size, Uint32 type, float coordx,
   if (sprite_str->sprites_chars == NULL)
     {
       free_memory ((char *) sprite_str);
-      fprintf (stderr, "(!)sprites_string.c/sprites_string_create(): "
-               "not enough memory to allocate 'sprite_char_struct'!\n");
+      LOG_ERR ("not enough memory to allocate 'sprite_char_struct'!");
       return NULL;
     }
   for (i = 0; i < sprite_str->max_of_chars; i++)
@@ -358,8 +448,7 @@ sprites_string_delete (sprite_string_struct * sprite_str)
       strings_list[j] = NULL;
       return;
     }
-  fprintf (stderr,
-           "sprites_string.c/sprites_string_delete (): sprite_string_struct not found\n");
+  LOG_ERR ("sprite_string_struct not found");
 }
 
 
@@ -595,11 +684,11 @@ sprite_char_rotate_enlarge (sprite_char_struct * sprite_char, Sint32 incx,
  * @param str a simple string
  */
 bool
-sprite_string_set_char (sprite_string_struct * sprite_str, char *str)
+sprite_string_set_char (sprite_string_struct * sprite_str, const char *str)
 {
   if (strlen (str) > sprite_str->max_of_chars)
     {
-      fprintf (stderr, "(!)sprite_string_set_char(): string too long\n");
+      LOG_ERR ("string too long");
       return FALSE;
     }
   strcpy (sprite_str->string, str);
@@ -1180,7 +1269,7 @@ sprites_string_input_code (sprite_string_struct * sprite_str, Sint32 keycode)
     cursor_size;
   ycoord = (Sint32) sprite_str->coord_y + sprite_str->space / 2 - cursor_size;
   cursor_size += cursor_size;
-  if (ycoord + cursor_size >= offscreen_starty) 
+  if (ycoord + cursor_size >= offscreen_starty)
     {
       draw_empty_rectangle (game_offscreen, xcoord, ycoord - 2, color,
                             cursor_size, cursor_size);
@@ -1324,7 +1413,7 @@ sprites_string_input_code (sprite_string_struct * sprite_str, Sint32 keycode)
             {
               sprite_str->string[i] = sprite_str->string[i - 1];
             }
-          sprite_str->string[sprite_str->cursor_pos] = keycode;
+          sprite_str->string[sprite_str->cursor_pos] = (char) keycode;
           sprite_char = &sprite_str->sprites_chars[sprite_str->cursor_pos];
           sprite_str->cursor_pos++;
           sprite_chars_to_image (sprite_str);
