@@ -1,12 +1,12 @@
 /**
  * @file text_overlay.c
  * @brief Handle text overlay to display abouts, cheats menu and variables  
- * @date 2007-08-31
+ * @date 2012-08-26 
  * @author Bruno Ethvignot
  */
 /*
- * copyright (c) 1998-2007 TLK Games all rights reserved
- * $Id: text_overlay.c,v 1.30 2007/09/02 16:13:56 gurumeditation Exp $
+ * copyright (c) 1998-2014 TLK Games all rights reserved
+ * $Id: text_overlay.c,v 1.41 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,10 +23,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  */
-#include <stdbool.h>
+#include "config.h"
 #include "powermanga.h"
 #include "tools.h"
 #include "images.h"
+#include "display.h"
 #include "curve_phase.h"
 #include "config_file.h"
 #include "display.h"
@@ -39,21 +40,19 @@
 #include "grid_phase.h"
 #include "guardians.h"
 #include "lonely_foes.h"
+#include "log_recorder.h"
 #include "menu.h"
 #include "menu_sections.h"
 #include "meteors_phase.h"
+#include "options_panel.h"
 #include "satellite_protections.h"
 #include "shockwave.h"
 #include "sdl_mixer.h"
 #include "spaceship.h"
 #include "texts.h"
 #include "text_overlay.h"
-#ifdef USE_SDLMIXER
-#include <SDL/SDL_mixer.h>
-#endif
 
 #ifdef USE_SDLMIXER
-
 #ifdef UNDER_DEVELOPMENT
 static Uint32 current_sound = 0;
 #endif
@@ -83,7 +82,7 @@ typedef enum
   SECTION_VAR2
 } SECTIONS;
 
-static void draw_text (Sint32 xcoord, Sint32 ycoord, char *string);
+static void draw_text (Sint32 xcoord, Sint32 ycoord, const char *string);
 static void draw_about (void);
 #ifdef UNDER_DEVELOPMENT
 static void draw_variables_1 (void);
@@ -109,6 +108,7 @@ static Sint32 cheat_level_num = 0;
 static Sint32 cheat_guardian_num = 14;
 /** Loney foe number to launch */
 static Sint32 cheat_lonely_foe_num = 0;
+static bool cheat_button_pressed = FALSE;
 #endif
 
 /**
@@ -125,8 +125,7 @@ text_overlay_once_init (void)
   bitmap_font = (unsigned char *) load_pcx_file ("graphics/font_overlay.pcx");
   if (bitmap_font == NULL)
     {
-      fprintf (stderr, "(!)text_overlay.c/text_overlay_once_init():"
-               "could not load font file");
+      LOG_ERR ("could not load font file");
       return FALSE;
     }
   return TRUE;
@@ -146,6 +145,38 @@ text_overlay_release (void)
   bitmap_font = NULL;
 }
 
+/** 
+ * Check if the button that enables or disables the cheat menu is 
+ * pressed ([P] key, or mouse button into the panel option)
+ * @return TRUE if the button is pressed, or FALSE otherwise
+ */
+#ifdef UNDER_DEVELOPMENT
+static bool
+menu_check_cheat_button (void)
+{
+  bool result;
+  bool pressed = keys_down[K_P] || (mouse_b == 1
+                                    && mouse_x >
+                                    (offscreen_width_visible +
+                                     SCORE_MULTIPLIER_XCOORD * pixel_size)
+                                    && mouse_y >
+                                    (score_offscreen_height +
+                                     SCORE_MULTIPLIER_BOTTOM_YCOORD *
+                                     pixel_size));
+
+  if (!cheat_button_pressed && pressed)
+    {
+      result = TRUE;
+    }
+  else
+    {
+      result = FALSE;
+    }
+  cheat_button_pressed = pressed;
+  return result;
+}
+#endif
+
 /**
  * Draw text overlay
  */
@@ -181,7 +212,9 @@ text_overlay_draw (void)
   else
     {
       /* [Ctrl] key pressed? */
+#if !defined(_WIN32_WCE)
       if (keys_down[K_CTRL])
+#endif
         {
           if (keys_down[K_A])
             {
@@ -220,12 +253,14 @@ text_overlay_draw (void)
                   text_overlay_section = SECTION_VAR2;
                 }
             }
-          if (keys_down[K_P] && menu_status == MENU_OFF)
+          if (menu_status == MENU_OFF && menu_check_cheat_button ())
             {
               last_key_down = K_P;
               if (text_overlay_section == SECTION_CHEATS_MENU)
                 {
                   text_overlay_section = NO_SECTION;
+                  player_pause = FALSE;
+                  is_pause_draw = FALSE;
                 }
               else
                 {
@@ -239,7 +274,9 @@ text_overlay_draw (void)
 #endif
         }
 #ifdef UNDER_DEVELOPMENT
+#if !defined(_WIN32_WCE)
       else
+#endif
         {
           if (keys_down[K_RETURN] || keys_down[K_SPACE])
             {
@@ -295,9 +332,9 @@ cheats_menu_check (void)
     case ITEM_DESTROY_GUARDIAN:
       if (guardian->number)
         {
-          if (guardian->enemy[0]->is_enabled)
+          if (guardian->foe[0]->is_enabled)
             {
-              guardian->enemy[0]->spr.energy_level = -1;
+              guardian->foe[0]->spr.energy_level = -1;
             }
         }
       enabled = TRUE;
@@ -319,12 +356,12 @@ cheats_menu_check (void)
       break;
     case ITEM_LONELY_FOE:
       enabled = TRUE;
-      lonely_foe_add (cheat_lonely_foe_num) ;
+      lonely_foe_add (cheat_lonely_foe_num);
       break;
     case ITEM_WHOLE_LONELY_FOES:
       for (i = 0; i < LONELY_FOES_MAX_OF; i++)
         {
-          lonely_foe_add (i) ;
+          lonely_foe_add (i);
         }
       enabled = TRUE;
       break;
@@ -346,32 +383,31 @@ cheats_menu_check (void)
  * Text of the cheats menu
  */
 #ifdef UNDER_DEVELOPMENT
-char cheats_menu_text[] = 
-{
-  "################################@"
-  "# ] level number       :??     #@"
-  "#   go to guardian     :??     #@"
-  "#   most powefull spaceship    #@"
-  "#   destroy guardian   :??     #@"
-  "#   add protection satellites  #@"
-  "#   add extra guns             #@"
-  "#   upgrade spaceship          #@"
-  "#   lonely foe         :??     #@"
-  "#   whole lonely foes          #@"
-  "#   maximum front shot 1       #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#                              #@"
-  "#  > PRESS CTRL-P TO CANCEL <  #@"
+static char cheats_menu_text[] = {
   "################################@"
+    "# ] level number       :??     #@"
+    "#   go to guardian     :??     #@"
+    "#   most powefull spaceship    #@"
+    "#   destroy guardian   :??     #@"
+    "#   add protection satellites  #@"
+    "#   add extra guns             #@"
+    "#   upgrade spaceship          #@"
+    "#   lonely foe         :??     #@"
+    "#   whole lonely foes          #@"
+    "#   maximum front shot 1       #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#                              #@"
+    "#  > PRESS CTRL-P TO CANCEL <  #@"
+    "################################@"
 };
 #endif
 
@@ -485,12 +521,12 @@ draw_cheats_menu (void)
 /**
  * About text displaying with a [Ctrl] + [A]
  */
-static char about_texts[] = {
+static const char about_texts[] = {
   "********************************@"
     "*                              *@* "
     POWERMANGA_VERSION
     "*@*                LINUX VERSION *@"
-    "* (c) 1998-2007 TLK-GAMES      *@"
+    "* (c) 1998-2014 TLK-GAMES      *@"
     "*                              *@"
     "* LINUX.TLK.FR                 *@"
     "*                              *@"
@@ -507,7 +543,7 @@ static char about_texts[] = {
     "* PATRICE DUHAMEL              *@"
     "* SAM HOCEVAR                  *@"
     "*                              *@"
-    "*  > PRESS CTRL-A TO CANCEL <  *@"
+    "*  > PRESS CTRL-A TO CANCEL <  *@" 
     "********************************@"
 };
 
@@ -525,31 +561,29 @@ draw_about (void)
  * variables displaying with a [Ctrl] + [V]
  */
 #ifdef UNDER_DEVELOPMENT
-static char variables_text_1[] =
-{
-  " * * * * * * * * * * * * * * * *@"
-  "* num-level:??    etat-menu:?   @"
-  "  player-pause:?  aff-pause:?  *@"
-  "* game-over-player-one:?        @"
-  "  aff-game-over:?  quit-game:? *@"
-  "* guardian->is_appearing:?      @"
-  "  gardian-activity:??          *@"
-  "* meteor-activity:?             @"
-  "  grid.is-enable:?             *@"
-  "* courbe.activity:?             @"
-  "  touch-90-:?                  *@"
-  "* nbr-nmis:???                  @"
-  "  menu-section:               ?*@"
-  "*                  vmode:?      @"
-  "  tmp_apparition-vj:           *@"
-  "* disparition-vj:               @"
-  "  ship->fire_rate:             *@"
-  "* mem-numof_zones:?????         @"
-  "  mem-total-size:???????? ?????*@"
-  "* taille-mem-glob:????????      @"
-  "                               *@"
-  "*  > PRESS CTRL-V TO CANCEL <   @"
+static char variables_text_1[] = {
   " * * * * * * * * * * * * * * * *@"
+    "* num-level:??    etat-menu:?   @"
+    "  player-pause:?  aff-pause:?  *@"
+    "* game-over-player-one:?        @"
+    "  aff-game-over:?  quit-game:? *@"
+    "* guardian->is_appearing:?      @"
+    "  gardian-activity:??          *@"
+    "* meteor-activity:?             @"
+    "  grid.is-enable:?             *@"
+    "* courbe.activity:?             @"
+    "  touch-90-:?                  *@"
+    "* nbr-nmis:???                  @"
+    "  menu-section:               ?*@"
+    "*                  vmode:?      @"
+    "  tmp_apparition-vj:           *@"
+    "* disparition-vj:               @"
+    "  ship->fire_rate:             *@"
+    "* mem-numof_zones:?????         @"
+    "  mem-total-size:???????? ?????*@"
+    "* taille-mem-glob:????????      @"
+    "                               *@"
+    "*  > PRESS CTRL-V TO CANCEL <   @" " * * * * * * * * * * * * * * * *@"
 };
 #endif
 
@@ -581,42 +615,43 @@ draw_variables_1 (void)
   integer_to_ascii (spaceship_appears_count, 4, str + (33 * 14) + 20);
   integer_to_ascii (spaceship_disappears, 4, str + (33 * 15) + 18);
   integer_to_ascii (ship->fire_rate, 4, str + (33 * 16) + 17);
+#if defined (USE_MALLOC_WRAPPER)
   integer_to_ascii (mem_numof_zones, 5, str + (33 * 17) + 17);
   integer_to_ascii (mem_total_size, 8, str + (33 * 18) + 17);
   integer_to_ascii (mem_total_size / 1024, 5, str + (33 * 18) + 26);
+#endif
   /* integer_to_ascii (taille_mem_glob, 8, str + (33 * 19) + 18); */
   draw_text (0, 0, str);
 }
 #endif
 
-
-char variables_text_2[] = 
-{ 
-  " * * * * * * * * * * * * * * * *@"
-  "* test channel is playing       @"
-  "  ????????????????             *@"
-  "* current-sound:                @"
-  "                               *@"
-  "*                               @"
-  "  sound-samples-len:           *@"
-  "* difficulty:                   @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*                               @"
-  "                               *@"
-  "*  > PRESS CTRL-B TO CANCEL <   @"
+#ifdef UNDER_DEVELOPMENT
+static char variables_text_2[] = {
   " * * * * * * * * * * * * * * * *@"
+    "* test channel is playing       @"
+    "  ????????????????             *@"
+    "* current-sound:                @"
+    "                               *@"
+    "*                               @"
+    "  sound-samples-len:           *@"
+    "* difficulty:                   @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*                               @"
+    "                               *@"
+    "*  > PRESS CTRL-B TO CANCEL <   @" 
+    " * * * * * * * * * * * * * * * *@"
 };
-
+#endif
 
 /**
  * Display other variable values and play sound
@@ -725,8 +760,8 @@ draw_variables_2 (void)
  * @param ycoord top-left y coordinate of the text
  * @param string chars to draw
  */
-void
-draw_text (Sint32 xcoord, Sint32 ycoord, char *string)
+static void
+draw_text (Sint32 xcoord, Sint32 ycoord, const char *string)
 {
   Uint32 offset;
   unsigned char *source, *screen, *dest, c;
